; ******
; Mazogs
; ******
; (c)1981 Bug-Byte Software Ltd, written by Don Priestley.
; For the 16KB ZX81.
;
; Disassembled by Paul Farrow (www.fruitcake.plus.com), 22 May 2016 (revised 29 May 2017).

; ======================================================================================================================================================

; ====================
; Assembler Directives
; ====================
; For TASM assembler.

#define DEFB .BYTE
#define DEFW .WORD
#define DEFM .TEXT
#define DEFS .BLOCK
#define EQU  .EQU
#define ORG  .ORG
#define END  .END

; ======
; Macros
; ======

; Creates the alternate version of: LD (nn),HL

#define STORE_HL(nn)    DEFB $ED, $63, nn & $FF, nn >> 8

; =======
; Options
; =======

; Include the following definition to create a P81 file, otherwise a P file will be generated.
;#define MAKE_P81

; ======================================================================================================================================================

; =======================
; Character Set Constants
; =======================

_SPACE                          EQU     $00     ; 0
_TOPLEFTBLACK                   EQU     $01     ; 1
_TOPRIGHTBLACK                  EQU     $02     ; 2
_TOPBLACK                       EQU     $03     ; 3
_BOTTOMLEFTBLACK                EQU     $04     ; 4
_LEFTBLACK                      EQU     $05     ; 5
_BOTTOMLEFTTOPRIGHT             EQU     $06     ; 6
_BOTTOMRIGHTWHITE               EQU     $07     ; 7
_CHEQUERBOARD                   EQU     $08     ; 8
_TOPWHITEBOTTOMCHEQUER          EQU     $09     ; 9
_TOPCHEQUERBOTTOMWHITE          EQU     $0A     ; 10
_QUOTE                          EQU     $0B     ; 11
_POUND                          EQU     $0C     ; 12
_DOLLAR                         EQU     $0D     ; 13
_COLON                          EQU     $0E     ; 14
_QUESTIONMARK                   EQU     $0F     ; 15
_OPENBRACKET                    EQU     $10     ; 16
_CLOSEBRACKET                   EQU     $11     ; 17
_GREATERTHAN                    EQU     $12     ; 18
_LESSTHAN                       EQU     $13     ; 19
_EQUALS                         EQU     $14     ; 20
_PLUS                           EQU     $15     ; 21
_MINUS                          EQU     $16     ; 22
_ASTERISK                       EQU     $17     ; 23
_DIVIDE                         EQU     $18     ; 24
_SEMICOLON                      EQU     $19     ; 25
_COMMA                          EQU     $1A     ; 26
_FULLSTOP                       EQU     $1B     ; 27
_0                              EQU     $1C     ; 28
_1                              EQU     $1D     ; 29
_2                              EQU     $1E     ; 30
_3                              EQU     $1F     ; 31
_4                              EQU     $20     ; 32
_5                              EQU     $21     ; 33
_6                              EQU     $22     ; 34
_7                              EQU     $23     ; 35
_8                              EQU     $24     ; 36
_9                              EQU     $25     ; 37
_A                              EQU     $26     ; 38
_B                              EQU     $27     ; 39
_C                              EQU     $28     ; 40
_D                              EQU     $29     ; 41
_E                              EQU     $2A     ; 42
_F                              EQU     $2B     ; 43
_G                              EQU     $2C     ; 44
_H                              EQU     $2D     ; 45
_I                              EQU     $2E     ; 46
_J                              EQU     $2F     ; 47
_K                              EQU     $30     ; 48
_L                              EQU     $31     ; 49
_M                              EQU     $32     ; 50
_N                              EQU     $33     ; 51
_O                              EQU     $34     ; 52
_P                              EQU     $35     ; 53
_Q                              EQU     $36     ; 54
_R                              EQU     $37     ; 55
_S                              EQU     $38     ; 56
_T                              EQU     $39     ; 57
_U                              EQU     $3A     ; 58
_V                              EQU     $3B     ; 59
_W                              EQU     $3C     ; 60
_X                              EQU     $3D     ; 61
_Y                              EQU     $3E     ; 62
_Z                              EQU     $3F     ; 63
_RND                            EQU     $40     ; 64
_INKEY                          EQU     $41     ; 65
_PI                             EQU     $42     ; 66
_CURSORUP                       EQU     $70     ; 112
_CURSORDOWN                     EQU     $71     ; 113
_CURSORLEFT                     EQU     $72     ; 114
_CURSORRIGHT                    EQU     $73     ; 115
_GRAPHICS                       EQU     $74     ; 116
_EDIT                           EQU     $75     ; 117
_NEWLINE                        EQU     $76     ; 118
_RUBOUT                         EQU     $77     ; 119
_MODE                           EQU     $78     ; 120
_FUNCTION                       EQU     $79     ; 121
_NUMBER                         EQU     $7E     ; 126
_CURSOR                         EQU     $7F     ; 127
_BLACK                          EQU     $80     ; 128
_TOPLEFTWHITE                   EQU     $81     ; 129
_TOPRIGHTWHITE                  EQU     $82     ; 130
_BOTTOMBLACK                    EQU     $83     ; 131
_BOTTOMLEFTWHITE                EQU     $84     ; 132
_RIGHTBLACK                     EQU     $85     ; 133
_TOPLEFTBOTTOMRIGHT             EQU     $86     ; 134
_BOTTOMRIGHTBLACK               EQU     $87     ; 135
_INVCHEQUERBOARD                EQU     $88     ; 136
_TOPBLACKBOTTOMCHEQUER          EQU     $89     ; 137
_TOPCHEQUERBOTTOMBLACK          EQU     $8A     ; 138
_INVQUOTE                       EQU     $8B     ; 139
_INVPOUND                       EQU     $8C     ; 140
_INVDOLLAR                      EQU     $8D     ; 141
_INVCOLON                       EQU     $8E     ; 142
_INVQUESTIONMARK                EQU     $8F     ; 143
_INVOPENBRACKET                 EQU     $90     ; 144
_INVCLOSEBRACKET                EQU     $91     ; 145
_INVGREATERTHAN                 EQU     $92     ; 146
_INVLESSTHAN                    EQU     $93     ; 147
_INVEQUALS                      EQU     $94     ; 148
_INVPLUS                        EQU     $95     ; 149
_INVMINUS                       EQU     $96     ; 150
_INVASTERISK                    EQU     $97     ; 151
_INVDIVIDE                      EQU     $98     ; 152
_INVSEMICOLON                   EQU     $99     ; 153
_INVCOMMA                       EQU     $9A     ; 154
_INVFULLSTOP                    EQU     $9B     ; 155
_INV0                           EQU     $9C     ; 156
_INV1                           EQU     $9D     ; 157
_INV2                           EQU     $9E     ; 158
_INV3                           EQU     $9F     ; 159
_INV4                           EQU     $A0     ; 160
_INV5                           EQU     $A1     ; 161
_INV6                           EQU     $A2     ; 162
_INV7                           EQU     $A3     ; 163
_INV8                           EQU     $A4     ; 164
_INV9                           EQU     $A5     ; 165
_INVA                           EQU     $A6     ; 166
_INVB                           EQU     $A7     ; 167
_INVC                           EQU     $A8     ; 168
_INVD                           EQU     $A9     ; 169
_INVE                           EQU     $AA     ; 170
_INVF                           EQU     $AB     ; 171
_INVG                           EQU     $AC     ; 172
_INVH                           EQU     $AD     ; 173
_INVI                           EQU     $AE     ; 174
_INVJ                           EQU     $AF     ; 175
_INVK                           EQU     $B0     ; 176
_INVL                           EQU     $B1     ; 177
_INVM                           EQU     $B2     ; 178
_INVN                           EQU     $B3     ; 179
_INVO                           EQU     $B4     ; 180
_INVP                           EQU     $B5     ; 181
_INVQ                           EQU     $B6     ; 182
_INVR                           EQU     $B7     ; 183
_INVS                           EQU     $B8     ; 184
_INVT                           EQU     $B9     ; 185
_INVU                           EQU     $BA     ; 186
_INVV                           EQU     $BB     ; 187
_INVW                           EQU     $BC     ; 188
_INVX                           EQU     $BD     ; 189
_INVY                           EQU     $BE     ; 190
_INVZ                           EQU     $BF     ; 191
_DOUBLEQUOTE                    EQU     $C0     ; 192
_AT                             EQU     $C1     ; 193
_TAB                            EQU     $C2     ; 194
_CODE                           EQU     $C4     ; 196
_VAL                            EQU     $C5     ; 197
_LEN                            EQU     $C6     ; 198
_SIN                            EQU     $C7     ; 199
_COS                            EQU     $C8     ; 200
_TAN                            EQU     $C9     ; 201
_ASN                            EQU     $CA     ; 202
_ACS                            EQU     $CB     ; 203
_ATN                            EQU     $CC     ; 204
_LN                             EQU     $CD     ; 205
_EXP                            EQU     $CE     ; 206
_INT                            EQU     $CF     ; 207
_SQR                            EQU     $D0     ; 208
_SGN                            EQU     $D1     ; 209
_ABS                            EQU     $D2     ; 210
_PEEK                           EQU     $D3     ; 211
_USR                            EQU     $D4     ; 212
_STR                            EQU     $D5     ; 213
_CHR                            EQU     $D6     ; 214
_NOT                            EQU     $D7     ; 215
_DOUBLEASTERISK                 EQU     $D8     ; 216
_OR                             EQU     $D9     ; 217
_AND                            EQU     $DA     ; 218
_LESSTHANEQUAL                  EQU     $DB     ; 219
_GREATERTHANEQUAL               EQU     $DC     ; 220
_NOTEQUAL                       EQU     $DD     ; 221
_THEN                           EQU     $DE     ; 222
_TO                             EQU     $DF     ; 223
_STEP                           EQU     $E0     ; 224
_LPRINT                         EQU     $E1     ; 225
_LLIST                          EQU     $E2     ; 226
_STOP                           EQU     $E3     ; 227
_SLOW                           EQU     $E4     ; 228
_FAST                           EQU     $E5     ; 229
_NEW                            EQU     $E6     ; 230
_SCROLL                         EQU     $E7     ; 231
_CONT                           EQU     $E8     ; 232
_DIM                            EQU     $E9     ; 233
_REM                            EQU     $EA     ; 234
_FOR                            EQU     $EB     ; 235
_GOTO                           EQU     $EC     ; 236
_GOSUB                          EQU     $ED     ; 237
_INPUT                          EQU     $EE     ; 238
_LOAD                           EQU     $EF     ; 239
_LIST                           EQU     $F0     ; 240
_LET                            EQU     $F1     ; 241
_PAUSE                          EQU     $F2     ; 242
_NEXT                           EQU     $F3     ; 243
_POKE                           EQU     $F4     ; 244
_PRINT                          EQU     $F5     ; 245
_PLOT                           EQU     $F6     ; 246
_RUN                            EQU     $F7     ; 247
_SAVE                           EQU     $F8     ; 248
_RAND                           EQU     $F9     ; 249
_IF                             EQU     $FA     ; 250
_CLS                            EQU     $FB     ; 251
_UNPLOT                         EQU     $FC     ; 252
_CLEAR                          EQU     $FD     ; 253
_RETURN                         EQU     $FE     ; 254
_COPY                           EQU     $FF     ; 255

; ======================================================================================================================================================

; ==========
; Maze Codes
; ==========

; $00 _SPACE                            ; Empty.
; $08 _CHEQUERBOARD                     ; External wall.
; $88 _INVCHEQUERBOARD                  ; Dead end.
; $80 _BLACK                            ; Internal wall.
; $1B _FULLSTOP                         ; Trail.
; $0D _DOLLAR                           ; Exit.
; $17 _ASTERISK                         ; 'This Way'.
; $1D _1                                ; Standing.
; $1E _2                                ; Running Right 1.
; $9E _INV2                             ; Running Right 2.
; $1F _3                                ; Running Left 1.
; $9F _INV3                             ; Running Left 2.
; $20 _4                                ; Up-Down Right Leg Up.
; $A0 _INV4                             ; Up-Down Left Leg Up.
; $21 _5                                ; Holding Treasure.
; $22 _6                                ; Running Holding Treasure Right 1.
; $A2 _INV6                             ; Running Holding Treasure Right 2.
; $23 _7                                ; Running Holding Treasure Left 1.
; $A3 _INV7                             ; Running Holding Treasure Left 2.
; $24 _8                                ; Down Holding Treasure Right Leg Up.
; $A4 _INV8                             ; Down Holding Treasure Left Leg Up.
; $25 _9                                ; Up Holding Treasure Right Leg Up.
; $A5 _INV9                             ; Up Holding Treasure Left Leg Up.
; $26 _A                                ; Holding Sword.
; $27 _B                                ; Running With Sword Right 1.
; $A7 _INVB                             ; Running With Sword Right 2.
; $28 _C                                ; Running With Sword Left 1.
; $A8 _INVC                             ; Running With Sword Left 2.
; $29 _D                                ; Up-Down With Sword Left Leg Up.
; $A9 _INVD                             ; Up-Down With Sword Right Leg Up.
; $3D _X                                ; Mazog Eyes Open.
; $BD _INVX                             ; Mazog Eyes Closed.
; $39 _T                                ; Treasure 1.
; $B9 _INVT                             ; Treasure 2.
; $35 _P                                ; Prisoner Eyes Closed.
; $B5 _INVP                             ; Prisoner Eyes Open.
; $B8 _INVS                             ; Sword.
; $2B _F                                ; Fighting 1.
; $2C _G                                ; Fighting 2.
; $2D _H                                ; Fighting 3.

; ======================================================================================================================================================

; ===============
; Unused Routines
; ===============

; The following routines are never used by the game:
;
; $42A3 - Delay 0.3 Seconds.
; $43EE - Display Maze Around Player Position.
; $4929 - Toggle Maze Code.
; $4934 - Display Random Patterns.
; $5016 - Reset Re-Seed Counter.
; $50E5 - Display Moves Remaining.

; There are also numerous remnants of REM statements and NOP instructions at the start of routines.
; The NOP instructions hint at the program being hand assembled and included to allow room to make
; modifications should bugs be found or changes in functionality be required. The program is therefore
; not as compact as it could be.

; The Display Moves Remaining routine at $50E5 might imply that the original intention was to have
; the game loop always display how many moves were remaining.

; The Display Random Patterns routine at $4934 might either have been used to check how random the
; pseudo random number generator was, or perhaps an effect originally intended within the game but
; then dropped.

; The routine at $439E is used to allow the user to examine the maze. It has four entry points to
; allow the top-left, top-right, bottom-left and bottom-right quarters of the maze to be displayed.
; Toggling between the quarters might have been deemed not to provide a nice method for examining
; the route to the treasure and so the routine was re-used as a means to scroll around the maze.
; The entry point to display from the top-left point of the maze was always used and the location
; specifying the start address of the maze was simply changed from BASIC. The maze was then displayed
; as if starting from this position. This allows scrolling left or right from one row of the maze
; onto the previous or next row respectively.

; ======================================================================================================================================================

; ============
; Program Name
; ============
; The ZX81 program name consists of one or more non-inverted characters, with the last character inverted.

#ifdef MAKE_P81

        ORG  $4003

        DEFB _M
        DEFB _A
        DEFB _Z
        DEFB _O
        DEFB _G
        DEFB _S + $80

#endif

; ======================================================================================================================================================

; ================
; System Variables
; ================

ERR_NR  EQU                       16384         ; $4000
FLAGS   EQU                       16385         ; $4001
ERR_SP  EQU                       16386         ; $4002
RAMTOP  EQU                       16388         ; $4004
MODE    EQU                       16390         ; $4006
PPC     EQU                       16391         ; $4007

; The ZX81 program is saved from the following location onwards.

        ORG  $4009

VERSN:  DEFB $00                ; 16393           $4009
E_PPC:  DEFW $2328              ; 16394           $400A
D_FILE: DEFW L6F0E              ; 16396           $400C
DF_CC:  DEFW L6F0E+$0001        ; 16398           $400E
VARS:   DEFW L7227              ; 16400           $4010
DEST:   DEFW L7227+$0073        ; 16402           $4012
E_LINE: DEFW L7227+$0001        ; 16404           $4014
CH_ADD: DEFW L6F08-$0001        ; 16406           $4016
X_PTR:  DEFW $C000              ; 16408           $4018
STKBOT: DEFW L7227+$0001        ; 16410           $401A
STKEND: DEFW L7227+$0001        ; 16412           $401C
BERG:   DEFB $23                ; 16414           $401E
MEM:    DEFW MEMBOT             ; 16415           $401F
SPARE1: DEFB $00                ; 16417 - unused  $4021
DF_SZ:  DEFB $02                ; 16418           $4022
S_TOP:  DEFW $1928              ; 16419           $4023  Line 6440 is at the top of the BASIC lising
LAST_K  DEFW $FFFF              ; 16421           $4025
DBOUNC: DEFB $FF                ; 16423           $4027
MARGIN: DEFB $37                ; 16424           $4028
NXTLIN: DEFW L6F08              ; 16425           $4029  The BASIC program will auto-run from line 9020.
OLDPPC: DEFW $2332              ; 16427           $402B
FLAGX:  DEFB $00                ; 16429           $402D
STRLEN: DEFW $FA7D              ; 16430           $402E
T_ADDR: DEFW $0C8D              ; 16432           $4030
SEED:   DEFW $00EC              ; 16434           $4032
FRAMES: DEFW $EA16              ; 16436           $4034
COORDS: DEFW $0000              ; 16438           $4036
PR_CC:  DEFB $BC                ; 16440           $4038
S_POSN: DEFB $21                ; 16441           $4039
        DEFB $18                ; 16442           $403A
CDFLAG: DEFB $40                ; 16443           $403B  Temporary FAST mode.
PRBUFF: DEFW $0000, $0000       ; 16444           $403C
        DEFW $0000, $0000
        DEFW $0000, $0000
        DEFW $0000, $0000
        DEFW $0000, $0000
        DEFW $0000, $0000
        DEFW $0000, $0000
        DEFW $0000, $0000
        DEFB _NEWLINE           ; 16476           $405C
MEMBOT: DEFW $0000, $0000       ; 16477           $405D
        DEFW $8100, $0000
        DEFW $0000, $8080
        DEFW $8080, $8080
        DEFW $8080, $8080
        DEFW $8080, $9185
        DEFW $0090, $0000
        DEFW $0000
SPARE2: DEFB $00                ; 16507 - unused  $407B
SPARE3: DEFB $00                ; 16508 - unused  $407C

; ======================================================================================================================================================

; ========================================
; BASIC Line 1 - Contains the Machine Code
; ========================================

L407D:  DEFB 1 >> 8
        DEFB 1 & $FF
        DEFW L51D8 - L4081
L4081:  DEFB _REM

        DEFB _NEWLINE, _NEWLINE                 ; Hide the machine code.

; ------------------------------------------------------------------------------------------------------------------------------------------------------

; -----------------
; Program Constants
; -----------------

MAZE    EQU  $730A                              ; Address of the maze.

; -----------------
; Program Variables
; -----------------

L4084:  DEFB $E5                                ; Holds the last random 8-bit number.
L4085:  DEFB $04                                ; Holds $01, $02, $03 or $04 representing four equal chance decisions.
L4086:  DEFB _CHEQUERBOARD                      ; Holds the maze code for the external wall. Also holds the low byte of the number of moves to the treasure / exit.
L4087:  DEFB $01                                ; Holds the time to re-seed random number when generating the maze. Also used to hold the low byte of the distance count. Also holds the high byte of the number of moves to the treasure / exit.
L4088:  DEFW MAZE+$01D6                         ; Holds address of the player within the maze. Also used to hold the high byte of the distance count.
L408A:  DEFW MAZE+$0540                         ; Holds the location of the exit within the maze.
L408C:  DEFB _A                                 ; Used to note the maze code of the player location while the maze is being cleared. Also used to note the starting time when generating the maze.
L408D:  DEFW MAZE                               ; Holds the address of the maze. This is adjusted when examining the maze at the end of the game.
L408F:  DEFB _ASTERISK                          ; Holds the maze code when calculating the number of empty locations within the maze, or the distance to the treasure / exit.
L4090:  DEFB $29                                ; Holds the re-seed timer.

; ----------------------------
; Unused - Remains of REM line
; ----------------------------

L4091:  DEFB _FULLSTOP

; ------------------------------------------------
; Generate Random Number Based Upon Frames Counter
; ------------------------------------------------

L4092:  LD   A,(FRAMES)
        LD   (L4084),A                          ; Set the random number based on the frames counter.

; ------------------------
; Generate a Random Number
; ------------------------
; The pseudo random number is generated by: (Last_Random_Number * $43) + $01FD
; Exit: HL=Random number ($0000-$FFFF).
;       A=Random number ($00-$FF, the low byte of HL).

L4098:  LD   A,(L4084)                          ; Fetch the last random number.
        LD   C,A

        LD   L,A
        LD   H,$00

; Generate HL=Last_Random_Number * $40

        LD   B,$06

L40A1:  ADD  HL,HL
        DJNZ L40A1

; Generate HL=Last_Random_Number * $43

        ADD  HL,BC
        ADD  HL,BC
        ADD  HL,BC

; Generate HL=(Last_Random_Number * $43) + $01FD

        LD   BC,$01FD
        ADD  HL,BC

        LD   A,L
        LD   (L4084),A                          ; Store the new random number.
        RET  

; --------
; Not Used
; --------

L40B0:  DEFB $00, $00, $00, $00

; -------------------------
; Determine Random Decision
; -------------------------
; Exit: A=Random decision ($01=0%-25%, $02=25%-50%, $03=50%-75% or $04=75%-100%).

L40B4:  LD   A,(L4084)                          ; Fetch the current random number.
        CP   $80                                ; Is it $00-$7F?
        JP   M,L40CD                            ; Jump if so.

        CP   $C0                                ; Is it $80-$BF?
        JP   M,L40C7                            ; Jump if so.

        LD   A,$04                              ; Signal it is 75%-100%.
        LD   (L4085),A
        RET  

L40C7:  LD   A,$03                              ; Signal it is 50%-75%.
        LD   (L4085),A
        RET  

L40CD:  CP   $40                                ; Is it 0%-25%?
        JP   M,L40D8                            ; Jump if so.

        LD   A,$02                              ; Signal it is 25%-50%.
        LD   (L4085),A
        RET  

L40D8:  LD   A,$01                              ; Signal it is 0%-25%.
        LD   (L4085),A
        RET  

; --------------------
; Fetch Key Press Code
; --------------------
;
;          Bit0  Bit1  Bit2  Bit3  Bit4    Bit4  Bit3  Bit2  Bit1  Bit0
;          ----  ----  ----  ----  ----    ----  ----  ----  ----  ----
; $F7FE =    1     2     3     4     5       6     7     8     9     0   = $EFFE
; $FBFE =    Q     W     E     R     T       Y     U     I     O     P   = $DFFE
; $FDFE =    A     S     D     F     G       H     J     K     L    N/L  = $BFFE
; $FEFE =  SHIFT   Z     X     C     V       B     N     M     .   SPACE = $7FFE
;
; Exit: A=$00 if no keys are being pressed, or one of the following key codes:
;
;          Bit0  Bit1  Bit2  Bit3  Bit4    Bit4  Bit3  Bit2  Bit1  Bit0    UNSHIFTED
;          ----  ----  ----  ----  ----    ----  ----  ----  ----  ----
; $F7FE =   $0A   $0C   $10   $18   $28     $30   $20   $18   $14   $12  = $EFFE
; $FBFE =   $06   $08   $0C   $14   $24     $40   $30   $28   $24   $22  = $DFFE
; $FDFE =   $04   $06   $0A   $12   $22     $60   $50   $48   $44   $42  = $BFFE
; $FEFE =   $00   $05   $09   $11   $21     $A0   $90   $88   $84   $82  = $7FFE
;
;          Bit0  Bit1  Bit2  Bit3  Bit4    Bit4  Bit3  Bit2  Bit1  Bit0    SHIFTED
;          ----  ----  ----  ----  ----    ----  ----  ----  ----  ----
; $F7FE =   $0B   $0D   $11   $19   $29     $31   $21   $19   $15   $13  = $EFFE
; $FBFE =   $07   $09   $0D   $15   $25     $41   $31   $29   $25   $23  = $DFFE
; $FDFE =   $05   $07   $0B   $13   $23     $61   $51   $49   $45   $42  = $BFFE
; $FEFE =   $01   $06   $0A   $12   $22     $A1   $91   $89   $85   $83  = $7FFE
;
; Exit: HL=$0000 if no keys are being pressed, or one of the following key codes:
;
;          Bit0  Bit1  Bit2  Bit3  Bit4    Bit4  Bit3  Bit2  Bit1  Bit0    UNSHIFTED
;          ----  ----  ----  ----  ----    ----  ----  ----  ----  ----
; $F7FE = $0208 $0408 $0808 $1008 $2008   $2010 $1010 $0810 $0410 $0210  = $EFFE
; $FBFE = $0204 $0404 $0804 $1004 $2004   $2020 $1020 $0820 $0420 $0220  = $DFFE
; $FDFE = $0202 $0402 $0802 $1002 $2002   $2040 $1040 $0840 $0440 $0240  = $BFFE
; $FEFE = $0000 $0401 $0801 $1001 $2001   $2080 $1080 $0880 $0480 $0280  = $7FFE
;
;          Bit0  Bit1  Bit2  Bit3  Bit4    Bit4  Bit3  Bit2  Bit1  Bit0    SHIFTED
;          ----  ----  ----  ----  ----    ----  ----  ----  ----  ----
; $F7FE = $0308 $0508 $0908 $1108 $2108   $2110 $1110 $0910 $0510 $0310  = $EFFE
; $FBFE = $0304 $0504 $0904 $1104 $2104   $2120 $1120 $0920 $0520 $0320  = $DFFE
; $FDFE = $0302 $0502 $0902 $1102 $2102   $2140 $1140 $0940 $0540 $0340  = $BFFE
; $FEFE = $0100 $0501 $0901 $1101 $2101   $2180 $1180 $0980 $0580 $0380  = $7FFE

L40DE:  AND  A                                  ; Ensure the carry flag is reset for the subtraction below.
        LD   HL,$FFFF                           ; The code for no keys pressed.
        LD   BC,(LAST_K)                        ; Fetch the current key code.

; B=Column (No key=$FF; Unshifted=$FD, $FB, $F7, $EF, $DF; Shifted=$FC, $FA, $F6, $EE, $DE).
; C=Row ($FF no key, or $FE, $FD, $FB, $F7, $EF, $DF, $BF, $7F).

        SBC  HL,BC                              ; Invert the row and column codes.

; H=Column (No key: $00; Unshifted: Bit0=$02, Bit1=$04, Bit2=$08, Bit3=$10, Bit4=$20; Shifted: Bit0=$03, Bit1=$05, Bit2=$09, Bit3=$11, Bit4=$21).
; L=Row (No key: $FF; SHIFT-V=$01, A-G=$02, Q-T=$04, 1-5=$08, 6-0=$10, Y-P=$20, H-NEWLINE=$40, B-SPACE=$80).

        LD   A,H                                ; Fetch the column code.
        ADD  A,L                                ; Combine with the row code.
        RET  

; ------
; Unused
; ------

L40EB:  NOP     

; -----------------------------------
; Insert External Wall Into Maze Area
; -----------------------------------

; Insert the top external wall.

L40EC:  LD   HL,(L408D)                         ; Fetch the address of the maze.
        LD   A,(L4086)                          ; Fetch the maze code for the external wall.
        LD   (HL),A                             ; Fill the first location with the maze code for an external wall.
        LD   B,$3F                              ; Column 63.

L40F5:  INC  HL                                 ; Advance to the next column within the row.
        LD   (HL),A                             ; Fill the location with the maze code for an external wall.
        DJNZ L40F5                              ; Repeat all for columns in the row.

; Insert the right external wall.

        LD   DE,$0040                           ; There are 64 columns in the maze.
        LD   B,$2F                              ; There are 47 rows to fill.

L40FE:  ADD  HL,DE                              ; Advance to the same column within the next row.
        LD   (HL),A                             ; Fill the location with the maze code for an external wall.
        DJNZ L40FE                              ; Repeat for all rows within the maze.

; Insert the bottom external wall.

        LD   B,$3F                              ; There are 63 columns to fill.

L4104:  DEC  HL                                 ; Move to the previous column position.
        LD   (HL),A                             ; Fill the location with the maze code for an external wall.
        DJNZ L4104                              ; Repeat for all columns.

; Insert the left external wall.

        LD   B,$2E                              ; There are 46 rows to fill.

L410A:  AND  A
        SBC  HL,DE                              ; Move to the same column position within the previous row.
        LD   (HL),A                             ; Fill the location with the maze code for an external wall.
        DJNZ L410A                              ; Repeat for all rows.

        RET  

; ----------------------------
; Unused - Remains of REM line
; ----------------------------

L4111:  DEFB _FULLSTOP
        DEFB _FULLSTOP
        DEFB _FULLSTOP
        DEFB _FULLSTOP
        DEFB _FULLSTOP
        DEFB _FULLSTOP
        DEFB _FULLSTOP
        DEFB _NEWLINE

        DEFB 2 >> 8
        DEFB 2 & $FF
        DEFW $01C4
        DEFB _REM

        DEFB $00, $00

; -------------------
; Construct Maze Area
; -------------------
; This routine constructs the maze area, setting the border around it and filling all internal locations with wall maze codes.

L4120:  NOP

        LD   HL,(L408D)                         ; Fetch the address of the maze.
L4124:  LD   A,_BLACK                           ; The maze code for an internal wall (the code is changed from BASIC).
        LD   B,$30                              ; There are 48 rows in the maze.

L4128:  PUSH BC                                 ; Save the row counter.
        LD   B,$40                              ; There are 64 columns in the maze.

L412B:  LD   (HL),A                             ; Mark the maze location as filled.
        INC  HL                                 ; Advance to the next location.
        DJNZ L412B                              ; Repeat for all columns.

        POP  BC                                 ; Retrieve the row counter.
        DJNZ L4128                              ; Repeat for all rows.

        CALL L40EC                              ; Insert the external wall around the maze.
        RET  

; -------------
; Generate Maze
; -------------
; This routine generates the maze. The maze must already have been filled with internal walls, surrounded by an external wall.
; The routine creates a series of paths, with the initial path starting from the maze entrance. A direction is selected at
; random and an attempt made to progress the path in that direction. If this succeeds then a new random direction is selected
; and an attempt made to progress the path in the new direction. If the path could not be progressed in the selected direction
; then the other possible directions are checked in a fixed circular sequence of left-right-down-up until a free direction is
; found. The path is repeatedly progressed in this fashion until it is not possible to progress it further in any direction.
; When this occurs, a random location within the maze is selected to form the starting point of a new path and the process then
; continues from here. A path will be progressed in the selected direction unless it would cause it to intersect with an existing
; path. The routine will continue to attempt to route paths until a timeout of between 5.12 and 10.24 seconds expires.

L4136:  NOP

        LD   A,(FRAMES+$0001)                   ; Fetch the high byte of the frames counter.
        LD   (L408C),A                          ; Note this as the time the maze generation was started.

        LD   HL,(L4088)                         ; Fetch the player's starting location within the maze, i.e. the maze entrance.

        NOP

; Loops here to begin a new path.

L4141:  LD   (L408A),HL                         ; Store the start location of a new path (initially this will be the maze entrance).

; Loops back here after progressing the current route one position.

L4144:  CALL L4098                              ; Generate a random 8-bit number.

        LD   DE,(L408A)                         ; Fetch the current position of the path within the maze.

        CALL L40B4                              ; Split the random number into four equal ranges.

        CP   $02                                ; Was it 25%-50%?
        JR   Z,L4161                            ; Jump if it was to attempt to progress the path to the right.

        CP   $03                                ; Was it 50%-75%?
        JR   Z,L4168                            ; Jump if it was to attempt to progress the path to the down.

        CP   $04                                ; Was it 75%-100%?
        JR   Z,L416F                            ; Jump if it was to attempt to progress the path to the up.

; Attempt to progress the path to the left.

        CALL L41D6                              ; Can the path progress to the left?
        CP   $0A
        JR   Z,L4144                            ; Jump back if so to progress the path another step.

; Attempt to progress the path to the right.

L4161:  CALL L41FA                              ; Can the path progress to the right?
        CP   $0A
        JR   Z,L4144                            ; Jump back if so to progress the path another step.

; Attempt to progress the path downwards.

L4168:  CALL L421E                              ; Can the path progress downwards?
        CP   $0A
        JR   Z,L4144                            ; Jump back if so to progress the path another step.

; Attempt to progress the path upwards.

L416F:  CALL L4249                              ; Can the path progress upwards?
        CP   $0A
        JR   Z,L4144                            ; Jump back if so to progress the path another step.

; Attempt to progress the path to the left.

        CALL L41D6                              ; Can the path progress to the left?
        CP   $0A
        JR   Z,L4144                            ; Jump back if so to progress the path another step.

; Attempt to progress the path to the right.

        CALL L41FA                              ; Can the path progress to the right?
        CP   $0A
        JR   Z,L4144                            ; Jump back if so to progress the path another step.

; Attempt to progress the path downwards.

        CALL L421E                              ; Can the path progress downwards?
        CP   $0A
        JR   Z,L4144                            ; Jump back if so to progress the path another step.

; This point is reached when it is no longer possible to progress the path in any direction.

L418B:  NOP     

; Enters here to select a random location for the start of a new path.

L418C:  NOP     
        NOP     
        NOP     
        NOP     

        LD   A,(L4087)                          ; Increment the re-seed random number timer.
        INC  A
        LD   (L4087),A

        CALL Z,L4092                            ; Generate a random 8-bit number based upon the frames counter.

        LD   HL,L408C                           ; Point to the maze generation timeout.
        LD   A,(FRAMES+$0001)                   ; Fetch the initial frames counter value.
        INC  A                                  ; Allow 2 * 256 = 512 frames, i.e. 10.24 seconds. However, since the low byte of the frames count
        INC  A                                  ; might have initially been at $FF, the timeout could be as low as 5.12 seconds.
        CP   (HL)                               ; Has the maze generation timeout expired?
        JP   Z,L427F                            ; Jump ahead if so.

; The time to generate the maze has not yet expired, so select a new random position as the start of the next path.

        NOP     

        CALL L4098                              ; Generate a random 8-bit number.

        LD   HL,(L408D)                         ; Fetch the address of the maze.
        LD   BC,$0080
        ADD  HL,BC                              ; Point to the start of the third row, i.e. the first that can contain sprites other than walls.

        LD   B,$00
        LD   C,A                                ; Transfer the random number to BC.
        ADD  HL,BC
        ADD  HL,BC
        ADD  HL,BC                              ; Offset into the maze by: random_number * 3.

        LD   B,$03                              ; The loop counter for multiplying by 8.
        LD   D,$00
        LD   E,A                                ; DE=Holds the random number.

L41BC:  RL   E                                  ; Multiply the random number by 2, 4 then 8.
        RL   D
        DJNZ L41BC                              ; Repeat for all multiplications.

        ADD  HL,DE                              ; Offset into the maze by: random_number * 11;

        LD   A,_SPACE
        CP   (HL)                               ; Is the location empty?
        JP   Z,L4141                            ; Jump if the location is empty to begin a new path.

; The location is not empty, i.e. it contains an internal wall. So check for an empty location within the 6 positions to the right.
; If an empty location is found then this is used as the starting position for a new path.

        LD   B,$06                              ; There are 6 consecutive locations to check.

L41CB:  INC  HL                                 ; Advance to the next location to the right.
        CP   (HL)                               ; Is the location empty?
        JP   Z,L4141                            ; Jump if the location is empty to begin a new path.

        DJNZ L41CB                              ; Repeat the search for an empty location within the 6 consecutive locations.

; An empty location was not found near the randomly selected location so jump back to select a new random location to try.

        JP   L418C                              ; Jump back to select a new random location.

; ------
; Unused
; ------

L41D5:  NOP     

; ------------------
; Progress Path Left
; ------------------
; Entry: DE=Current path location within the maze.
; Exit : A=$0A if path was progressed to the left.

L41D6:  LD   A,_BLACK                           ; Maze code for an internal wall.

        PUSH DE
        POP  HL                                 ; Transfer the current location within the maze to HL.

        DEC  HL                                 ; Point to the location to the left.
        CP   (HL)                               ; Is there an internal wall here?
        RET  NZ                                 ; Return if not.

        DEC  HL                                 ; Is there an internal wall at the next left?
        CP   (HL)
        RET  NZ                                 ; Return if not.

        LD   BC,$0041                           ; Offset to the original column in the row below the starting position.
        ADD  HL,BC
        CP   (HL)                               ; Is there an internal wall below?
        RET  NZ                                 ; Return if not.

        LD   BC,$0080                           ; Offset to the original column in the row above the starting position.
        AND  A
        SBC  HL,BC
        CP   (HL)                               ; Is there an internal wall above?
        RET  NZ                                 ; Return if not.

; There is an internal wall above, below and the two positions to the left, i.e. progressing left will not touch another pathway.

        DEC  DE                                 ; Point to the position to the left.
        LD   A,_SPACE
        LD   (DE),A                             ; Remove the internal wall from this location.

        LD   (L408A),DE                         ; Store the new path position within the maze.

        LD   A,$0A                              ; Signal that the path was progressed.
        RET  

; ------
; Unused
; ------

L41F9:  NOP    

; -------------------
; Progress Path Right
; -------------------
; Entry: DE=Current path location within the maze.
; Exit : A=$0A if path was progressed to the right.

L41FA:  LD   A,_BLACK                           ; Maze code for an internal wall.

        PUSH DE
        POP  HL                                 ; Transfer the current location within the maze to HL.

        INC  HL                                 ; Point to the location to the right.
        CP   (HL)                               ; Is there an internal wall here?
        RET  NZ                                 ; Return if not.

        INC  HL                                 ; Is there an internal wall at the next right?
        CP   (HL)
        RET  NZ                                 ; Return if not.

        LD   BC,$003F                           ; Offset to the original column in the row below the starting position.
        ADD  HL,BC
        CP   (HL)                               ; Is there an internal wall below?
        RET  NZ                                 ; Return if not.

        LD   BC,$0080                           ; Offset to the original column in the row above the starting position.
        AND  A
        SBC  HL,BC
        CP   (HL)                               ; Is there an internal wall above?
        RET  NZ                                 ; Return if not.

; There is an internal wall above, below and the two positions to the right, i.e. progressing right will not touch another pathway.

        INC  DE                                 ; Point to the position to the right.
        LD   A,_SPACE
        LD   (DE),A                             ; Remove the internal wall from this location.

        LD   (L408A),DE                         ; Store the new path position within the maze.

        LD   A,$0A                              ; Signal that the path was progressed.
        RET  

; ------
; Unused
; ------

L421D:  NOP     

; -----------------------
; Progress Path Downwards
; -----------------------
; Entry: DE=Current path location within the maze.
; Exit : A=$0A if path was progressed downwards.

L421E:  LD   A,_BLACK                           ; Maze code for an internal wall.

        PUSH DE
        POP  HL                                 ; Transfer the current location within the maze to HL.

        LD   BC,$0041                           ; Offset to the column to the left in the row above.
        AND  A
        SBC  HL,BC
        CP   (HL)                               ; Is there an internal wall?
        RET  NZ                                 ; Return if not.

        INC  HL
        CP   (HL)                               ; Is there an internal wall in the original column in the row above?
        RET  NZ                                 ; Return if not.

        INC  HL
        CP   (HL)                               ; Is there an internal wall to the column to the right in the row above?
        RET  NZ                                 ; Return if not.

        LD   BC,$0041                           ; Offset to the original column in the next row above.
        AND  A
        SBC  HL,BC
        CP   (HL)                               ; Is there an internal wall?
        RET  NZ                                 ; Return if not.

; There is an internal wall above-left, above-right, immediately above for the next two rows.

        EX   DE,HL                              ; Restore the original position to HL.
        LD   BC,$0040
        AND  A
        SBC  HL,BC                              ; Point to the same column in the row above.

        LD   A,_SPACE
        LD   (HL),A                             ; Remove the internal wall from this location.

        LD   (L408A),HL                         ; Store the new path position within the maze.

        LD   A,$0A                              ; Signal that the path was progressed.
        RET  

; ------
; Unused
; ------

L4248:  NOP     

; ---------------------
; Progress Path Upwards
; ---------------------
; Entry: DE=Current path location within the maze.
; Exit : A=$0A if path was progressed upwards.

L4249:  LD   A,_BLACK                           ; Maze code for an internal wall.

        PUSH DE
        POP  HL                                 ; Transfer the current location within the maze to HL.

        LD   BC,$003F                           ; Offset to the column to the left in the row below.
        ADD  HL,BC
        CP   (HL)                               ; Is there an internal wall?
        RET  NZ                                 ; Return if not.

        INC  HL
        CP   (HL)                               ; Is there an internal wall in the original column in the row below?
        RET  NZ                                 ; Return if not.

        INC  HL
        CP   (HL)                               ; Is there an internal wall to the column to the right in the row below?
        RET  NZ                                 ; Return if not.

        LD   BC,$003F                           ; Offset to the original column in the next row below.
        ADD  HL,BC
        CP   (HL)                               ; Is there an internal wall?
        RET  NZ                                 ; Return if not.

; There is an internal wall below-left, below-right, immediately below for the next two rows.

        EX   DE,HL                              ; Restore the original position to HL.
        LD   BC,$0040
        ADD  HL,BC                              ; Point to the same column in the row below.

        LD   A,_SPACE
        LD   (HL),A                             ; Remove the internal wall from this location.

        LD   (L408A),HL                         ; Store the new path position within the maze.

        LD   A,$0A                              ; Signal that the path was progressed.
        RET  

; -----------------
; Delay 0.3 Seconds
; -----------------
; T-states = 93346 => 0.2872 seconds.

L426D:  NOP                                     ; 4

        LD   B,$FF                              ; 7     Outer delay loop count.

; Outer loop = 93325 T-states.

L4270:  PUSH BC                                 ; 11    Save the outer delay loop count.

        LD   B,$0A                              ; 7     Inner delay loop count.

; Inner loop = 325 T-states.

L4273:  NOP                                     ; 4     Loop iteration delay = (33*10)-5 = 325.
        NOP                                     ; 4     
        NOP                                     ; 4
        NOP                                     ; 4
        NOP                                     ; 4
        DJNZ L4273                              ; 13/8  Repeat the inner delay.

        POP  BC                                 ; 10    Retrieve the outer delay loop count.
        DJNZ L4270                              ; 13/8  Repeat the outer delay.

        RET  

; ------
; Unused
; ------

L427E:  NOP     

; --------------------------------
; Maze Generation Timeout Occurred
; --------------------------------

L427F:  LD   A,_SPACE                           ; Maze code for an empty location.
        LD   (L408F),A                          ; Set the maze code used when calculating the number of empty locations within the maze.

; -------------------------------------------------------------
; Calculate Number of Locations, or Distance to Treasure / Exit
; -------------------------------------------------------------
; The routine is entered from above and is used to determine how many empty locations there are in the maze,
; which is then used by BASIC to check whether there are a sufficient number of movement possibilities.
; The routine is also called from BASIC to calculate the number of locations to reach the treasure or exit.
; The route is first populated with 'This Way' codes and then this routine used to count how many 'This Way'
; codes there are. This yields the distance.

L4284:  LD   A,(L408F)                          ; Fetch the route maze code.
        LD   HL,(L408D)                         ; Fetch the address of the maze.
        LD   DE,$0000                           ; The distance count.
        LD   B,$2E                              ; The number of rows in the maze, excluding the bottom internal and external walls.

L428F:  PUSH BC                                 ; Save the maze row counter.

        LD   B,$40                              ; The number of columns in the maze.

L4292:  CP   (HL)                               ; Is this location part of the route?
        JR   NZ,L4296                           ; Jump ahead if not.

        INC  DE                                 ; This location is part of the route so increment the distance count.

L4296:  INC  HL                                 ; Advance to the next maze location.
        DJNZ L4292                              ; Repeat for all columns within the current row.

        POP  BC                                 ; Retrieve the maze row counter.
        DJNZ L428F                              ; Repeat for all rows in the maze.

        LD   (L4086),DE                         ; Store the number of moves to the treasure / exit.
        RET  

; ------
; Unused
; ------

L42A2:  DEFB $C9, $C9

; ----------------------------
; Delay 0.3 Seconds (Not Used)
; ----------------------------
; T-states = 93346 => 0.2872 seconds.
; This is a duplicate of the routine at $426D.

L42A4:  NOP     

L42A5:  LD   B,$FF                              ; Outer delay loop count.

; Delay = (255 * (11 + 7 + 325 + 10 + 13) ) - 5 = 93325.

L42A6:  PUSH BC                                 ; Save the outer delay loop count.

        LD   B,$0A                              ; Inner delay loop count.

L42A9:  NOP                                     ; Loop iteration delay = (33*10)-5 = 325.
        NOP     
        NOP     
        NOP     
        NOP     
        DJNZ L42A9                              ; Repeat the inner delay.

        POP  BC                                 ; Retrieve the outer delay loop count.
        DJNZ L42A6                              ; Repeat the outer delay.

        RET  

; ----------------------------
; Unused - Remains of REM line
; ----------------------------

L42B4:  DEFB _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP
        DEFB _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP
        DEFB _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP
        DEFB _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP
        DEFB _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP
        DEFB _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP
        DEFB _NEWLINE

        DEFB 3 >> 8
        DEFB 3 & $FF
        DEFW $013C
        DEFB _REM
        DEFB _FULLSTOP, _FULLSTOP

; -----------------------------------------
; Clear Maze of Mazogs, Trails, 'This Way's
; -----------------------------------------

L42E8:  LD   HL,(L4088)                         ; Fetch the address of the player within the maze.
        LD   A,(HL)                             ; Fetch the maze code at the player location.
        LD   (L408C),A                          ; Save it.

        LD   HL,(L408D)                         ; Fetch the address of the maze.
        LD   B,$30                              ; There are 48 rows in the maze.

L42F4:  PUSH BC                                 ; Save the row counter.
        LD   B,$40                              ; There are 64 columns in the maze.

L42F7:  LD   A,(HL)                             ; Fetch the maze code from the current maze location.
        CP   _FULLSTOP                          ; Trail?
        JR   Z,L430A                            ; Jump ahead if so to erase the maze code.

        CP   _ASTERISK                          ; 'This Way'?
        JR   Z,L430A                            ; Jump ahead if so to erase the maze code.

        CP   _X                                 ; Mazog with eyes open?
        JR   Z,L430A                            ; Jump ahead if so to erase the maze code.

        CP   _INVX                              ; Mazog with eyes closed?
        JR   Z,L430A                            ; Jump ahead if so to erase the maze code.

        JR   L430C                              ; Jump ahead to leave the maze code unaltered.

L430A:  LD   (HL),_SPACE                        ; Erase the maze code.

L430C:  INC  HL                                 ; Advance to the next maze location.
        DJNZ L42F7                              ; Repeat for all columns within this row.

        POP  BC                                 ; Retrieve the row counter.
        DJNZ L42F4                              ; Repeat for all rows.

        RET  

; ---------------------------------------------------
; Populate the Maze with Route to the Treasure / Exit
; ---------------------------------------------------
; This routine cleverly determines the route to the treasure, or if the player has already collected the treasure then it
; will determine the route to the exit. It first searches around the player's location for the treasure #1 maze code. If this
; is not found then it searches for treasure #2 maze code. If this is not found then it searches for the exit maze code (which
; will only ever be in the maze once the player has collected the treasure). If the exit is not found then it searches for an
; empty location. If an empty location is found then it is replaced with 'This Way'. The search is now repeated from this new
; location. As each empty location is found it is replaced with 'This Way'. This continues until either the treasure / exit is
; found or there is no empty location found, i.e. a dead end was reached. When a dead end is reached, a search is now made for
; 'This Way' and replaced with a special 'Dead End' maze code. If an empty location is found adjacent to the 'Dead End'
; location then it is explored. If an empty location is not found then there must be another 'This Way' that lead to this location
; originally and so it is now replaced with 'Dead End'. The net result is that all dead ends are back-tracked and labelled as
; dead ends. This leaves only those 'This Way' codes that form part of the actual route to the treasure or exit (as appropriate).
; Once the route to the treasure / exit has been established, all 'Dead End' codes are replaced as empty locations to leave just
; the route through the maze in place.

L4313:  LD   HL,(L4088)                         ; Fetch the address of the player within the maze.

; Enter a loop to search for treasure #1 maze code at the current location.

L4316:  LD   A,_T                               ; Maze code for the treasure.

        PUSH HL
        POP  DE                                 ; Save the current location.

; Enter a loop to search for a specific maze code (treasure #1, treasure #2, exit, empty location or 'This Way') at the current location.

L431A:  DEC  HL                                 ; Point to the location to the left.
        CP   (HL)                               ; Is there the maze code to the left?
        JR   Z,L4359                            ; Jump if there is.

; The maze code is not to the left.

        INC  HL                                 ; Point to the location to the right.
        INC  HL
        CP   (HL)                               ; Is there the maze code to the right?
        JR   Z,L4359                            ; Jump if there is.

; The maze code is not to the right.

        LD   BC,$003F                           ; Width of the maze - 1 (which combines with the increment done above).
        ADD  HL,BC                              ; Point to the location below.
        CP   (HL)                               ; Is there the maze code below?
        JR   Z,L4359                            ; Jump if there is.

; The maze code is not below.

        AND  A
        LD   BC,$0080                           ; Point to the location above.
        SBC  HL,BC
        CP   (HL)                               ; Is there the maze code above?
        JR   Z,L4359                            ; Jump if there is.

; The maze code is not above.

        NOP     

        PUSH DE
        POP  HL                                 ; Retrieve the original location.

        CP   _T                                 ; Searching for treasure #1?
        JR   Z,L4350                            ; Jump if so.

        CP   _INVT                              ; Searching for treasure #2?
        JR   Z,L4348                            ; Jump if so.

        CP   _DOLLAR                            ; Searching for the exit?
        JR   Z,L434C                            ; Jump if so.

        CP   _SPACE                             ; Searching for an empty location?
        JR   Z,L4354                            ; Jump if so.

; Was searching for 'This Way' but failed to find it. Must be at the exit.

        JR   L4377                              ; Jump ahead to continue.

; Failed to find treasure #2 at the current location so examine the location for the exit.

L4348:  LD   A,_DOLLAR                          ; Exit maze code.
        JR   L431A                              ; Loop back to search for the exit.

; Failed to find the exit at the current location so examine whether the location is empty.

L434C:  LD   A,_SPACE                           ; Empty maze code.
        JR   L431A                              ; Loop back to search for an empty location.

; Failed to find treasure #1 at the current location so examine the location for treasure #2.

L4350:  LD   A,_INVT                            ; Treasure #2 maze code.
        JR   L431A                              ; Loop back to search for the treasure #2.

; Failed to find an empty location so examine the location for 'This Way'.

L4354:  LD   A,_ASTERISK                        ; 'This Way' maze code.
        JR   L431A                              ; Loop back to search for 'This Way'.

L4358:  NOP     

; Joins here when the required maze code is to the left, right, above or below.

L4359:  CP   _T                                 ; Searching for treasure #1?
        JR   Z,L4377                            ; Jump ahead if so.

        CP   _INVT                              ; Searching for treasure #2?
        JR   Z,L4377                            ; Jump ahead if so.

        CP   _DOLLAR                            ; Searching for the exit?
        JR   Z,L4377                            ; Jump ahead if so.

        CP   _SPACE                             ; Searching for an empty location?
        JR   Z,L436D                            ; Jump ahead if so.

        CP   _ASTERISK                          ; Searching for 'This Way'?
        JR   Z,L4372                            ; Jump ahead if so.

; An empty location was found to the left, right, above or below.

L436D:  LD   A,_ASTERISK                        ; 'This Way'.
        LD   (DE),A

        JR   L4316                              ; Jump back to examine the find the next location.

; 'This Way' was found to the left, right, above or below. The search will always favour an empty location and so
; if an empty location was not found but a 'This Way' was found then it means that a dead end was reached. The
; search is then back-tracked along the route that was previously followed. The location is marked as a dead end,
; which eventually will leave only those 'This Way' entries that form part of the route.

L4372:  LD   A,_INVCHEQUERBOARD                 ; Mark as a dead end.
        LD   (DE),A

        JR   L4316                              ; Jump back to examine the find the next location.

; Reached the treasure #1, treasure #2 or exit. The exit will only be in the maze after the player has collected the treasure
; and so will not be found when searching for the treasure.

L4377:  LD   A,_ASTERISK                        ; Insert 'This Way' at the current maze location.
        LD   (DE),A

; Now remove all dead end markers and replace with empty locations. This will leave 'This Way' markers along the route to the
; treasure or exit.

        LD   A,(L408C)                          ; Fetch the maze code of the player.
        LD   HL,(L4088)                         ; Fetch the address of the player within the maze.
        LD   (HL),A                             ; Restore it in the maze.

        LD   HL,(L408D)                         ; Fetch the address of the maze.
        LD   B,$30                              ; There are 48 rows in the maze.

L4386:  PUSH BC                                 ; Save the row counter.
        LD   B,$40                              ; There are 64 columns in the maze.

L4389:  LD   A,(HL)                             ; Fetch the maze code at the current location.
        CP   _INVCHEQUERBOARD                   ; Does it mark a dead end?
        JR   Z,L4390                            ; Jump ahead if so.

        JR   L4392                              ; Jump ahead to continue with the next column.

L4390:  LD   (HL),_SPACE                        ; Replace the dead end with an empty location.

L4392:  INC  HL                                 ; Advance to the next column position.
        DJNZ L4389                              ; Repeat for all columns within this row of the maze.

        POP  BC                                 ; Retrieve the row count.
        DJNZ L4386                              ; Repeat for all rows in the maze.

        RET  

; ------
; Unused
; ------

L4399:  DEFB _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP

; ---------------------------------
; Draw the Maze to the Display File
; ---------------------------------
; This routine is used when examining the maze at the end of a game.
; The maze is 4 times the size of the display. The following routine appears to have been originally intended to statically show one
; of the quarters of the maze. It fetches the address of the maze and then applies an offset to point to the selected quarter.
; However, only the entry point that shows the top-left quarter is ever called. It appears that flipping between the quarters was deemed
; not to provide a nice way to browse the maze and so instead the routine was re-used to allow scrolling through the maze. The offset
; was fixed at $0000 and the BASIC program simply adjusts the starting position within the maze from which to perform the copy into the
; display file. This allows the transition between maze rows to be displayed on the same row of the display file.

L439E:  LD   HL,(L408D)                         ; Fetch the address of the top-left position shown within the maze.
        LD   BC,$0000                           ; Offset to the top-left quarter of the maze (1st row within the maze).
        JR   L43BC                              ; Jump ahead to continue.

; Display bottom-left quarter of the maze - Entry point never used.

L4406:  LD   HL,(L408D)                         ; Fetch the address of the maze.
        LD   BC,$0600                           ; Offset to the bottom-left quarter of the maze (24th row within the maze).
        JR   L43BC                              ; Jump ahead to continue.

; Display top-right quarter of the maze - Entry point never used.

L440E:  LD   HL,(L408D)                         ; Fetch the address of the maze.
        LD   BC,$0020                           ; Offset to the top-right quarter of the maze (32nd column within the maze).
        JR   L43BC                              ; Jump ahead to continue.

; Display bottom-right quarter of the maze - Entry point never used.

L4416:  LD   HL,(L408D)                         ; Fetch the address of the maze.
        LD   BC,$0620                           ; Offset to the bottom-right quarter of the maze (24th row and 32nd column within the maze).

; All entry points converge here.
; HL=Address of the top-left position within the maze to display.
; BC=Offset into the maze (which will always be $0000).

L43BC:  ADD  HL,BC                              ; Offset into the maze.

        LD   DE,(D_FILE)                        ; Fetch the address of the display file.
        INC  DE                                 ; Advance past the initial newline.

        LD   B,$18                              ; There are 24 rows in the display.

L43C4:  PUSH BC                                 ; Save the row count.

        LD   BC,$0020                           ; There are 32 columns in the display.
        LDIR                                    ; Copy a row of maze codes into the display.

        INC  DE                                 ; Advance past the end of row terminator in the display file.

        LD   BC,$0020                           ; Advance to the starting column in the row below of the maze.
        ADD  HL,BC

        POP  BC                                 ; Retrieve the row count.

        DJNZ L43C4                              ; Repeat for all rows in the display.

        RET  

; ------
; Unused
; ------

L43D3:  DEFB _FULLSTOP, _FULLSTOP

; -----------
; Fill Screen
; -----------
; This routine is used to fill the screen with inverse chequerboard or black.
; The character to fill the screen with is poked into $43DA from BASIC before
; the routine is called.

L43D5:  LD   HL,(D_FILE)                        ; Fetch the address of the display file.
        INC  HL                                 ; Advance past the initial 'end-of-line' character.
L43D9:  LD   A,_INVCHEQUERBOARD                 ; The code to fill the screen with (set from BASIC).
        LD   B,$18                              ; There are 24 rows.

L43DD:  PUSH BC                                 ; Save the row counter.
        LD   B,$20                              ; There are 32 columns per row.

L43E0:  LD   (HL),A                             ; Fill the cell within the display file.
        INC  HL                                 ; Advance to the next column within this row.
        DJNZ L43E0                              ; Repeat for all columns within this row.

        INC  HL                                 ; Skip over the end-of-line terminator.
        POP  BC                                 ; Retrieve the row counter.
        DJNZ L43DD                              ; Repeat for all rows.

        RET  

; ------
; Unused
; ------

L43E9:  DEFB $00, $00, $00, $00, $00   

; ----------------------------------------------
; Display Maze Around Player Position (Not Used)
; ----------------------------------------------
; This routine displays a 16 by 16 grid of the maze centred around the position of the player.
; It does not take into account the fact that the player might be close to the edge of the maze and hence
; locations outside the maze need to be handled. A more sophisticated version exists at $517C that
; resolves this problem and is used when displaying a View.

L43EE:  LD   HL,(D_FILE)                        ; Fetch the address of the display file.

        LD   BC,$008D                           ; Offset to row 4, column 8 within the display file.
        ADD  HL,BC

        PUSH HL
        POP  DE                                 ; Transfer the display file address to DE.

        LD   HL,(L4088)                         ; Fetch the address of the player within the maze.
        LD   BC,$0207                           ; Offset up 8 rows and 7 columns.
        AND  A
        SBC  HL,BC

        LD   B,$10                              ; There are 16 rows of the maze to display.

L4402:  PUSH BC                                 ; Save the row count.

        LD   BC,$0010                           ; There are 16 columns to display.
        LDIR                                    ; Copy the columns of the current row in the maze into the display file.

        PUSH HL                                 ; Save the address within the maze.

        PUSH DE
        POP  HL                                 ; Transfer the display file address to HL.

        LD   BC,$0011                           ; Offset to the starting column within the display file.
        ADD  HL,BC

        PUSH HL
        POP  DE                                 ; Transfer the display file address to DE.

        POP  HL                                 ; Retrieve the address within the maze.

        LD   BC,$0030                           ; Offset to the column to display from within the next row.
        ADD  HL,BC

        POP  BC                                 ; Retrieve the row count.
        DJNZ L4402                              ; Repeat for all rows to display.

        RET  

; ----------------------------
; Unused - Remains of REM line
; ----------------------------

L441A:  DEFB _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP
        DEFB _NEWLINE

        DEFB 4 >> 8
        DEFB 4 & $FF
        DEFW $01DC
        DEFB _REM

        DEFB _X, _X
        DEFB _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP
        DEFB _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP
        DEFB _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP

; ------------------------------------------------------------------------------------------------------------------------------------------------------

; =======
; Sprites
; =======

; |            |
; |     ##     |
; |     ##     |
; |   ######   |
; |   # ## #   |
; |   # ## #   |
; |    ####    |
; |    #  #    |
; |    #  #    |
; |   ##  ##   |

L443E:  DEFB $00, $00, $87, $04, $00, $00
        DEFB $00, $87, $81, $82, $04, $00
        DEFB $00, $85, $85, $05, $05, $00
        DEFB $00, $00, $07, $84, $00, $00
        DEFB $00, $87, $05, $85, $04, $00

; |            |
; |     ##     |
; |     ##     |
; |   ######   |
; |   # ## #   |
; |   # ## #   |
; |    ####    |
; |    #  ##   |
; |    #       |
; |   ##       |

L445C:  DEFB $00, $00, $87, $04, $00, $00
        DEFB $00, $87, $81, $82, $04, $00
        DEFB $00, $85, $85, $05, $05, $00
        DEFB $00, $00, $07, $84, $04, $00
        DEFB $00, $87, $05, $00, $00, $00

; |            |
; |     ##     |
; |     ##     |
; |   ######   |
; |   # ## #   |
; |   # ## #   |
; |    ####    |
; |   ##  #    |
; |       #    |
; |       ##   |

L447A:  DEFB $00, $00, $87, $04, $00, $00
        DEFB $00, $87, $81, $82, $04, $00
        DEFB $00, $85, $85, $05, $05, $00
        DEFB $00, $87, $07, $84, $00, $00
        DEFB $00, $00, $00, $85, $04, $00

; |            |
; |      ##    |
; |      ##    |
; |   ####     |
; |   # ####   |
; |   # ##     |
; |    #####   |
; |    #   #   |
; |  ###   ##  |
; |  #         |

L4498:  DEFB $00, $00, $00, $83, $00, $00
        DEFB $00, $87, $83, $07, $00, $00
        DEFB $00, $85, $85, $07, $01, $00
        DEFB $00, $00, $07, $03, $05, $00
        DEFB $00, $07, $01, $00, $03, $00

; |            |
; |      ##    |
; |      ##    |
; |     ##     |
; |     ##     |
; |     ##     |
; |     ##     |
; |   ####     |
; |   # #      |
; |     ##     |

L44B6:  DEFB $00, $00, $00, $83, $00, $00
        DEFB $00, $00, $87, $07, $00, $00
        DEFB $00, $00, $85, $05, $00, $00
        DEFB $00, $87, $81, $05, $00, $00
        DEFB $00, $02, $85, $04, $00, $00

; |            |
; |    ##      |
; |    ##      |
; |     ####   |
; |   #### #   |
; |     ## #   |
; |   #####    |
; |   #   #    |
; |  ##   ###  |
; |         #  |

L44D4:  DEFB $00, $00, $83, $00, $00, $00
        DEFB $00, $00, $84, $83, $04, $00
        DEFB $00, $02, $84, $05, $05, $00
        DEFB $00, $85, $03, $84, $00, $00
        DEFB $00, $03, $00, $02, $84, $00

; |            |
; |    ##      |
; |    ##      |
; |     ##     |
; |     ##     |
; |     ##     |
; |     ##     |
; |     ####   |
; |     #  #   |
; |    ##      |

L44F2:  DEFB $00, $00, $83, $00, $00, $00
        DEFB $00, $00, $84, $04, $00, $00
        DEFB $00, $00, $85, $05, $00, $00
        DEFB $00, $00, $85, $82, $04, $00
        DEFB $00, $00, $81, $00, $01, $00

; |            |
; | ### ###////|
; | #####      |
; |   ###      |
; |    ###     |
; |    # ####  |
; |  ### #  #  |
; |      #  ## |
; |    ###     |
; |    #       |

L4510:  DEFB $87, $83, $87, $83, $09, $09
        DEFB $02, $84, $80, $00, $00, $00
        DEFB $00, $00, $07, $82, $83, $00
        DEFB $00, $03, $01, $05, $85, $04
        DEFB $00, $00, $07, $01, $00, $00

; |            |
; |  ////## ## |
; |       # ## |
; |   ######## |
; |   #   ###  |
; |   # ### #  |
; |  ## #   #  |
; |     # ###  |
; |     #      |
; |    ##      |

L452E:  DEFB $00, $09, $09, $83, $87, $04
        DEFB $00, $87, $83, $81, $81, $05
        DEFB $00, $85, $87, $81, $84, $00
        DEFB $00, $03, $85, $87, $81, $00
        DEFB $00, $00, $81, $00, $00, $00

; |            |
; |   ###////  |
; |    #       |
; |    # ##    |
; |    # ##    |
; |    ###     |
; |     ###### |
; | ######## # |
; | #      # # |
; |##      ##  |

L454C:  DEFB $00, $87, $83, $09, $09, $00
        DEFB $00, $00, $05, $83, $00, $00
        DEFB $00, $00, $82, $07, $00, $00
        DEFB $87, $83, $81, $80, $07, $05
        DEFB $81, $00, $00, $00, $82, $01

; |            |
; |    ##      |
; |    ##      |
; | ########   |
; | #//\\//#   |
; | #//\\//#   |
; |   ####     |
; |   #  #     |
; |   #  #     |
; |  ##  ##    |

L456A:  DEFB $00, $00, $83, $00, $00, $00
        DEFB $87, $83, $80, $83, $04, $00
        DEFB $85, $08, $88, $08, $05, $00
        DEFB $00, $85, $03, $05, $00, $00
        DEFB $00, $81, $00, $82, $00, $00

; |            |
; |    ##      |
; |    ##      |
; |    # //    |
; |    ####    |
; |    ##\\    |
; |   #####    |
; |   #   #    |
; | ###   ##   |
; | #          |

L4588:  DEFB $00, $00, $83, $00, $00, $00
        DEFB $00, $00, $07, $09, $00, $00
        DEFB $00, $00, $80, $89, $00, $00
        DEFB $00, $85, $03, $84, $00, $00
        DEFB $85, $03, $00, $02, $01, $00

; |            |
; |    ##      |
; |    ##      |
; |    # //    |
; |    ####    |
; |    ##\\    |
; |    ##      |
; |  ####      |
; |  # #       |
; |    ##      |

L45A6   DEFB $00, $00, $83, $00, $00, $00
        DEFB $00, $00, $07, $09, $00, $00
        DEFB $00, $00, $80, $89, $00, $00
        DEFB $00, $83, $80, $00, $00, $00
        DEFB $00, $01, $82, $00, $00, $00

; |            |
; |    ##      |
; |    ##      |
; |  // #      |
; |  ####      |
; |  \\##      |
; |  #####     |
; |  #   #     |
; | ##   ###   |
; |        #   |

L45C4:  DEFB $00, $00, $83, $00, $00, $00
        DEFB $00, $09, $84, $00, $00, $00
        DEFB $00, $89, $80, $00, $00, $00
        DEFB $00, $07, $03, $05, $00, $00
        DEFB $02, $01, $00, $03, $05, $00

; |            |
; |    ##      |
; |    ##      |
; |  // #      |
; |  ####      |
; |  \\##      |
; |    ##      |
; |    ####    |
; |     # #    |
; |    ##      |

L45E2:  DEFB $00, $00, $83, $00, $00, $00
        DEFB $00, $09, $84, $00, $00, $00
        DEFB $00, $89, $80, $00, $00, $00
        DEFB $00, $00, $80, $83, $00, $00
        DEFB $00, $00, $81, $02, $00, $00

; ----------------------------
; Unused - Remains of REM line
; ----------------------------

L4600:  DEFB _NEWLINE

        DEFB 5 >> 8
        DEFB 5 & $0FF
        DEFW $01CB
        DEFB _REM

        DEFB _X, _X
        DEFB _FULLSTOP, _FULLSTOP 

; --------------
; Sprites (Cont)
; --------------

; |            |
; |    ##      |
; |    ##      |
; | ########   |
; | #//\\//#   |
; |  //\\//    |
; |   ####     |
; |   #  ##    |
; |   #        |
; |  ##        |

L460A:  DEFB $00, $00, $83, $00, $00, $00
        DEFB $87, $83, $80, $83, $04, $00
        DEFB $02, $08, $88, $08, $01, $00
        DEFB $00, $85, $03, $82, $00, $00
        DEFB $00, $81, $00, $00, $00, $00

; |            |
; |    ##      |
; |    ##      |
; | ########   |
; | #\\//\\#   |
; |  \\//\\    |
; |   ####     |
; |  ##  #     |
; |      #     |
; |      ##    |

L4628:  DEFB $00, $00, $83, $00, $00, $00
        DEFB $87, $83, $80, $83, $04, $00
        DEFB $02, $88, $08, $88, $01, $00
        DEFB $00, $81, $03, $05, $00, $00
        DEFB $00, $00, $00, $82, $00, $00

; |            |
; |    ##      |
; |    ##      |
; | ########   |
; | #//##//#   |
; | #//##//#   |
; |   ####     |
; |   #  ##    |
; |   #        |
; |  ##        |

L4646:  DEFB $00, $00, $83, $00, $00, $00
        DEFB $87, $83, $80, $83, $04, $00
        DEFB $85, $08, $80, $08, $05, $00
        DEFB $00, $85, $03, $82, $00, $00
        DEFB $00, $81, $00, $00, $00, $00

; |            |
; |    ##      |
; |    ##      |
; | ########   |
; | #\\##\\#   |
; | #\\##\\#   |
; |   ####     |
; |  ##  #     |
; |      #     |
; |      ##    |

L4664:  DEFB $00, $00, $83, $00, $00, $00
        DEFB $87, $83, $80, $83, $04, $00
        DEFB $85, $88, $80, $88, $05, $00
        DEFB $00, $81, $03, $05, $00, $00
        DEFB $00, $00, $00, $82, $00, $00

; |   #    #   |
; | ##      ## |
; | #   ##   # |
; | ########## |
; |    ####    |
; |    #@@#    |
; |   ######   |
; |  #  ##  #  |
; |  ##    ##  |
; |            |

L4682:  DEFB $87, $06, $00, $00, $86, $04
        DEFB $85, $83, $81, $82, $83, $05
        DEFB $00, $00, $9B, $9B, $00, $00
        DEFB $00, $06, $84, $07, $86, $00
        DEFB $00, $03, $00, $00, $03, $00

; |            |
; |  ##    ##  |
; |  #  ##  #  |
; |   ######   |
; |    ####    |
; |    ####    |
; | ########## |
; | #   ##   # |
; | ##      ## |
; |   #    #   |

L46A0:  DEFB $00, $83, $00, $00, $83, $00
        DEFB $00, $86, $81, $82, $06, $00
        DEFB $00, $00, $80, $80, $00, $00
        DEFB $85, $03, $84, $07, $03, $05
        DEFB $02, $86, $00, $00, $06, $01

; |####//######|
; |####//######|
; |############|
; |############|
; |//########//|
; |//########//|
; |############|
; |############|
; |######//####|
; |######//####|

L46BE:  DEFB $80, $80, $08, $80, $80, $80
        DEFB $80, $80, $80, $80, $80, $80
        DEFB $08, $80, $80, $80, $80, $08
        DEFB $80, $80, $80, $80, $80, $80
        DEFB $80, $80, $80, $08, $80, $80

; |####//######|
; |############|
; |############|
; |############|
; |//########//|
; |//##@##@##//|
; |############|
; |############|
; |######//####|
; |######//####|

L46DC:  DEFB $80, $80, $08, $80, $80, $80
        DEFB $80, $80, $80, $80, $80, $80
        DEFB $08, $80, $9B, $9B, $80, $08
        DEFB $80, $80, $80, $80, $80, $80
        DEFB $80, $80, $80, $08, $80, $80

; |            |
; |            |
; |            |
; |            |
; |            |
; |            |
; |            |
; |            |
; |            |
; |            |

L46FA:  DEFB $00, $00, $00, $00, $00, $00
        DEFB $00, $00, $00, $00, $00, $00
        DEFB $00, $00, $00, $00, $00, $00
        DEFB $00, $00, $00, $00, $00, $00
        DEFB $00, $00, $00, $00, $00, $00

; |############|
; |############|
; |##\/\/\/\/##|
; |##/\/\/\/\##|
; |##\/\/\/\/##|
; |##/\/\/\/\##|
; |##\/\/\/\/##|
; |##/\/\/\/\##|
; |############|
; |############|

L4718:  DEFB $80, $80, $80, $80, $80, $80
        DEFB $80, $BD, $BD, $BD, $BD, $80
        DEFB $80, $BD, $BD, $BD, $BD, $80
        DEFB $80, $BD, $BD, $BD, $BD, $80
        DEFB $80, $80, $80, $80, $80, $80

; |            |
; |            |
; |            |
; |            |
; |            |
; |    .  .    |
; |            |
; |            |
; |            |
; |            |

L4736:  DEFB $00, $00, $00, $00, $00, $00
        DEFB $00, $00, $00, $00, $00, $00
        DEFB $00, $00, $1B, $1B, $00, $00
        DEFB $00, $00, $00, $00, $00, $00
        DEFB $00, $00, $00, $00, $00, $00

; |            |
; |            |
; |  T H I S   |
; |            |
; |            |
; |            |
; |    W A Y   |
; |            |
; |            |
; |            |

L4754:  DEFB $00, $00, $00, $00, $00, $00
        DEFB $00, $39, $2D, $2E, $38, $00
        DEFB $00, $00, $00, $00, $00, $00
        DEFB $00, $00, $3C, $26, $3E, $00
        DEFB $00, $00, $00, $00, $00, $00

; |**##**##**##|
; |**##**##**##|
; |##**##**##**|
; |##**##**##**|
; |**##//\\//##|
; |**##//\\//##|
; |##**##**##**|
; |##**##**##**|
; |**##**##**##|
; |**##**##**##|

L4772:  DEFB $97, $80, $97, $80, $97, $80
        DEFB $80, $97, $80, $97, $80, $97
        DEFB $97, $80, $08, $88, $08, $80
        DEFB $80, $97, $80, $97, $80, $97
        DEFB $97, $80, $97, $80, $97, $80

; |##**##**##**|
; |##**##**##**|
; |**##**##**##|
; |**##**##**##|
; |##**\\//\\**|
; |##**\\//\\**|
; |**##**##**##|
; |**##**##**##|
; |##**##**##**|
; |##**##**##**|

L4790:  DEFB $80, $97, $80, $97, $80, $97
        DEFB $97, $80, $97, $80, $97, $80
        DEFB $80, $97, $88, $08, $88, $97
        DEFB $97, $80, $97, $80, $97, $80
        DEFB $80, $97, $80, $97, $80, $97

; |####    ####|
; |####    ####|
; |##        ##|
; |            |
; |        #   |
; |  ////####  |
; |        #   |
; |##        ##|
; |####    ####|
; |####    ####|

L47AE:  DEFB $80, $80, $00, $00, $80, $80
        DEFB $03, $00, $00, $00, $00, $03
        DEFB $00, $09, $09, $83, $82, $00
        DEFB $83, $00, $00, $00, $01, $83
        DEFB $80, $80, $00, $00, $80, $80

; ----------------------------
; Unused - Remains of REM line
; ----------------------------

L47CC:  DEFB _FULLSTOP, _FULLSTOP, _FULLSTOP
        DEFB _NEWLINE

        DEFB 7 >> 8
        DEFB 7 & $FF
        DEFW $01DC
        DEFB _REM

        DEFB _FULLSTOP

; --------------
; Sprites (Cont)
; --------------

; |            |
; |  #  ##     |
; |  #  ##     |
; |  # #####   |
; |  ##### #   |
; |  #  ## #   |
; |    ####    |
; |    #  #    |
; |    #  #    |
; |   ##  ##   |

L47D6:  DEFB $00, $04, $87, $04, $00, $00
        DEFB $00, $05, $81, $82, $04, $00
        DEFB $00, $07, $84, $05, $05, $00
        DEFB $00, $00, $07, $84, $00, $00
        DEFB $00, $87, $05, $85, $04, $00

; |            |
; |      ## #  |
; |      ## #  |
; |   ####  #  |
; |   # #####  |
; |   # ##  #  |
; |    #####   |
; |    #   #   |
; |  ###   ##  |
; |  #         |

L47F4:  DEFB $00, $00, $00, $83, $87, $00
        DEFB $00, $87, $83, $07, $85, $00
        DEFB $00, $85, $85, $07, $84, $00
        DEFB $00, $00, $07, $03, $05, $00
        DEFB $00, $07, $01, $00, $03, $00

; |            |
; |      ## #  |
; |      ## #  |
; |   ####  #  |
; |   # #####  |
; |   # ##  #  |
; |     ##     |
; |   ####     |
; |   # #      |
; |     ##     |

L4812:  DEFB $00, $00, $00, $83, $87, $00
        DEFB $00, $87, $83, $07, $85, $00
        DEFB $00, $85, $85, $07, $84, $00
        DEFB $00, $87, $81, $05, $00, $00
        DEFB $00, $02, $85, $04, $00, $00

; |            |
; |  # ##      |
; |  # ##      |
; |  #  ####   |
; |  ##### #   |
; |  #  ## #   |
; |   #####    |
; |   #   #    |
; |  ##   ###  |
; |         #  |

L4830:  DEFB $00, $04, $83, $00, $00, $00
        DEFB $00, $05, $84, $83, $04, $00
        DEFB $00, $07, $84, $05, $05, $00
        DEFB $00, $85, $03, $84, $00, $00
        DEFB $00, $03, $00, $02, $84, $00

; |            |
; |  # ##      |
; |  # ##      |
; |  #  ####   |
; |  ##### #   |
; |  #  ## #   |
; |     ##     |
; |     ####   |
; |     #  #   |
; |    ##      |

L484E:  DEFB $00, $04, $83, $00, $00, $00
        DEFB $00, $05, $84, $83, $04, $00
        DEFB $00, $07, $84, $05, $05, $00
        DEFB $00, $00, $85, $82, $04, $00
        DEFB $00, $00, $81, $00, $01, $00

; |            |
; |  #  ##     |
; |  #  ##     |
; |  # #####   |
; |  ##### #   |
; |  #  ## #   |
; |    ####    |
; |   ##  #    |
; |       #    |
; |       ##   |

L486C:  DEFB $00, $04, $87, $04, $00, $00
        DEFB $00, $05, $81, $82, $04, $00
        DEFB $00, $07, $84, $05, $05, $00
        DEFB $00, $87, $07, $84, $00, $00
        DEFB $00, $00, $00, $85, $04, $00

; |            |
; |  #  ##     |
; |  #  ##     |
; |  # #####   |
; |  ##### #   |
; |  #  ## #   |
; |    ####    |
; |    #  ##   |
; |    #       |
; |   ##       |

L488A:  DEFB $00, $04, $87, $04, $00, $00
        DEFB $00, $05, $81, $82, $04, $00
        DEFB $00, $07, $84, $05, $05, $00
        DEFB $00, $00, $07, $84, $04, $00
        DEFB $00, $87, $05, $00, $00, $00

; ------------------------------------------------------------------------------------------------------------------------------------------------------

; ----------------
; Program Variable
; ----------------
; The default value points to the remains of a REM line; it will be overridden before being used.

L48A8:  DEFW L47CC                              ; Holds the address of the next sprite character to display.

; --------------------------------------
; Display Sprites Around Player Position
; --------------------------------------
; This routine populates the display file with the sprites corresponding to the maze codes around the player position within the maze.

L48AA:  LD   HL,(L4088)                         ; Fetch the address of the player within the maze.
        LD   BC,$007D                           ; Offset to 2 rows down and 3 to the left. This will be reversed by the subtraction
        ADD  HL,BC                              ; below to end up pointing to the top-left cell of the maze to display.

        PUSH HL
        POP  DE                                 ; Transfer the maze address to DE.

        LD   HL,(D_FILE)                        ; Fetch the address of the display file.
        LD   BC,$0065                           ; Offset to row 3 column 1, which will where the top-left sprite will be drawn.
        ADD  HL,BC                              ; Advance the display file pointer.

; Enter a loop for each column within the maze to render.

L48BA:  LD   B,$04                              ; The number of sprite columns (changed from BASIC between 5 and 4 on title screen).

; HL=Address the display sprite in display file.
; DE=Row below the bottom displayed row and one column to the left.

L48BC:  PUSH BC
        PUSH HL                                 ; Save the address within the display file.

        PUSH DE                                 ; Transfer the maze address to HL.
        POP  HL

        LD   BC,$00FF                           ; Move back up four rows and one column across to the right.
        AND  A
        SBC  HL,BC

        PUSH HL
        POP  DE                                 ; Transfer the maze address to DE.

; DE=Address within the maze.

        POP  HL                                 ; Retrieve the address within the display file.

; Enter a loop to render 4 maze codes vertically.

        LD   B,$04                              ; There are 4 maze locations vertically to render.

; DE=Current maze position.
; HL=Current address within the display file.

L48CB:  PUSH BC                                 ; Save the vertical maze location counter.
        PUSH HL                                 ; Save the current address within the display file.

        PUSH DE                                 ; Copy the current maze location into HL.
        POP  HL

        LD   A,(HL)                             ; Fetch the maze code from the maze.
        CALL L490A                              ; Toggle the maze code if a prisoner, treasure or a mazog.

        LD   BC,$0040                           ; The maze is 64 columns wide.
        ADD  HL,BC                              ; Advance to the same column within the next row of the maze.
        PUSH HL
        POP  DE                                 ; Transfer the new location position to DE.

        CALL L49B7                              ; Fetch address of sprite for the code.
        LD   (L48A8),BC                         ; Save the address of the sprite.

        POP  HL                                 ; Retrieve the address in the display file where the sprite will be shown. 
        LD   B,$05                              ; There are 5 rows in the sprite.

L48E3:  PUSH BC                                 ; Save the row counter.
        LD   B,$06                              ; There are 6 columns in the sprite.

L48E6:  PUSH BC                                 ; Save the column counter.

        LD   BC,(L48A8)                         ; Fetch the address of the sprite.
        LD   A,(BC)                             ; Fetch the next character code to display.
        INC  BC                                 ; Point to the next character within the current row of the sprite.
        LD   (L48A8),BC                         ; Store the address of the next character of the sprite to display.

        LD   (HL),A                             ; Store the character in the display file.
        INC  HL                                 ; Advance to the next display file location.

        POP  BC                                 ; Retrieve the column counter.
        DJNZ L48E6                              ; Loop back for all columns in the current row.

        LD   BC,$001B                           ; Offset to the start column for the sprite within the next row.
        ADD  HL,BC                              ; Advance to the start column position within the next row.

        POP  BC                                 ; Retrieve the row counter.
        DJNZ L48E3                              ; Loop back for all rows in the sprite.

        POP  BC                                 ; Retrieve the vertical maze location counter.
        DJNZ L48CB                              ; Loop back for all vertical locations within the current column of the maze.

; The 4 positions within the column of the maze have been rendered to the display file.

        LD   BC,$028E                           ; Offset to move back to the top of the display file and to the start of the next sprite column (19 rows + 27 columns).
        AND  A
        SBC  HL,BC                              ; Point back to the start of the next sprite column within the display file.

        POP  BC                                 ; Retrieve the vertical sprite counter.
        DJNZ L48BC                              ; Loop back if there are further sprites to display.

        RET  

; ----------------
; Update Maze Code
; ----------------
; Entry: A=Maze code.
;        DE=Address within the maze.

L490A:  NOP     

        AND  A                                  ; Redundant, possibly originally intended to check for a value of $00.

        CP   _P                                 ; Is it a prisoner sprite 1?
        JR   Z,L4925                            ; Jump ahead if so.

        CP   _INVP                              ; Is it a prisoner sprite 2?
        JR   Z,L4925                            ; Jump ahead if so.

        CP   _T                                 ; Is it treasure sprite 1?
        JR   Z,L4925                            ; Jump ahead if so.

        CP   _INVT                              ; Is it treasure sprite 2?
        JR   Z,L4925                            ; Jump ahead if so.

        CP   _X                                 ; Is it a mazog sprite 1?
        JR   Z,L4925                            ; Jump ahead if so.

        CP   _INVX                              ; Is it a mazog sprite 2?
        JR   Z,L4925                            ; Jump ahead if so.

        RET  

L4925:  ADD  A,$80                              ; Toggle the maze code.
        LD   (DE),A                             ; Store the new maze code in the maze.
        RET  

; ---------------------------
; Toggle Maze Code (Not Used)
; ---------------------------
; This is a duplicate of the code at $4925.

L4929:  ADD  A,$80
        LD   (DE),A
        RET  

; ----------------------------
; Unused - Remains of REM line
; ----------------------------

L492D:  DEFB _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP

; ----------------------------------
; Display Random Patterns (Not Used)
; ----------------------------------
; This routine sequences through 20 full screen frames of random patterns. For each frame, each row is filled
; with one of four graphic characters selected at random. The routine is never used by the game.

L4934:  LD   B,$14                              ; The display file with be filled with 20 frames of random patterns.

L4936:  PUSH BC                                 ; Save the frame count.

        LD   DE,(D_FILE)                        ; Fetch the address of the display file.
        INC  DE                                 ; Advance past the initial newline.

        LD   B,$18                              ; There are 24 rows in the display.

L493E:  PUSH BC                                 ; Save the row count.

        CALL L4098                              ; Generate a random 8-bit number.
        CALL L40B4                              ; Split the random number into four equal ranges.

; $01=0%-25%, $02=25%-50%, $03=50%-75% or $04=75%-100%.

        ADD  A,$04                              ; A=$05-$08.

; $05=Left Black.
; $06=Bottom left black, top right black.
; $07=Bottom right white.
; $08=Chequerboard.

        LD   B,$20                              ; There are 32 visible columns in the display.

L4949:  LD   (DE),A                             ; Insert the random character into the column position.
        INC  DE                                 ; Advance to the next column.

        DJNZ L4949                              ; Repeat for all columns within the current row.

        INC  DE                                 ; Advance past the end of line newline terminator.

        POP  BC                                 ; Retrieve the row count.
        DJNZ L493E                              ; Repeat for all rows in the display.

        CALL L426D                              ; Delay 0.3 seconds.

        POP  BC                                 ; Retrieve the frame count.
        DJNZ L4936                              ; Repeat for all frames.

        RET  

; ----------------------------
; Unused - Remains of REM line
; ----------------------------

        DEFB _FULLSTOP, _FULLSTOP, _FULLSTOP

; --------------------------------
; Moves Gained for Killing a Mazog
; --------------------------------

L495B:  DEFB $8E                                ; Holds the number of moves gained for killing a mazog.

; ----------------------------
; Player Collided with a Mazog
; ----------------------------
; The player has moved into a location containing a mazog.
; The moves remaining counter is increased with the gain for killing the mazog prior to the fight occurring.
; If the player loses the fight then it is irrelevant that the moves remaining counter was increased. 

L495C:  PUSH HL                                 ; Preserve the value of HL.

        LD   HL,(L4B0E)                         ; Fetch the moves remaining counter.
        LD   A,(L495B)                          ; Apply the moves gain assuming the mazog is killed.
        LD   B,$00
        LD   C,A
        ADD  HL,BC
        STORE_HL(L4B0E)                         ; LD (L4B0E),HL. Store the new moves remaining counter.

        POP  HL                                 ; Restore the value of HL.
        JP   L4DC1                              ; Perform the fight between the player and the mazog.

; ------
; Unused
; ------

L496F:  DEFB $00

; ------------------------------
; Delay Before Moving All Mazogs
; ------------------------------

L4970:  CALL L426D                              ; Delay 0.3 seconds.

        NOP     
        NOP     
        NOP     

        JP   L4F57                              ; Jump to move all mazogs.

; ----------------------------
; Unused - Remains of REM line
; ----------------------------

L4979:  DEFB _FULLSTOP

; ---------------------------
; Address of Treasure in Maze
; ---------------------------

L497A:  DEFW $7D00                              ; Holds the address of the treasure when relocated by the player within the maze.

; -----------------------
; Store Treasure Location
; -----------------------

L497C:  STORE_HL(L497A)                         ; LD (L497A),HL. Store the address of the treasure relocated by the player within the maze.
        JP   L4C50                              ; Jump to wait for the movement key to be released, then render the screen around the player position, and then move all mazogs.

; ----------------------------
; Unused - Remains of REM line
; ----------------------------

L4983:  DEFB _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP
        DEFB _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP
        DEFB _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP
        DEFB _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP
        DEFB _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP
        DEFB _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP
        DEFB _NEWLINE

        DEFB $0008 >> 8
        DEFB $0008 & $FF
        DEFW $015C
        DEFB _REM
        DEFB _FULLSTOP, _FULLSTOP

; ----------------------
; Find Address of Sprite
; ----------------------
; Entry: A=Code.
; Exit : BC=Address of sprite.

L49B7:  CP   _SPACE                             ; Empty?
        JP   Z,L4A70

        CP   _BLACK                             ; Wall?
        JP   Z,L4A74

        CP   _FULLSTOP                          ; Trail?
        JP   Z,L4A78

        CP   _ASTERISK                          ; 'This Way'?
        JP   Z,L4A7C

        CP   _1                                 ; Standing?
        JP   Z,L4A80

        CP   _2                                 ; Running Right 1?
        JP   Z,L4A84

        CP   _INV2                              ; Running Right 2?
        JP   Z,L4A88

        CP   _3                                 ; Running Left 1?
        JP   Z,L4A8C

        CP   _INV3                              ; Running Left 2?
        JP   Z,L4A90

        CP   _4                                 ; Up-Down Right Leg Up?
        JP   Z,L4A94

        CP   _INV4                              ; Up-Down Left Leg Up?
        JP   Z,L4A98

        CP   _5                                 ; Holding Treasure?
        JP   Z,L4A9C

        CP   _6                                 ; Running Holding Treasure Right 1?
        JP   Z,L4AA0

        CP   _7                                 ; Running Holding Treasure Left 1?
        JP   Z,L4AA4

        CP   _INV7                              ; Running Holding Treasure Left 2?
        JP   Z,L4AA8

        CP   _8                                 ; Down Holding Treasure Right Leg Up?
        JP   Z,L4AAC

        CP   _INV8                              ; Down Holding Treasure Left Leg Up?
        JP   Z,L4AB0

        CP   _9                                 ; Up Holding Treasure Right Leg Up?
        JP   Z,L4AB4

        CP   _INV9                              ; Up Holding Treasure Left Leg Up?
        JP   Z,L4AB8

        CP   _A                                 ; Holding Sword?
        JP   Z,L4ABC

        CP   _B                                 ; Running With Sword Right 1?
        JP   Z,L4AC0

        CP   _INVB                              ; Running With Sword Right 2?
        JP   Z,L4AC4

        CP   _C                                 ; Running With Sword Left 1?
        JP   Z,L4AC8

        CP   _INVC                              ; Running With Sword Left 2?
        JP   Z,L4ACC

        CP   _D                                 ; Up-Down With Sword Left Leg Up?
        JP   Z,L4AD0

        CP   _INVD                              ; Up-Down With Sword Right Leg Up?
        JP   Z,L4AD4

        CP   _X                                 ; Mazog Eyes Open?
        JP   Z,L4AD8

        CP   _INVX                              ; Mazog Eyes Closed?
        JP   Z,L4ADC

        CP   _T                                 ; Treasure 1?
        JP   Z,L4AE0

        CP   _INVT                              ; Treasure 2?
        JP   Z,L4AE4

        CP   _P                                 ; Prisoner Eyes Closed?
        JP   Z,L4AE8

        CP   _INVP                              ; Prisoner Eyes Open?
        JP   Z,L4AEC

        CP   _INVS                              ; Sword?
        JP   Z,L4AF0

        CP   _INV6                              ; Running Holding Treasure Right 2?
        JP   Z,L4B00

        CP   _F                                 ; Fighting 1?
        JP   Z,L4AF4

        CP   _G                                 ; Fighting 2?
        JP   Z,L4AF8

        CP   _H                                 ; Fighting 3?
        JP   Z,L4AFC

; An external wall will drop down here to be displayed as an empty location.

L4A70:  LD   BC,L46FA                           ; Empty sprite definition.
        RET  

L4A74:  LD   BC,L4718                           ; Wall sprite definition.
        RET  

L4A78:  LD   BC,L4736                           ; Trail sprite definition.
        RET  

L4A7C:  LD   BC,L4754                           ; 'This Way' sprite definition.
        RET  

L4A80:  LD   BC,L443E                           ; Standing sprite definition.
        RET  

L4A84:  LD   BC,L4498                           ; Running Right 1 sprite definition.
        RET  

L4A88:  LD   BC,L44B6                           ; Running Right 2 sprite definition.
        RET  

L4A8C:  LD   BC,L44D4                           ; Running Left 1 sprite definition.
        RET  

L4A90:  LD   BC,L44F2                           ; Running Left 2 sprite definition.
        RET  

L4A94:  LD   BC,L445C                           ; Up-Down Right Leg Up sprite definition.
        RET  

L4A98:  LD   BC,L447A                           ; Up-Down Left Leg Up sprite definition.
        RET  

L4A9C:  LD   BC,L456A                           ; Holding Treasure sprite definition.
        RET  

L4AA0:  LD   BC,L4588                           ; Running Holding Treasure Right 1 sprite definition.
        RET  

L4AA4:  LD   BC,L45C4                           ; Running Holding Treasure Left 1 sprite definition.
        RET  

L4AA8:  LD   BC,L45E2                           ; Running Holding Treasure Left 2 sprite definition.
        RET  

L4AAC:  LD   BC,L460A                           ; Down Holding Treasure Right Leg Up sprite definition.
        RET  

L4AB0:  LD   BC,L4628                           ; Down Holding Treasure Left Leg Up sprite definition.
        RET  

L4AB4:  LD   BC,L4646                           ; Up Holding Treasure Right Leg Up sprite definition.
        RET  

L4AB8:  LD   BC,L4664                           ; Up Holding Treasure Left Leg Up sprite definition.
        RET  

L4ABC:  LD   BC,L47D6                           ; Holding Sword sprite definition.
        RET  

L4AC0:  LD   BC,L47F4                           ; Running With Sword Right 1 sprite definition.
        RET  

L4AC4:  LD   BC,L4812                           ; Running With Sword Right 2 sprite definition.
        RET  

L4AC8:  LD   BC,L4830                           ; Running With Sword Left 1 sprite definition.
        RET  

L4ACC:  LD   BC,L484E                           ; Running With Sword Left 2 sprite definition.
        RET  

L4AD0:  LD   BC,L486C                           ; Up-Down With Sword Left Leg Up sprite definition.
        RET  

L4AD4:  LD   BC,L488A                           ; Up-Down With Sword Right Leg Up sprite definition.
        RET  

L4AD8:  LD   BC,L4682                           ; Mazog Eyes Open sprite definition.
        RET  

L4ADC:  LD   BC,L46A0                           ; Mazog Eyes Closed sprite definition.
        RET  

L4AE0:  LD   BC,L4772                           ; Treasure 1 sprite definition.
        RET  

L4AE4:  LD   BC,L4790                           ; Treasure 2 sprite definition.
        RET  

L4AE8:  LD   BC,L46BE                           ; Prisoner Eyes Closed sprite definition.
        RET  

L4AEC:  LD   BC,L46DC                           ; Prisoner Eyes Open sprite definition.
        RET  

L4AF0:  LD   BC,L47AE                           ; Sword sprite definition.
        RET  

L4AF4:  LD   BC,L4510                           ; Fighting 1 sprite definition.
        RET  

L4AF8:  LD   BC,L452E                           ; Fighting 2 sprite definition.
        RET  

L4AFC:  LD   BC,L454C                           ; Fighting 3 sprite definition.
        RET  

L4B00:  LD   BC,L45A6                           ; Running Holding Treasure Right 2 sprite definition.
        RET  

; ----------------------------
; Unused - Remains of REM line
; ----------------------------

L4B04:  DEFB _FULLSTOP, _FULLSTOP, _FULLSTOP
        DEFB _FULLSTOP, _FULLSTOP, _FULLSTOP
        DEFB $D0, $FF

; -----------------
; Program Variables
; -----------------

L4B0C:  DEFB $00                                ; Indicates whether the game includes a move remaining countdown ($01=No countdown, $00=Countdown).
L4B0D:  DEFB $00                                ; $01=Moving mazogs, $00=Static mazogs.
L4B0E:  DEFW $06E9                              ; Holds the moves remaining counter.

; The following are cleared at the start of a game:

L4B10:  DEFB $00                                ; $01=Holding sword, $00=No sword.
L4B11:  DEFB $00                                ; $01=Holding treasure, $00=No treasure.
L4B12:  DEFB $00                                ; $01=The way is being shown, $00=The way is not being shown.
L4B13:  DEFB $00                                ; $01=View mode, $00=Normal mode.
L4B14:  DEFB $00                                ; $01=Starved.
L4B15:  DEFB $00                                ; $01=Exited with treasure.
L4B16:  DEFB $00                                ; $01=Situation report requested.
L4B17:  DEFB $01                                ; Holds the movement direction code ($01=Left, $02=Right, $03=Up, $04=Down).
L4B18:  DEFB $01                                ; $01=Player killed by a mazog.

L4B19:  DEFB $0F                                ; Number of moves required to pay for a View. This value is set from BASIC and then not changed by the game.

; ---------------------
; Operate the Game Loop
; ---------------------
; An return is only made when the game is over.

L4B1A:  LD   B,$09                              ; The number of game flags to clear.
        LD   HL,L4B10                           ; The start address of the game flags to clear.

L4B1F:  LD   (HL),$00                           ; Clear a game flag.
        INC  HL                                 ; Advance to the next game flag.
        DJNZ L4B1F                              ; Repeat for all game flags.

        NOP     
        NOP     
        NOP     

; Enter the main program loop.

L4B27:  LD   A,(L4B12)                          ; Is the way being shown?
        CP   $00
        JR   Z,L4B3D                            ; Jump ahead if not.

; The way is being shown.

        LD   A,(FRAMES+$0001)                   ; Has the 'This Way' timer expired, which occurs when the high byte of frames decremented from $FF to $FC?
        CP   $FC                                ; The timer expires after $300 frames which corresponds to 15.36 seconds.
        JR   NZ,L4B3D                           ; Jump ahead if not.

; The 'This Way' timer has expired so remove the 'This Way' markers.

        CALL L42E8                              ; Clear the maze of mazogs, trails and 'This Way's.

        LD   A,$00
        LD   (L4B12),A                          ; Signal that the way is no longer being shown.

; Joins here after processing the 'This Way' shown flag.

L4B3D:  LD   A,(L4B13)                          ; In View mode?
        CP   $00
        JP   Z,L4B52                            ; Jump ahead if not.

; In View mode.

        LD   A,(FRAMES+$0001)                   ; Fetch the high byte of the 'View' timer. Has it decremented from $FF to $FE?
L4B48:  CP   $FE                                ; Has the view timeout expired, i.e. after 5.1 seconds?
        JP   NZ,L4C9D                           ; Jump ahead if not.

; The view timeout has expired.

        LD   A,$00
        LD   (L4B13),A                          ; Signal not in View mode.

; Joins here after processing the View shown flag.

L4B52:  CALL L40DE                              ; Fetch the key press code.

        LD   HL,(L4088)                         ; Fetch the address of the player within the maze.
        PUSH HL
        POP  DE                                 ; DE=Address of the player maze code within the maze.

        LD   BC,$0040                           ; The number of columns in the maze, used to apply an offset when moving up or down.

        CP   $04                                ; Was key 'A' (LEFT) pressed?
        JR   Z,L4B8E                            ; Jump ahead if so.

        CP   $60                                ; Was key 'H' (LEFT) pressed?
        JR   Z,L4B8E                            ; Jump ahead if so.

        CP   $0A                                ; Was key 'D' (RIGHT) pressed? (Also '1' and 'SHIFT'+'X')
        JR   Z,L4B93                            ; Jump ahead if so.

        CP   $50                                ; Was key 'J' (RIGHT) pressed?
        JR   Z,L4B93                            ; Jump ahead if so.

        CP   $08                                ; Was key 'W' (UP) pressed?
        JR   Z,L4B98                            ; Jump ahead if so.

        CP   $09                                ; Was key 'X' (DOWN) pressed? (Also 'SHIFT'+'W')
        JR   Z,L4B9F                            ; Jump ahead if so.

        CP   $06                                ; Was key 'S' (DOWN) pressed? (Also 'Q' and 'SHIFT'+'Z')
        JR   Z,L4B9F                            ; Jump ahead if so.

        CP   $21                                ; Was key 'V' (VIEW) pressed? (Also 'SHIFT'+'7')
        JP   Z,L4C6A                            ; Jump ahead if so.

        CP   $40                                ; Was key 'Y' (STOP) pressed?
        JR   Z,L4B88                            ; Jump ahead if so.

; Either no key or an invalid key was pressed.

        CALL L4CA6                              ; Display a non-moving player graphic (standing, holding treasure, holding sword).
        JP   L4970                              ; Delay 0.3 seconds then move all mazogs.

; The 'Y' key (Situation Report) was pressed.

L4B88:  LD   A,$01
        LD   (L4B16),A                          ; Signal that the player has requested a situation report.
        RET  

; The 'A' or 'H' key (LEFT) was pressed.

L4B8E:  DEC  HL                                 ; Move the player left in the maze.
        LD   A,$01                              ; Movement code for left.
        JR   L4BA2                              ; Jump ahead to continue.

; The 'D' or 'J' key (RIGHT) was pressed.

L4B93:  INC  HL                                 ; Move the player right in the maze.
        LD   A,$02                              ; Movement code for right.
        JR   L4BA2                              ; Jump ahead to continue.

; The 'W' key (UP) was pressed.

L4B98:  AND  A
        SBC  HL,BC                              ; Move the player up in the maze.
        LD   A,$03                              ; Movement code for up.
        JR   L4BA2                              ; Jump ahead to continue.

; The 'X' or 'S' key (DOWN) was pressed.

L4B9F:  ADD  HL,BC                              ; Move the player down in the maze.

        LD   A,$04                              ; Movement code for down.

; Joins here with all 4 movement directions.

L4BA2:  LD   (L4B17),A                          ; Store the movement direction code.

        LD   A,(HL)                             ; Fetch the maze code at the new location within the maze.

        CP   _BLACK                             ; Is it a wall?
        JP   Z,L4C32                            ; Jump if it is.

        CP   _SPACE                             ; Is it an empty location?
        JP   Z,L4CC4                            ; Jump if it is.

        CP   _FULLSTOP                          ; Is it a trail?
        JP   Z,L4CC4                            ; Jump if it is.

        CP   _ASTERISK                          ; Is it a 'This Way'?
        JP   Z,L4CC4                            ; Jump if it is.

        CP   _X                                 ; Is it a mazog with eyes open?
        JP   Z,L495C                            ; Jump if it is.

        CP   _INVX                              ; Is it a mazog with eyes closed?
        JP   Z,L495C                            ; Jump if it is.

        CP   _T                                 ; Is it a treasure #1?
        JR   Z,L4BE5                            ; Jump if it is.

        CP   _INVT                              ; Is it a treasure #2?
        JR   Z,L4BE5                            ; Jump if it is.

        CP   _P                                 ; Is it a prisoner with eyes closed?
        JR   Z,L4C10                            ; Jump if it is.

        CP   _INVP                              ; Is it a prisoner with eyes open?
        JR   Z,L4C10                            ; Jump if it is.

        CP   _INVS                              ; Is it a sword?
        JR   Z,L4C38                            ; Jump if it is.

        CP   _DOLLAR                            ; Is it the exit?
        JR   Z,L4BDF                            ; Jump if it is.

        JP   L4B27                              ; Jump back to repeat the main program loop.

; The exit has been reached.

L4BDF:  LD   A,$01
        LD   (L4B15),A                          ; Signal that the player has exited with the treasure.
        RET  

; ---------------------------------
; Player Collided with the Treasure
; ---------------------------------
; The player has moved into a location containing the treasure.

L4BE5:  LD   BC,(L408A)                         ; Fetch the location of the exit within the maze.
        LD   A,_DOLLAR                          ; Insert the exit maze code into the maze.
        LD   (BC),A

        LD   A,(L4B10)                          ; Does the player have a sword?
        CP   $01
        JR   NZ,L4BFC                           ; Jump ahead if not.

; The player has a sword.

        LD   (HL),_INVS                         ; Replace the treasure with the sword.

        LD   A,$00
        LD   (L4B10),A                          ; Signal that the player does not have a sword.
        JR   L4BFE                              ; Jump ahead to continue.

; The player does not have a sword.

L4BFC:  LD   (HL),_BLACK                        ; Replace the treasure with an internal wall.

L4BFE:  LD   A,_5                               ; Insert the maze code for holding the treasure.
        LD   (DE),A

        LD   A,$01
        LD   (L4B11),A                          ; Signal the player is holding the treasure.

; Wait for the movement key to be released.

L4C06:  CALL L40DE                              ; Fetch the key press code.
        CP   $00                                ; Is a key being pressed?
        JR   NZ,L4C06                           ; Jump back if so.

; The key as been released.

        JP   L4DCB                              ; Jump to render the screen around the player position and then move all mazogs.

; -------------------------------
; Player Collided with a Prisoner
; -------------------------------
; The player has moved into a location containing a prisoner. The prisoner is only freed if the game contains mobile mazogs.
; Entry: HL=Maze location of the player.

L4C10:  PUSH HL                                 ; Save the player's location within the maze.
        CALL L4CA6                              ; Display a non-moving player graphic (standing, holding treasure, holding sword).
        POP  HL                                 ; Retrieve the player's location within the maze.

        LD   A,(L4B0D)                          ; Fetch the mazog type flag.
        CP   $00                                ; Are they static mazogs?
        JR   Z,L4C1E                            ; Jump if so.

        LD   (HL),_BLACK                        ; Free the prisoner by replacing with an internal wall.

L4C1E:  LD   HL,$FFFF                           ; Reset the timer for displaying 'This Way'.
        LD   (FRAMES),HL

        CALL L42E8                              ; Clear the maze of mazogs, trails and 'This Way's.
        CALL L4313                              ; Populate the maze with the route to the treasure / exit.

        LD   A,$01
        LD   (L4B12),A                          ; Signal the way is being shown.

        JP   L4DCB                              ; Jump to render the screen around the player position and then move all mazogs.

; ---------------------------
; Player Collided with a Wall
; ---------------------------

L4C32:  CALL L4CA6                              ; Display a non-moving player graphic (standing, holding treasure, holding sword).
        JP   L4DCE                              ; Jump to move all mazogs.

; ----------------------------
; Player Collided with a Sword
; ----------------------------
; The player has moved into a location containing a sword.

L4C38:  PUSH HL                                 ; Preserve registers.
        PUSH DE

        CALL L4CA6                              ; Display a non-moving player graphic (standing, holding treasure, holding sword).

        POP  DE                                 ; Restore registers.
        POP  HL

        LD   A,(L4B10)                          ; Does the player have a sword?
        CP   $01
        JP   Z,L4DCE                            ; Jump ahead if so.

        LD   A,(L4B11)                          ; Does the player have the treasure?
        CP   $01
        JR   Z,L4C5B                            ; Jump ahead if so.

; The player has picked up a sword.

        LD   (HL),_BLACK                        ; Replace the sword with a wall.

; Joins here after swapping the treasure for a sword.

L4C50:  LD   A,_A                               ; Change the player maze code to Holding a Sword.
        LD   (DE),A

        LD   A,$01
        LD   (L4B10),A                          ; Signal the player has a sword.

        JP   L4C06                              ; Jump to wait for the movement key to be released, then render the screen around the player position, and then move all mazogs.

; The player has the treasure.

L4C5B:  LD   (HL),_T                            ; Replace the sword with the treasure.

        LD   A,$00
        LD   (L4B11),A                          ; Signal the player does not have the treasure.

        LD   BC,(L408A)                         ; Fetch the location of the exit within the maze.
        LD   (BC),A                             ; Mark the location as empty, i.e. remove the exit.

        JP   L497C                              ; Jump to wait for the movement key to be released, then render the screen around the player position, and then move all mazogs.

; The 'V' key (VIEW) was pressed.

L4C6A:  LD   A,$01
        LD   (L4B13),A                          ; Signal in View mode.

        LD   HL,$FFFF                           ; Reset the timer for displaying the view.
        LD   (FRAMES),HL

        CALL L43D5                              ; Fill screen with inverse chequerboard.
        CALL L5097                              ; Decrement countdown timer and delay 0.3 seconds.

        LD   A,(L4B0C)                          ; Does the game include a countdown?
        CP   $01
        JP   Z,L4C9D                            ; Jump if not.

; The game includes a countdown.

        NOP     
        NOP     
        NOP     
        NOP     
        NOP     
        NOP     
        NOP     
        NOP     
        NOP     
        NOP     
        NOP     
        NOP     
        NOP     
        NOP     
        NOP     
        NOP     
        NOP     
        NOP     
        NOP     
        NOP     
        NOP     
        NOP     
        NOP     

        CALL L42E8                              ; Clear the maze of mazogs, trails and 'This Way's.

; Joins here when the game does not include a countdown.

L4C9D:  CALL L426D                              ; Delay 0.3 seconds.
        CALL L517C                              ; Display the View.
        JP   L4DCE                              ; Make an indirect jump to move all mazogs.

; -----------------------------
; Display Static Player Graphic
; -----------------------------
; Display the player standing, holding the treasure or holding a sword.
; Entry: DE=Address of player within the maze.

L4CA6:  NOP     

        LD   A,(L4B11)                          ; Does the player have the treasure?
        CP   $01
        JR   Z,L4CB9                            ; Jump ahead if so.

        LD   A,(L4B10)                          ; Does the player have a sword?
        CP   $01
        JR   Z,L4CBD                            ; Jump ahead if so.

        LD   A,_1                               ; The maze code for the player standing.
        JR   L4CBF                              ; Jump ahead to continue.

L4CB9:  LD   A,_5                               ; The maze code for the player holding the treasure.
        JR   L4CBF                              ; Jump ahead to continue.

L4CBD:  LD   A,_A                               ; The maze code for the player holding a sword.

L4CBF:  LD   (DE),A
        CALL L48AA                              ; Render the screen of sprites at the current player position.
        RET  

; ---------------
; Move the Player
; ---------------
; Enters here when the player moves to a location that is empty, contains a trail or a 'This Way'.
; Entry: DE=Address of the current player location within the maze.
;        HL=Address of the new player location within the maze.

L4CC4:  NOP     

        LD   A,(L4B17)                          ; Fetch the movement direction code.
        CP   $02                                ; Was the movement to the right?
        JR   Z,L4D11                            ; Jump if it was.

        CP   $03                                ; Was the movement up?
        JR   Z,L4D4C                            ; Jump if it was.

        CP   $04                                ; Was the movement down?
        JP   Z,L4D87                            ; Jump if it was.

; The player is moving to the left
; --------------------------------

        NOP     

        LD   A,(L4B11)                          ; Does the player have the treasure?
        CP   $01
        JR   Z,L4CF3                            ; Jump ahead if so.

        LD   A,(L4B10)                          ; Does the player have a sword?
        CP   $01
        JR   Z,L4D02                            ; Jump ahead if so.

; The player does not have a sword or the treasure.

        LD   A,(DE)                             ; Fetch the maze code of the player at the current location within the maze.
        CP   _3                                 ; Is it maze code Running Left 1?
        JR   Z,L4CEE                            ; Jump ahead if so.

; Change to the Running Left 1 animation frame.

        LD   A,_3                               ; Maze code for Running Left 1.
        JP   L4DA4                              ; Update the player maze code in the maze.

; Change to the Running Left 2 animation frame.

L4CEE:  LD   A,_INV3                            ; Maze code for Running Left 2.
        JP   L4DA4                              ; Update the player maze code in the maze.

; The player is holding the treasure.

L4CF3:  LD   A,(DE)                             ; Fetch the maze code of the player at the current location within the maze.
        CP   _7                                 ; Is it maze code Running Holding Treasure Left 1?
        JR   Z,L4CFD                            ; Jump ahead if so.

; Change to the Running Holding Treasure Left 1 animation frame.

        LD   A,_7                               ; Maze code for Running Holding Treasure Left 1.
        JP   L4DA4                              ; Update the player maze code in the maze.

; Change to the Running Holding Treasure Left 2 animation frame.

L4CFD:  LD   A,_INV7                            ; Maze code for Running Holding Treasure Left 2.
        JP   L4DA4                              ; Update the player maze code in the maze.

; The player is holding a sword.

L4D02:  LD   A,(DE)                             ; Fetch the maze code of the player at the current location within the maze.
        CP   _C                                 ; Is it maze code Running With Sword Left 1?
        JR   Z,L4D0C                            ; Jump ahead if so.

; Change to the Running With Sword Left 1 animation frame.

        LD   A,_C                               ; Maze code for Running With Sword Left 1.
        JP   L4DA4                              ; Update the player maze code in the maze.

; Change to the Running With Sword Left 2 animation frame.

L4D0C:  LD   A,_INVC                            ; Maze code for Running With Sword Left 2.
        JP   L4DA4                              ; Update the player maze code in the maze.

; The player is moving to the right
; ---------------------------------

L4D11:  LD   A,(L4B11)                          ; Does the player have the treasure?
        CP   $01
        JR   Z,L4D2E                            ; Jump ahead if so.

        LD   A,(L4B10)                          ; Does the player have a sword?
        CP   $01
        JR   Z,L4D3D                            ; Jump ahead if so.

; The player does not have a sword or the treasure.

        LD   A,(DE)                             ; Fetch the maze code of the player at the current location within the maze.
        CP   _2                                 ; Is it maze code Running Right 1?
        JR   Z,L4D29                            ; Jump ahead if so.

; Change to the Running Right 1 animation frame.

        LD   A,_2                               ; Maze code for Running Right 1.
        JP   L4DA4                              ; Update the player maze code in the maze.

; Change to the Running Right 2 animation frame.

L4D29:  LD   A,_INV2                            ; Maze code for Running Right 2.
        JP   L4DA4                              ; Update the player maze code in the maze.

; The player is holding the treasure.

L4D2E:  LD   A,(DE)                             ; Fetch the maze code of the player at the current location within the maze.
        CP   _6                                 ; Is it maze code Running Holding Treasure Right 1?
        JR   Z,L4D38                            ; Jump ahead if so.

; Change to the Running Holding Treasure Right 1 animation frame.

        LD   A,_6                               ; Maze code for Running Holding Treasure Right 1.
        JP   L4DA4                              ; Update the player maze code in the maze.

; Change to the Running Holding Treasure Right 2 animation frame.

L4D38:  LD   A,_INV6                            ; Maze code for Running Holding Treasure Right 2.
        JP   L4DA4                              ; Update the player maze code in the maze.

; The player is holding a sword.

L4D3D:  LD   A,(DE)                             ; Fetch the maze code of the player at the current location within the maze.
        CP   _B                                 ; Is it maze code Running With Sword Right 1?
        JR   Z,L4D47                            ; Jump ahead if so.

; Change to the Running With Sword Right 1 animation frame.

        LD   A,_B                               ; Maze code for Running With Sword Right 1.
        JP   L4DA4                              ; Update the player maze code in the maze.

; Change to the Running With Sword Right 2 animation frame.

L4D47:  LD   A,_INVB                            ; Maze code for Running With Sword Right 2.
        JP   L4DA4                              ; Update the player maze code in the maze.

; The player is moving up
; -----------------------

L4D4C:  LD   A,(L4B11)                          ; Does the player have the treasure?
        CP   $01
        JR   Z,L4D69                            ; Jump ahead if so.

        LD   A,(L4B10)                          ; Does the player have a sword?
        CP   $01
        JR   Z,L4D78                            ; Jump ahead if so.

; The player does not have a sword or the treasure.
; Joins here when moving down.

L4D5A:  LD   A,(DE)                             ; Fetch the maze code of the player at the current location within the maze.
        CP   _4                                 ; Is it maze code Up-Down Right Leg Up?
        JR   Z,L4D64                            ; Jump ahead if so.

; Change to the Up-Down Right Leg Up animation frame.

        LD   A,_4                               ; Maze code Up-Down Right Leg Up.
        JP   L4DA4                              ; Update the player maze code in the maze.

; Change to the Up-Down Left Leg Up animation frame.

L4D64:  LD   A,_INV4                            ; Maze code Up-Down Left Leg Up.
        JP   L4DA4                              ; Update the player maze code in the maze.

; The player is holding the treasure.

L4D69:  LD   A,(DE)                             ; Fetch the maze code of the player at the current location within the maze.
        CP   _9                                 ; Is it maze code Up Holding Treasure Right Leg Up?
        JR   Z,L4D73                            ; Jump ahead if so.

; Change to the Running With Sword Right 1 animation frame.

        LD   A,_9                               ; Maze code Up Holding Treasure Right Leg Up.
        JP   L4DA4                              ; Update the player maze code in the maze.

; Change to the Running With Sword Right 1 animation frame.

L4D73:  LD   A,_INV9                            ; Maze code Up Holding Treasure Left Leg Up.
        JP   L4DA4                              ; Update the player maze code in the maze.

; The player is holding a sword.
; Joins here when moving down.

L4D78:  LD   A,(DE)                             ; Fetch the maze code of the player at the current location within the maze.
        CP   _D                                 ; Is it maze code Up-Down With Sword Left Leg Up?
        JR   Z,L4D82                            ; Jump ahead if so.

; Change to the Running With Sword Right 1 animation frame.

        LD   A,_D                               ; Maze code Up-Down With Sword Left Leg Up.
        JP   L4DA4                              ; Update the player maze code in the maze.

; Change to the Running With Sword Right 1 animation frame.

L4D82:  LD   A,_INVD                            ; Maze code Up-Down With Sword Right Leg Up.
        JP   L4DA4                              ; Update the player maze code in the maze.

; The player is moving down
; -------------------------

L4D87:  LD   A,(L4B11)                          ; Does the player have the treasure?
        CP   $01
        JR   Z,L4D98                            ; Jump ahead if so.

        LD   A,(L4B10)                          ; Does the player have a sword?
        CP   $01
        JR   Z,L4D78                            ; Jump if so to handle via the move up routine.

; The player does not have a sword or the treasure.

        JP   L4D5A                              ; Handle via the move up routine.

; The player is holding the treasure.

L4D98:  LD   A,(DE)                             ; Fetch the maze code of the player at the current location within the maze.
        CP   _8                                 ; Is it maze code Down Holding Treasure Right Leg Up?
        JR   Z,L4DA2                            ; Jump ahead if so.

; Change to the Running With Sword Right 1 animation frame.

        LD   A,_8                               ; Maze code Down Holding Treasure Right Leg Up.
        JP   L4DA4                              ; Update the player maze code in the maze.

; Change to the Running With Sword Right 1 animation frame.

L4DA2:  LD   A,_INV8                            ; Maze code Down Holding Treasure Left Leg Up.

; All paths join here to change the player's maze code in the maze.

L4DA4:  LD   (HL),A                             ; Set the maze code for the player at the new maze position.

        LD   A,_FULLSTOP
        LD   (DE),A                             ; Place a trail marker in the older player location within the maze.

        LD   (L4088),HL                         ; Save the new location of the player in the maze.

        CALL L5097                              ; Decrement countdown timer and delay 0.3 seconds.

        LD   A,(L4B14)                          ; Did the player starve to death?
        CP   $01
        RET  Z                                  ; Return if so.

L4DB4:  NOP                                     ; For game 'TRY IT OUT', the BASIC replaces these NOPs with CALL $426D, which
L4DB5:  NOP                                     ; performs a delay of 0.3 Seconds.
L4DB6:  NOP

        JP   L4DCB                              ; Jump to render the screen of sprites at the current player position, then move all mazogs

; ------
; Unused
; ------

L4DBA:  DEFB $00, $00, $00, $00, $00, $00, $00

; --------------------------------------
; Perform Fight Between Player and Mazog
; --------------------------------------

L4DC1:  NOP     

        CALL L4E2A                              ; Perform a fight between the player and a mazog.

        LD   A,(L4B18)                          ; Has the player been killed by a mazog?
        CP   $01
        RET  Z                                  ; Return if so.

; The player is alive.
; Joins here after moving the player.

L4DCB:  CALL L48AA                              ; Render the screen of sprites at the current player position.

; Joins here when the player has a sword.

L4DCE:  JP   L4F57                              ; Jump to move all mazogs.

; ------
; Unused
; ------

L4DD1:  DEFB $AA, $48, $CD, $AA

; --------------------
; Mazog Location Table
; --------------------
; The table holds the locations of all mazogs within the maze. There is capacity for 40 mazogs but the game only uses 38.
; When a mazog is killed, its location is changed to be outside the maze by setting its high address byte to $FF.

L4DD5:  DEFW $789C      ; MAZE + (MAZE_WIDTH * 22) + 18
        DEFW $7768      ; MAZE + (MAZE_WIDTH * 17) + 30
        DEFW $7983      ; MAZE + (MAZE_WIDTH * 25) + 57
        DEFW $7794      ; MAZE + (MAZE_WIDTH * 18) + 10
        DEFW $7920      ; MAZE + (MAZE_WIDTH * 24) + 22
        DEFW $7C0C      ; MAZE + (MAZE_WIDTH * 36) + 2
        DEFW $7C6F      ; MAZE + (MAZE_WIDTH * 37) + 37
        DEFW $7E53      ; MAZE + (MAZE_WIDTH * 45) + 9
        DEFW $7B04      ; MAZE + (MAZE_WIDTH * 31) + 58
        DEFW $7710      ; MAZE + (MAZE_WIDTH * 16) + 6
        DEFW $747C      ; MAZE + (MAZE_WIDTH * 5 ) + 50
        DEFW $7BBF      ; MAZE + (MAZE_WIDTH * 34) + 53
        DEFW $7823      ; MAZE + (MAZE_WIDTH * 20) + 25
        DEFW $7500      ; MAZE + (MAZE_WIDTH * 7 ) + 54
        DEFW $77EC      ; MAZE + (MAZE_WIDTH * 19) + 34
        DEFW $7B0F      ; MAZE + (MAZE_WIDTH * 32) + 5
        DEFW $7CF3      ; MAZE + (MAZE_WIDTH * 39) + 41
        DEFW $76E4      ; MAZE + (MAZE_WIDTH * 15) + 26
        DEFW $FFF7      ; Dead mazog.
        DEFW $771B      ; MAZE + (MAZE_WIDTH * 16) + 17
        DEFW $7A28      ; MAZE + (MAZE_WIDTH * 28) + 30
        DEFW $FFC3      ; Dead mazog.
        DEFW $7BE0      ; MAZE + (MAZE_WIDTH * 35) + 22
        DEFW $79AF      ; MAZE + (MAZE_WIDTH * 26) + 37
        DEFW $7DC4      ; MAZE + (MAZE_WIDTH * 42) + 58
        DEFW $75BB      ; MAZE + (MAZE_WIDTH * 10) + 49
        DEFW $73F8      ; MAZE + (MAZE_WIDTH * 3 ) + 46
        DEFW $7A33      ; MAZE + (MAZE_WIDTH * 28) + 41
        DEFW $7537      ; MAZE + (MAZE_WIDTH * 8 ) + 45
        DEFW $745B      ; MAZE + (MAZE_WIDTH * 5 ) + 17
        DEFW $7E1C      ; MAZE + (MAZE_WIDTH * 44) + 18
        DEFW $7CE8      ; MAZE + (MAZE_WIDTH * 39) + 30
        DEFW $7D14      ; MAZE + (MAZE_WIDTH * 40) + 10
        DEFW $73A0      ; MAZE + (MAZE_WIDTH * 2 ) + 22
        DEFW $768C      ; MAZE + (MAZE_WIDTH * 14) + 2
        DEFW $76EF      ; MAZE + (MAZE_WIDTH * 15) + 37
        DEFW $73D7      ; MAZE + (MAZE_WIDTH * 3 ) + 13
        DEFW $FF3F      ; Dead mazog.
        DEFW $758C      ; MAZE + (MAZE_WIDTH * 10) + 2
        DEFW $73B3      ; MAZE + (MAZE_WIDTH * 2 ) + 41

; ------
; Unused
; ------

L4E25:  DEFB _FULLSTOP

; -----------------
; Program Variables
; -----------------

L4E26:  DEFB $34                                ; Offset into the mazog table of the mazog to move.
L4E27:  DEFB $26                                ; Holds the number of mazogs. The quantity is never changed by the game.
L4E28:  DEFB $28                                ; Holds the number of swords. The quantity is never changed by the game.
L4E29:  DEFB $1E                                ; Holds the number of prisoners. The quantity is never changed by the game.

; -----------------------
; Player Fighting a Mazog
; -----------------------
; Entry: DE=Previous location of the player in the maze.
;        HL=New location of the player in the maze.

L4E2A:  LD   A,_FULLSTOP                        ; Insert the maze code for a Trail at the previous player position.
        LD   (DE),A

        LD   (L4088),HL                         ; Save the address of the player within the maze.

        LD   B,$07                              ; Repeat the fight sequence 7 times.

L4E32:  PUSH BC                                 ; Save the fight loop counter.

        LD   (HL),_F                            ; Insert maze code Fighting 1.
        CALL L4E56                              ; Render the screen of sprites at the current player position.

        LD   (HL),_X                            ; Insert maze code Mazog with Eyes Open.
        CALL L4E56                              ; Render the screen of sprites at the current player position.

        LD   (HL),_G                            ; Insert maze code Fighting 2.
        CALL L4E56                              ; Render the screen of sprites at the current player position.

        LD   (HL),_INVX                         ; Insert maze code Mazog with Eyes Closed.
        CALL L4E56                              ; Render the screen of sprites at the current player position.

        LD   (HL),_H                            ; Insert maze code Fighting 3.
        CALL L4E56                              ; Render the screen of sprites at the current player position.

        LD   (HL),_X                            ; Insert maze code Mazog with Eyes Open.
        CALL L4E56                              ; Render the screen of sprites at the current player position.

        POP  BC                                 ; Retrieve the fight loop counter.
        DJNZ L4E32                              ; Repeat for all fight cycles.

        JR   L4E5C                              ; Jump ahead to continue.

; --------------------------------------
; Display Sprites Around Player Position
; --------------------------------------
; This routine populates the display file with the sprites corresponding to the maze codes around the player position within the maze.

L4E56:  PUSH HL
        CALL L48AA                              ; Render the screen of sprites at the current player position.
        POP  HL
        RET  

; -----------------------------------
; Player Fighting a Mazog (Continued)
; -----------------------------------

L4E5C:  LD   A,(L4B10)                          ; Does the player have a sword?
        CP   $00
        JR   Z,L4E83                            ; Jump if not.

; The player has a sword, so the player has won the fight. The mazog that has been killed
; must be identified and removed from the maze.

L4E63:  LD   (HL),_1                            ; Insert maze code for Standing. [*BUG* This should call $4CA6
                                                ; to check whether the player is holding the treasure]
        PUSH HL
        POP  DE                                 ; Transfer the player location to DE.

        LD   A,E                                ; The low byte of the player location.

        LD   HL,L4DD5                           ; The mazog location table.

; Enter a loop to determine which mazog the player is fighting.

L4E6B:  CP   (HL)                               ; Does the low byte match?
        JR   Z,L4E72                            ; Jump if so.

; The player is not at the same location as this mazog, so try the next one.

        INC  HL                                 ; Point to the next mazog table entry.
        INC  HL
        JR   L4E6B                              ; Jump back to test the next entry.

; The low byte matched.

L4E72:  INC  HL                                 ; Advance to the high byte.

        LD   A,D                                ; The high byte of the player location.
        CP   (HL)                               ; Does the high byte match?
        JR   Z,L4E7B                            ; Jump if so.

; The high byte did not match.

        INC  HL                                 ; Point to the next mazog table entry.
        LD   A,E                                ; Fetch the low byte of the player location.
        JR   L4E6B                              ; Jump back to test the next entry.

; The mazog the player collided with has been identified.

L4E7B:  LD   (HL),$FF                           ; Set the mazog outside the maze, i.e. remove it from the maze since it has been killed.

        LD   A,$00
        LD   (L4B10),A                          ; Signal the player does not have a sword.
        RET  

; The player does not have a sword
; --------------------------------

L4E83:  PUSH HL
        CALL L4092                              ; Generate a random 8-bit number based upon the frames counter.
        CALL L40B4                              ; Split the random number into four equal ranges.
        POP  HL

; There is a 50:50 chance that the player will win the fight.

        CP   $01                                ; If the random value was 0%-25%?
        JR   Z,L4E63                            ; Jump if so as the player has won the fight.

        CP   $03                                ; If the random value was 50%-75%?
        JR   Z,L4E63                            ; Jump if so as the player has won the fight.

; The mazog has won.

        LD   (HL),_X                            ; Insert maze code for a Mazog with Eyes Open.

; Update the screen rapidly so that the mazog appears manic with fast moving legs and blinking eyes.

        LD   B,$19                              ; Victory cycle count.

L4E97:  PUSH BC
        CALL L4E56                              ; Render the screen of sprites at the current player position. This routine toggles between the mazog animation frames.
        POP  BC
        DJNZ L4E97                              ; Repeat for all victory cycles.

        LD   A,$01
        LD   (L4B18),A                          ; Signal the mazog killed the player.
        RET  

; ------
; Unused
; ------

L4EA4:  NOP     

; ------------------------------------------------------------
; Insert Mazogs, Swords and Prisoners Randomly Within the Maze
; ------------------------------------------------------------
; Mazogs can only be placed at empty locations. Swords and prisoners can only be placed where there is an internal wall.
; No items are placed next to an external wall.

; Insert swords at random locations within the maze.

L4EA5:  LD   A,(L4E28)                          ; Fetch the number of swords.
        LD   B,A

L4EA9:  PUSH BC                                 ; Save the sword counter.

        CALL L4F0C                              ; Select a random location within the maze that contains an internal wall.
        LD   (HL),_INVS                         ; Insert the sword.

        POP  BC                                 ; Retrieve the sword counter.
        DJNZ L4EA9                              ; Repeat for all swords.

; Insert prisoners at random locations within the maze.

        LD   A,(L4E29)                          ; Fetch the number of prisoners.
        LD   B,A

L4EB6:  PUSH BC                                 ; Save the prisoner counter.

        CALL L4F0C                              ; Select a random location within the maze that contains an internal wall.
        LD   (HL),_INVP                         ; Insert the prisoner with eyes open.

        POP  BC                                 ; Retrieve the prisoner counter.
        DJNZ L4EB6                              ; Repeat for all prisoners.

        NOP     

; Determine random locations within the maze for the mazogs. The addresses of the mazogs are placed within the mazogs table
; rather than codes the mazogs inserted with the maze (this is done afterwards).
; The routine will only locate a mazog at the position of an empty location within the maze. Note that there is nothing to
; prevent multiple mazogs being placed at the same location.

        LD   HL,L4DD5                           ; The mazog location table.
        LD   A,(L4E27)                          ; Fetch the number of mazogs.
        LD   B,A

L4EC7:  PUSH BC                                 ; Save the mazog counter.
        PUSH HL                                 ; Save the mazog table entry pointer.

L4EC9:  CALL L4F27                              ; Select a random location within the maze.

        LD   A,(HL)                             ; Fetch the contents from the selected maze location.
        CP   _SPACE                             ; Is it an empty location?
        JR   NZ,L4EC9                           ; Jump back if not to select a different location.

; An empty location has been found where the mazog can be placed.

        DEC  HL                                 ; Point to the location to the left of the select position.
        LD   A,(HL)
        CP   _CHEQUERBOARD                      ; Is there an external wall to the left?
        JR   Z,L4EC9                            ; Jump if so to select another location.

        INC  HL                                 ; Point to the location to the right of the select position.
        INC  HL
        LD   A,(HL)
        CP   _CHEQUERBOARD                      ; Is there an external wall to the right?
        JR   Z,L4EC9                            ; Jump if so to select another location.

; The location is not next to an external wall.

        POP  HL                                 ; Retrieve the mazog table entry pointer.
        LD   (HL),E
        INC  HL
        LD   (HL),D                             ; Save the random maze location into the mazog table.

        INC  HL                                 ; Advance to the next table entry position.

        POP  BC                                 ; Retrieve the mazog counter.
        DJNZ L4EC7                              ; Repeat for all mazogs.

        NOP     

; -----------------
; Insert All Mazogs
; -----------------
; This routine inserts all alive mazogs into the maze. It is used from above to insert the mazogs for the first time,
; and also after clearing the maze when calculating the distance to the treasure/exit. It is called repeatedly from
; the main loop and if the mazog codes are already in the maze then they are simply overwritten, causing no change.
; It is also used when examining the maze at the end of the game after clearing the maze and then populating the route
; to the treasure.

L4EE7:  LD   A,(L4E27)                          ; Fetch the number of mazogs.
        LD   B,A
        LD   DE,L4DD5                           ; The mazog location table.

L4EEE:  LD   A,(DE)                             ; Fetch the low address of the mazog.
        LD   L,A

        INC  DE                                 ; Point to the high address byte.

        LD   A,(DE)                             ; Fetch the high address of the mazog.
        LD   H,A

        INC  DE                                 ; Point to the next table entry.

        CP   $FF                                ; Has this mazog been killed?
        JR   Z,L4F03                            ; Jump ahead if so.

        LD   A,(HL)                             ; Fetch the mazog sprite.
        CP   _INVX                              ; Does the mazog have its eyes closed?
        JR   Z,L4F01                            ; Jump ahead if so.

        LD   (HL),_X                            ; Insert the maze code for a mazog with eyes open.
        JR   L4F03                              ; Jump ahead to continue.

L4F01:  LD   (HL),_INVX                         ; Insert the code for a mazog with eyes closed.

L4F03:  DJNZ L4EEE                              ; Repeat for all mazogs.

        RET  

; ------
; Unused
; ------

L4F06:  DEFB $00, $00, $00, $00, $00, $00

; ----------------------------------------------------
; Select Random Maze Location Containing Internal Wall
; ----------------------------------------------------
; This routine is used when selecting the locations to place swords and prisoners within the maze.
; It prevents placing a sword or prisoner next to an external wall.
; Exit HL=Maze location.

L4F0C:  NOP     
        NOP     
        NOP     
        NOP     

        CALL L4F27                              ; Select a random location within the maze.

        LD   A,(HL)                             ; Fetch the contents of the location.
        CP   _BLACK                             ; Is it an internal wall?
        JR   NZ,L4F0C                           ; Jump back if not to select another location.

; It is an internal wall.

        DEC  HL                                 ; Point to the location to the left of the selection position.
        LD   A,(HL)                             ; Fetch the contents of the location.
        CP   _CHEQUERBOARD                      ; Is it an external wall?
        JR   Z,L4F0C                            ; Jump to select another location if an external wall was to the left.

        INC  HL                                 ; Point to the location to the right of the selection position.
        INC  HL
        LD   A,(HL)                             ; Fetch the contents of the location.
        CP   _CHEQUERBOARD                      ; Is it an external wall?
        JR   Z,L4F0C                            ; Jump to select another location if an external wall was to the right.

        DEC  HL                                 ; Point back to the selected location.
        RET  

; ---------------------------
; Select Random Maze Location
; ---------------------------
; This routine selects a random location within the maze by choosing a random 8-bit number, multiplying it by 11,
; and offsetting into the maze from the first row that can contain empty location (i.e. the 3rd row). This means that
; not all positions within the maze can be returned, but they are uniformly distributed throughout the maze.
; Exit: DE=Random location within the maze.
;       HL=Same random location within the maze.

L4F27:  NOP

        LD   A,(L4090)                          ; Fetch the re-seed counter.
        INC  A                                  ; Increment the timer.
        LD   (L4090),A                          ; Save the new timer value.

        CP   $AD                                ; Time to re-seed?
        CALL Z,L4092                            ; If so then generate a random 8-bit number based upon the frames counter.

        CALL L4098                              ; Generate a new random 8-bit number.

        LD   D,$00
        LD   E,A                                ; Transfer the random number to DE.

; Now multiply the random number by 11, by adding the number to itself 10 times.

        PUSH DE
        POP  HL                                 ; Transfer the random number to HL, which will hold the total.

        LD   B,$0A                              ; Addition counter.

L4F3E:  ADD  HL,DE                              ; Add the random number to the total.
        DJNZ L4F3E                              ; Repeat to for all additions.

        LD   DE,(L408D)                         ; Fetch the address of the maze.
        ADD  HL,DE                              ; Offset into the maze.

        LD   DE,$0080                           ; Two rows of the maze. The maze contains an external wall (chequerboard) and
        ADD  HL,DE                              ; inside this an inner wall (black).

; The multiplication by 11 performed above distributes the random number throughout the maze.
; The maze is 48 rows by 64 columns = 3072 positions. The top and bottom rows are external walls, and the
; next inner rows are always internal walls. Assuming the maze coordinates are 0 index based then the rows
; spans 0 to 47, and the first row that can contains game characters is row 2 and the last is row 45.
; The distribution range is:
; 0   x 11 = 0               => (0, 0)
; 255 x 11 = 2805 = 43 re 53 => (45, 53)

        PUSH HL
        POP  DE                                 ; Return the random location within the maze in DE.
        RET  

; ----------------------------
; Unused - Remains of REM line
; ----------------------------

        DEFB _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP
        DEFB _FULLSTOP

; -------------------
; Mazog Mobility Flag
; -------------------

L4F56:  DEFB $01                                ; Mazog mobility flag ($00=Moving, $01=Static). This flag is initialised from BASIC.

; ---------------
; Move All Mazogs
; ---------------

L4F57:  NOP
        NOP
        NOP  

        CALL L4EE7                              ; Insert all mazogs into the maze (in case previously removed when determining the way to the treasure/exit).

        LD   A,(L4B0C)                          ; Does the game include a countdown?
        CP   $01
        JP   Z,L4B27                            ; Jump if not to repeat the main program loop.

; The game includes a countdown.

        LD   A,$00
        LD   (L4E26),A                          ; Initialise the mazog table offset to the first entry.

        LD   A,(L4E27)                          ; Fetch the number of mazogs.
        LD   B,A

; Enter a loop to move all mazogs.

L4F6E:  PUSH BC                                 ; Save the mazog counter.

        LD   HL,L4DD5                           ; The mazog location table.

        LD   A,(L4E26)                          ; Fetch the next mazog table entry offset.
        LD   B,$00
        LD   C,A                                ; BC=Mazog table entry offset.

        INC  A
        INC  A                                  ; Advance the mazog table offset to the next entry.
        LD   (L4E26),A                          ; Save the new offset.

        ADD  HL,BC                              ; Point to the entry within the table.

        LD   E,(HL)
        INC  HL
        LD   D,(HL)                             ; Fetch the location of the mazog within the maze.

        PUSH HL                                 ; Save the address of the mazog table entry.

        LD   A,D
        CP   $FF                                ; Has the mazog been killed?
        JR   Z,L4FDC                            ; Jump ahead if so to move the next mazog.

; Now check whether the player is to the left or right. A check if not perform above or below and so
; a moving mazog will never jump on the player in these directions.

        PUSH DE                                 ; Transfer the mazog position to HL.
        POP  HL

        DEC  HL                                 ; The position to the left.

        CALL L5003                              ; Has the mazog collided with the player?
        JR   Z,L4FE3                            ; Jump if so.

        INC  HL                                 ; Reverse the decrement above.
        INC  HL                                 ; The position to the right.

        CALL L5003                              ; Has the mazog collided with the player?
        JR   Z,L4FE3                            ; Jump if so.

; The mazog has not collided with the player.

        LD   A,(L4F56)                          ; Fetch the mazogs mobility flag.
        CP   $01                                ; Can the mazogs move?
        JR   Z,L4FDC                            ; Jump ahead if they cannot.

; The mazogs can move.

        LD   A,(L4090)                          ; Fetch the re-seed timer.
        INC  A                                  ; Increment the timer.
        LD   (L4090),A                          ; Save the new timer value.

        CP   $D9                                ; Is it time to re-seed the random number generator?
        CALL Z,L500D                            ; If so then generate a new random number based upon the frames counter.

        CALL L4098                              ; Generate a random 8-bit number.
        CALL L40B4                              ; Split the random number into four equal ranges.

        PUSH DE                                 ; Transfer the mazog position to HL.
        POP  HL

        CP   $02                                ; Was it 25%-50%?
        JR   Z,L4FC0                            ; Jump if so to move to the right.

        CP   $03                                ; Was it 50%-75%?
        JR   Z,L4FC3                            ; Jump if so to move down.

        CP   $04                                ; Was it 75%-100%?
        JR   Z,L4FC9                            ; Jump if so to move up.

; Move the mazog to the left.

        DEC  HL                                 ; Point to the position to the left.
        JR   L4FCF                              ; Jump ahead to continue.

; Move the mazog to the right.

L4FC0:  INC  HL                                 ; Point to the position to the right.
        JR   L4FCF                              ; Jump ahead to continue.

; Move the mazog down.

L4FC3:  LD   BC,$0040                           ; The width of the maze.
        ADD  HL,BC                              ; Point to the position below.
        JR   L4FCF                              ; Jump ahead to continue.

; Move the mazog up.

L4FC9:  LD   BC,$0040                           ; The width of the maze.
        AND  A
        SBC  HL,BC                              ; Point to the position above.

; All paths converge here after moving the mazog.

L4FCF:  LD   A,(HL)                             ; Fetch the maze code at the new location.

        CP   _FULLSTOP                          ; Is it a Trail?
        JR   Z,L4FF6                            ; Jump ahead if so.

        CP   _ASTERISK                          ; Is it 'This Way'?
        JR   Z,L4FF6                            ; Jump ahead if so.

        CP   _SPACE                             ; Is it an empty location?
        JR   Z,L4FF6                            ; Jump ahead if so.

; The new location is already occupied and so the mazog cannot be moved there.
; Joins here for static mazogs.

L4FDC:  POP  HL                                 ; Discard the address of the mazog table entry.

L4FDD:  POP  BC                                 ; Retrieve the mazog counter.
        DJNZ L4F6E                              ; Loop back for all mazogs.

; All mazogs have been moved.

        JP   L4B27                              ; Jump to repeat the main program loop.

; The Mazog has moved left or right and collided with the player
; --------------------------------------------------------------

L4FE3:  LD   A,$00
        LD   (L4B13),A                          ; Signal not in View mode.

        EX   DE,HL                              ; Transfer the mazog position to DE.
        CALL L4E2A                              ; Perform a fight between the player and a mazog.

        LD   A,(L4B18)                          ; Has the player been killed by a mazog?
        CP   $00
        JR   Z,L4FDC                            ; Jump if not.

; The player has been killed by a mazog.

        POP  HL                                 ; Discard the address of the mazog table entry.
        POP  BC                                 ; Discard the mazog counter.
        RET  

; The mazog has moved into a location that is empty or contains a Trail or 'This Way'
; -----------------------------------------------------------------------------------

L4FF6:  LD   (HL),_X                            ; Insert the mazog with eyes open at the new maze location.

        LD   A,_SPACE
        LD   (DE),A                             ; Clear the old mazog location within the maze.

        PUSH HL
        POP  DE                                 ; Transfer the new maze location to DE.

        POP  HL                                 ; Retrieve the address of the mazog table entry.

        LD   (HL),D
        DEC  HL
        LD   (HL),E                             ; Replace the mazog table entry with the mazog's new maze location.

        JR   L4FDD                              ; Jump to move the next mazog.

; ---------------------------------
; Test Whether Collided with Player
; ---------------------------------
; Entry: HL=Location to test.
; Exit : Zero flag set if collided.

L5003:  PUSH HL

        LD   BC,(L4088)                         ; Fetch the address of the player within the maze.
        AND  A
        SBC  HL,BC                              ; Is the player at the test location?

        POP  HL
        RET  

; ---------------------
; Reset Re-Seed Counter
; ---------------------

L500D:  LD   A,$00
        LD   (L4090),A                          ; Reset the re-seed counter.

        CALL L4092                              ; Generate a random 8-bit number based upon the frames counter.
        RET  

; --------------------------------
; Reset Re-Seed Counter (Not Used)
; --------------------------------

L5016:  LD   A,$00
        LD   (L4090),A                          ; Reset the re-seed counter.

        CALL L4092                              ; Generate a random 8-bit number based upon the frames counter.
        RET  

; ----------------------------
; Unused - Remains of REM line
; ----------------------------

L501F:  DEFB _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP

; ---------------------------
; Insert Entrance Passageways
; ---------------------------
; The entrance/exit is located at row 19,63 (entering left) or 20,0 (entering right).
; A sword is always placed immediately above the player. An internal wall is placed
; left and right of the sword.

L5023:  LD   A,_BLACK                           ; Maze code for an internal wall.
        LD   HL,(L408D)                         ; Fetch the address of the maze.
        LD   BC,$04FF                           ; Offset to row 19 column 63.
        ADD  HL,BC
        LD   (HL),A                             ; Store an internal wall.

        INC  HL                                 ; Advance to the position to the right.
        LD   (HL),_INVS                         ; Insert a sword.

        LD   BC,$007F                           ; Offset to row 21 column 63.

        ADD  HL,BC

        LD   (HL),A                             ; Insert an internal wall.
        INC  HL                                 ; Advance to the position to the right.
        LD   (HL),A                             ; Insert an internal wall.

        CALL L5057                              ; Move to the same column in the row above.
        LD   (L4088),HL                         ; Save the address of the starting position of the player within the maze.

; A passage way has been inserted between the left and right sides of the maze. The top of the passageway
; contains an internal wall followed by a sword. The bottom of the passageway contains two internal walls.
; The player is placed in the passageway below the sword.

        LD   A,_SPACE                           ; The maze code for an empty location.

; Enter a loop to create a passageway into the maze to the left.

L503F:  LD   (HL),A                             ; Insert an empty location.

        PUSH HL
        POP  DE                                 ; Transfer the maze position to DE.

        DEC  HL                                 ; Point to the position to the left.
        CP   (HL)                               ; Is it empty?
        JR   Z,L5065                            ; Jump ahead if so.

; The position to the left is not empty.

        CALL L5057                              ; Move to the same column in the row above.
        CP   (HL)                               ; Is it empty?
        JR   Z,L5063                            ; Jump ahead if so.

; The position above-left is not empty.

        CALL L505E                              ; Move to the same column two rows below, i.e. one row below the original row.
        CP   (HL)                               ; Is it empty?
        JR   Z,L5063                            ; Jump ahead if so.

; The position below-left is not empty.

        PUSH DE
        POP  HL                                 ; Transfer the maze position to HL.

        DEC  HL                                 ; Point to the position to the left.
        JR   L503F                              ; Jump back to insert an empty location at the left position.

; --------------------
; Advance to Row Above
; --------------------
; Entry: HL=Maze position.
; Exit : HL=Maze position in the row above.

L5057:  LD   BC,$0040                           ; Advance to the same column position in the row above.
        AND  A
        SBC  HL,BC
        RET  

; ----------------------
; Advance Two Rows Below
; ----------------------
; Entry: HL=Maze position.
; Exit : HL=Maze position two rows below.

L505E:  LD   BC,$0080                           ; Advance to the same column two rows below.
        ADD  HL,BC
        RET  

; ---------------------------------------
; Insert Entrance Passageways (Continued)
; ---------------------------------------

; The maze location above-left or below-left is empty, so insert an empty location above or below to
; link up with the above-left or below-left empty location.

L5063:  INC  HL                                 ; Advance to the current column position.
        LD   (HL),A                             ; Insert an empty location to link to the empty diagonal position.

; Joins here when the maze location to the left is empty

L5065:  LD   HL,(L4088)                         ; Fetch the address of the player within the maze.

; Enter a loop to create a passageway into the maze to the right.

L5068:  LD   (HL),A                             ; Insert an empty location.

        PUSH HL
        POP  DE                                 ; Transfer the maze position to DE.

        INC  HL                                 ; Point to the position to the right.
        CP   (HL)                               ; Is it empty?
        JR   Z,L5082                            ; Jump ahead if so.

; The position to the right is not empty.

        CALL L5057                              ; Move to the same column in the row above.
        CP   (HL)                               ; Is it empty?
        JR   Z,L5080                            ; Jump ahead if so.

; The position above-right is not empty.

        CALL L505E                              ; Move to the same column two rows below, i.e. one row below the original row.
        CP   (HL)                               ; Is it empty?
        JR   Z,L5080                            ; Jump ahead if so.

; The position below-right is not empty.

        PUSH DE
        POP  HL                                 ; Transfer the maze position to HL.

        INC  HL                                 ; Point to the position to the right.
        JR   L5068                              ; Jump back to insert an empty location at the right position.

; The maze location above-right or below-right is empty, so insert an empty location above or below to
; link up with the above-right or below-right empty location.

L5080:  DEC  HL                                 ; Point back to the current column position.
        LD   (HL),A                             ; Insert an empty location.

; Joins here when the maze location to the right is empty.

L5082:  LD   HL,(L4088)                         ; Fetch the address of the starting location for the player within the maze.
        LD   (HL),_1                            ; Insert maze code for 'Player Standing'.
        RET  

; ----------------------------
; Unused - Remains of REM line
; ----------------------------

L5088:  DEFB $00, $00, $00, $00, $00
        DEFB _FULLSTOP, _FULLSTOP, _FULLSTOP

; -----------------
; Program Variables
; -----------------
; These program variables are used by the by the routine at $50E5, but that routine is never called by the game.

L5090:  DEFB $00                                ; Leading zero flag ($00=Leading zero, $01=Within number) when displaying the number of moves remaining.
L5091:  DEFW $2710                              ; Divisor (used by routine at L5116).
L5093:  DEFW $03C8                              ; Temporarily stores the dividend before storing the remainder (used by routine at L5116).
L5095:  DEFW $6F09                              ; Temporarily holds the display file address when displaying the number of moves remaining.

; -----------------------------------------------
; Decrement Countdown Timer and Delay 0.3 Seconds
; -----------------------------------------------

L5097:  LD   A,$00
        LD   (L5090),A                          ; Signal treat any zeros as leading zeros.

        LD   A,(L4B0C)                          ; Does the game include a moves remaining countdown?
        CP   $01
        RET  Z                                  ; Return if not.

; The game includes a moves remaining countdown.

        LD   HL,(L4B0E)                         ; Fetch the moves remaining counter.
        PUSH HL                                 ; Save it.

        LD   A,(L4B13)                          ; In View mode?
        CP   $01
        JR   Z,L50BC                            ; Jump ahead if so.

; Not in View mode.

        LD   BC,$0000
        AND  A
        SBC  HL,BC                              ; Has the moves remaining counter expired?
        JR   NZ,L50DF                           ; Jump ahead if not.

; The moves remaining counter has expired.

        LD   A,$01
        LD   (L4B14),A                          ; Signal that the player has starved to death.

L50BA:  JR   L50D7                              ; Jump ahead to keep the existing countdown timer value.

; In View mode.

L50BC:  LD   A,(L4B19)                          ; Fetch the View cost.
        LD   B,$00
        LD   C,A                                ; Transfer the View cost to BC.
        DEC  HL                                 ; Ensure that decrementing the moves remaining counter to 0 is treated as a roll over.
        AND  A
        SBC  HL,BC                              ; Apply the View cost to the moves remaining countdown.
        JP   M,L50D7                            ; Jump if the moves remaining countdown has rolled over (i.e. negative) to keep the existing countdown value.

; The moves remaining countdown does not go negative if the View cost is applied so proceed to apply it.

        POP  HL                                 ; Retrieve the existing moves remaining counter value.
        AND  A
        SBC  HL,BC                              ; Decrement the moves remaining to pay for the View.
        JR   L50D8                              ; Jump ahead to store the new moves remaining counter.

; The following is not used
; -------------------------

L50D0:  LD   BC,$0000
        AND  A
        SBC  HL,BC
        JR   Z,L50D7

; The timer has rolled over (i.e. negative)
; -----------------------------------------

L50D7:  POP  HL                                 ; Retrieve the moves remaining countdown.

L50D8:  LD   (L4B0E),HL                         ; Store the new moves remaining countdown.
        CALL L426D                              ; Delay 0.3 seconds.
        RET

; The moves remaining countdown has not expired.

L50DF:  POP  HL                                 ; Retrieve the moves remaining countdown.
        DEC  HL                                 ; Decrement the move remaining counter.
        JR   L50D8                              ; Jump to store the new moves remaining countdown.

; ------
; Unused
; ------

L50E3:  NOP     
        NOP     

; ----------------------------------
; Display Moves Remaining (Not Used)
; ----------------------------------

L50E5:  LD   HL,(D_FILE)                        ; Fetch the address of the display file.
        LD   BC,$002E                           ; Offset to location row 1, column 13.
        ADD  HL,BC
        LD   (L5095),HL                         ; Store the display file location address.

        LD   BC,(L4B0E)                         ; Fetch the moves remaining countdown.
        LD   (L5093),BC                         ; Store it as the dividend.

        LD   BC,$2710                           ; Divisor=10000.
        CALL L5116                              ; Display the dividend in the display file.

        LD   BC,$03E8                           ; Divisor=1000.
        CALL L5116                              ; Display the dividend in the display file.

        LD   BC,$0064                           ; Divisor=100.
        CALL L5116                              ; Display the dividend in the display file.

        LD   BC,$000A                           ; Divisor=10.
        CALL L5116                              ; Display the dividend in the display file.

        LD   BC,$0001                           ; Divisor=1.
        CALL L5116                              ; Display the dividend in the display file.
        RET  

; ------------------------
; Display Number of Digits
; ------------------------
; This routine divides the value in $5093 by the divisor passed in BC and inserts the result in the display file.
; The routine only works correctly for the edition 1 ZX81 ROM. For the edition 2 ROM the call to $151C will not
; store BC on the calculator stack but will perform:
; - INC E
; - LD  C,A
; - LD  B,$00
; - Run into $1520 which will stack BC.
; It will therefore store A on the calculator stack rather than BC and so will insert an incorrect result in the display file.
;
; Entry: BC=Divisor.
;        ($5093)=Dividend.
; Exit : ($5093)=Remainder.
;        BC=Quotient*Divisor.

L5116:  NOP

        LD   (L5091),BC                         ; Store the divisor.

        LD   BC,(L5093)                         ; Fetch the dividend.
        CALL $151C                              ; Stack it via a call to STACK-BC (equivalent to $1520 in the edition 2 ROM).

        LD   BC,(L5091)                         ; Fetch the divisor.
        CALL $151C                              ; Stack it via a call to STACK-BC (equivalent to $1520 in the edition 2 ROM).

        RST  28H                                ; Start the floating point calculator.
        DEFB $05                                ; Division.
        DEFB $24                                ; Int.
        DEFB $34                                ; Exit.

; The stack holds: Int(dividend/divisor).

        CALL $0EA7                              ; Fetch the result to BC via a call to FIND-INT (same address for both edition ROMs, an error report B occurs if out of range).

        LD   A,C                                ; Fetch the quotient of the division.
        ADD  A,_0                               ; Convert to a hex character representation, i.e. '0'-'F'.
        CALL L5150                              ; Insert character into the display file.

        CALL $151C                              ; Re-stack the integer result via a call to STACK-BC (equivalent to $1520 in the edition 2 ROM).

        LD   BC,(L5091)                         ; Fetch the divisor.
        CALL $151C                              ; Stack it via a call to STACK-BC (equivalent to $1520 in the edition 2 ROM).

        RST  28H                                ; Start the floating point calculator.
        DEFB $04                                ; Multiply.
        DEFB $34                                ; Exit.

; The stack holds: result=Int(dividend/divisor)*divisor.

        CALL $0EA7                              ; Fetch the result to BC via a call to FIND-INT (same address for both edition ROMs, an error report B occurs if out of range).

        LD   HL,(L5093)                         ; Fetch the dividend.
        AND  A
        SBC  HL,BC                              ; remainder = dividend - result.

        LD   (L5093),HL                         ; Store the remainder.
        RET  

; ------------------------------------------------
; Display Number Character Filtering Leading Zeros
; ------------------------------------------------
; Entry: A=Character representation of a value.

L5150:  NOP     

        LD   HL,(L5095)                         ; Fetch the display file address.

        CP   _0                                 ; Is the value '0'?
        JR   Z,L5160                            ; Jump ahead if so.

; The character is non-zero.

        PUSH AF                                 ; Save the character.

        LD   A,$01
        LD   (L5090),A                          ; Signal within the number.

        JR   L516D                              ; Jump ahead to insert the character into the display file.

; The character is zero.

L5160:  PUSH AF                                 ; Save the character code.

        LD   A,(L5090)                          ; Is this a leading zero?
        CP   $01
        JR   Z,L516D                            ; Jump ahead if not to insert the character into the display file.

; It is a leading zero.

        POP  AF                                 ; Discard the character code.

        LD   (HL),_INVCHEQUERBOARD              ; Display the background character instead.
        JR   L516F                              ; Jump ahead to advance t the next display file column.

; It is not a leading zero.

L516D:  POP  AF                                 ; Retrieve the character code.
        LD   (HL),A                             ; Insert into the display file.

L516F:  INC  HL                                 ; Advance to the next column within the display file.
        LD   (L5095),HL                         ; Save the new display file address.
        RET  

; ------
; Unused
; ------

L5174:  DEFB $C9, $C9

; ----------------------------
; Unused - Remains of REM line
; ----------------------------

L5176:  DEFB _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP

; ------------
; Display View
; ------------
; This routine displays a 16 by 16 area of the maze centred around the player.

L517C:  LD   HL,(D_FILE)                        ; Fetch the address of the display file.
        LD   BC,$008D                           ; Offset to location row 4, column 8.
        ADD  HL,BC

        PUSH HL
        POP  DE                                 ; Transfer the display file location to DE.

        LD   HL,(L4088)                         ; Fetch the address of the player within the maze.
        LD   BC,$0208                           ; Offset 8 rows up and 8 columns to the left.
        AND  A
        SBC  HL,BC                              ; Calculate the location of the top left position within the view.

        LD   B,$10                              ; There are 16 rows in the view.

; Enter a loop to display each row within the view.

L5190:  PUSH BC                                 ; Save the row counter.

        LD   B,$10                              ; The are 16 columns in the view.

; Enter a loop to display each column within a row of the view.

L5193:  PUSH BC                                 ; Save the column counter.
        PUSH HL                                 ; Save the location within the maze.

        LD   BC,(L408D)                         ; Fetch the start address of the maze.
        AND  A
        SBC  HL,BC                              ; Is the location before the start of the maze?
        JP   M,L51C7                            ; Jump if it is.

; The location is not before the start of the maze.

        PUSH BC                                 ; Transfer the start address of the maze to HL.
        POP  HL

        LD   BC,$0C00                           ; The size of the maze (48 rows by 64 columns).
        ADD  HL,BC                              ; HL=Location after the maze.
        PUSH HL
        POP  BC                                 ; Transfer the location after the maze to BC.

        POP  HL                                 ; Retrieve the location within the maze.
        PUSH HL

        AND  A
        SBC  HL,BC                              ; Is the location after the maze?
        JP   P,L51C7                            ; Jump ahead if it is.

; The location is within the maze.

        POP  HL                                 ; Retrieve the maze location.
        LD   A,(HL)                             ; Fetch the maze code from the maze.
        LD   (DE),A                             ; Insert the maze code into the display file.

; Advance to the next column position.

L51B2:  INC  HL                                 ; Advance to the next maze location.
        INC  DE                                 ; Advance to the next display file position.

        POP  BC                                 ; Retrieve the view column counter.
        DJNZ L5193                              ; Repeat for all columns within this row of the view.

; A row of the view has been displayed.

        LD   BC,$0030                           ; Offset to the starting column within the next row of the maze.
        ADD  HL,BC
        PUSH HL                                 ; Save the new address within the maze [redundant].

        EX   DE,HL                              ; HL=Display file address, DE=New maze location.
        LD   BC,$0011                           ; Advance to the next display file row.
        ADD  HL,BC
        EX   DE,HL                              ; HL=New maze location, DE=New display file address.

        POP  HL                                 ; Retrieve the new address within the maze [redundant].

        POP  BC                                 ; Retrieve the view row counter.
        DJNZ L5190                              ; Repeat for all rows within the view.

        RET  

; The location is outside the maze so display as an internal wall.

L51C7:  POP  HL                                 ; Retrieve the location within the maze.

        LD   A,_BLACK                           ; Insert an internal wall into the display file.
        LD   (DE),A
        JR   L51B2                              ; Jump to advance to the next column position.

; ------------------------------------------------------------------------------------------------------------------------------------------------------

; ----------------------------
; Unused - Remains of REM line
; ----------------------------

L51CD:  DEFB _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP, _FULLSTOP
        DEFB _FULLSTOP, _FULLSTOP

; ------------------------------------------------------------------------------------------------------------------------------------------------------

; -------------------
; End of BASIC Line 1
; -------------------

L51D7:  DEFB _NEWLINE

; ======================================================================================================================================================

; =============
; BASIC Program
; =============

; ---------
; Copyright
; ---------

;    2 REM
;    3 REM
;    4 REM MAZOGS (C)1981 BUG-BYTE
;    5 REM AUTHOR: DON PRIESTLEY
;    6 REM
;    7 REM
;    8 REM

; --------------
; Initialisation
; --------------

;  108 LET MST=29450                                                    ; Holds the address of the maze.
;  110 LET MDR=6100                                                     ; Holds the line number of the maze design routine.
;  112 LET BB=6030                                                      ; BASIC subroutine that toggles the maze codes and then draw sprites on a black background.
;  114 LET SUR=6052                                                     ; BASIC subroutine that fills the display with inverse chequerboard.
;  116 LET C=2                                                          ; Column number when displaying information.
;  120 LET POKE=6000                                                    ; BASIC subroutine that performs a double poke to address AD with value N.
;  122 LET INK=6060                                                     ; BASIC subroutine that waits until a key is not being pressed.
;  124 LET T=2000                                                       ; BASIC subroutine that displays the title screen. [Not used]
;  126 LET PR=6070                                                      ; BASIC subroutine that toggles the maze codes and then displays sprites around the current player location.
;  128 LET CT=6080                                                      ; BASIC subroutine that calculate distance to the treasure or exit.

;  198 POKE 19273,254                                                   ; Set the View timeout threshold.

;  200 LET AD=16525                                                     ; The address of the program variable that will hold the address of the maze.
;  202 LET N=MST                                                        ; Fetch the address of the maze.
;  204 GOSUB POKE                                                       ; Store the address of the maze.

;  206 POKE 19217,0                                                     ; Indicate not holding the treasure.

;  208 FOR A=19892 TO 19894                                             ; Clear the CALL $4DB4 inserted to slow down the game play when playing TRY IT OUT.
;  210 POKE A,0
;  212 NEXT A

;  214 POKE 17370,136                                                   ; The character used fill the screen when BASIC subroutine at 6050 is called.
;  216 POKE 18810,0                                                     ; Set the low byte of the program variable holding the address of the treasure relocated within the maze.

;  250 GOTO 2000                                                        ; Jump ahead to continue.

; ----------------
; Examine the Maze
; ----------------

; 1000 LET TD=PEEK 18810+PEEK 18811*256                                 ; Fetch the relocation address of the treasure.
; 1002 IF PEEK TD=57 OR PEEK TD=185 THEN POKE TD,151                    ; If the treasure has been relocated then replace it ['t' or 'T'] with an inverse asterisk.

; 1006 LET POS=PEEK 16520+256*PEEK 16521                                ; Fetch the location of the player.
; 1010 LET X=MST

; Enter a loop to scroll around the maze. The maze is scrolled by changing the location that holds the
; start address. Normally this points at the very top-left position of the maze but adjusting this program
; variable to point at another position within the maze means that when the maze draw routine is called the
; maze will be drawn from the specified offset position and so will appear to have scrolled.

; 1020 POKE 16525,X-INT (X/256)*256                                     ; Set the address of the start of the maze, i.e. the top-left position.
; 1022 POKE 16526,INT (X/256)

; 1030 RAND USR 17310                                                   ; Display a screenful of the maze.

; 1040 LET K$=INKEY$                                                    ; Read the keyboard.
; 1050 LET X=X+(K$="J")-(K$="H")+(K$="S")*64-(K$="W")*64                ; Determine the new top-left offset position, which includes traps to
;             +(X<MST)*64-(X>MST+1568)*64                               ; prevent scrolling outside the maze.

; 1052 IF K$="P" THEN GOTO 1100                                         ; Jump if requested to show the route to the treasure.
; 1054 IF K$="0" THEN GOTO 1200                                         ; Jump if requested to remove the route the treasure.
; 1056 IF K$="G" THEN RUN                                               ; Jump if requested to have another go at the game.

; 1060 GOTO 1020                                                        ; Loop back to allow the maze to be explored.

; ----------------------
; Show Route to Treasure
; ----------------------
; The display position is reset to the top-left position of the maze. This is done because the routines to clear the maze of mazogs, trails and 'This Way' codes
; and to populate the maze with the route to the treasure also use the same program variable to determine the location of the maze. If it does not point to the
; top-left corner of the maze then it will result in memory locations beyond the maze being modified, which can overwrite the stack and cause a crash.
; The original maze position is restored later at line 1020.

; 1100 PRINT AT 0,8;"#####SOLVING####"
; 1104 POKE TR,57                                                       ; Insert the treasure ['T'] into the maze at its original location.

; 1106 GOSUB 1250                                                       ; Reset to the top-left corner of the maze and place the player at the entrance.

; 1110 RAND USR 17128                                                   ; Clear the maze of mazogs, trails and 'This Way' codes.
; 1114 RAND USR 17171                                                   ; Populate the maze with the route to the treasure.

; 1116 GOTO 1210                                                        ; Jump ahead to continue.

; ------------------------
; Remove Route to Treasure
; ------------------------
; The display position is reset to the top-left position of the maze. This is done because the routine to clear the maze of mazogs, trails and 'This Way' codes
; also uses the same program variable to determine the location of the maze. If it does not point to the top-left corner of the maze then it will result in
; memory locations beyond the maze being modified, which can overwrite the stack and cause a crash. The original maze position is restored later at line 1020.

; 1200 GOSUB 1250                                                       ; Reset to the top-left corner of the maze and place the player at the entrance.

; 1206 RAND USR 17128                                                   ; Clear the maze of mazogs, trails and 'This Way' codes.

; Showing and removing the route join here.

; 1210 RAND USR 20199                                                   ; Insert all mazogs into the maze.
; 1212 POKE POS,8                                                       ; Insert a chequerboard character into the maze to show where the player was killed or exited.

; 1220 GOTO 1020                                                        ; Jump back to allow the maze to be explored.

; ---------------------------------
; Restore Maze and Player Locations
; ---------------------------------

; 1250 LET AD=16525                                                     ; The address of the program variable holding the start of the maze, i.e. the top-left position.
; 1252 LET N=MST                                                        ; The address in memory of the maze.
; 1254 GOSUB POKE                                                       ; Restore the program variable with the real start address of the maze.

; 1258 LET AD=16520                                                     ; The address of the program variable holding the location of the player within the maze.
; 1260 LET N=HM                                                         ; The address of the entrance / exit location within the maze.
; 1262 GOSUB POKE                                                       ; Set the player location at the entrance.

; 1264 POKE POS,0                                                       ; Remove the player's final position from the maze.
; 1266 RETURN

; -----------------
; Show Title Screen
; -----------------

; 2000 SLOW

; 2004 POKE 16677,128                                                   ; The code for an internal wall used to initially fill the maze.
; 2006 RAND USR 16672                                                   ; Construct the maze (consisting of an external wall filled with internal walls).

; 2007 POKE 16518,8                                                     ; The code for an external wall.
; 2008 RAND USR 16620                                                   ; Insert External Wall Into Maze Area.

; 2010 LET AD=16520                                                     ; Address of the program variable that holds the address of the player within the maze.
; 2012 LET N=MST+470                                                    ; Offset into the maze 7 rows and 22 columns.
; 2014 GOSUB POKE                                                       ; Store as the address of the player.

; 2016 POKE N-130,33                                                    ; '5' = Holding treasure.
; 2017 POKE N-129,57                                                    ; 'T' = Treasure #1.
; 2018 POKE N-66,27                                                     ; '.' = Trail.
; 2019 POKE N-65,27                                                     ; '.' = Trail.
; 2020 POKE N-64,39                                                     ; 'B' = Running to the right with a sword #1.
; 2021 POKE N-63,61                                                     ; 'X' = Mazog with eyes open.
; 2022 POKE N-1,23                                                      ; '*' = 'This Way'.
; 2023 POKE N,53                                                        ; 'P' = Prisoner with eyes closed.
; 2024 POKE N+1,0                                                       ; ' ' = Empty location.
; 2025 POKE N+65,184                                                    ; 's' = Sword.
; 2026 POKE N+63,23                                                     ; '*' = 'This Way'.
; 2027 POKE N+62,189                                                    ; 'x' = Mazog with eyes closed.

; A section of the maze is filled as follows:
; 5T###
; ..BX#
; #*P #
; x*#s#

; 2030 GOSUB SUR                                                        ; Fill the display with inverse chequerboard characters.
; 2031 GOSUB PR                                                         ; Toggle the maze codes and then display the sprites around the current player location.

; The title screen will appear as:
; 5t###
; ..Bx#
; #*p #
; X*#s#

; --------------------
; Animate Title Screen
; --------------------

; 2032 PRINT AT 1,6;"A MAZE ADVENTURE GAME"
; 2034 GOSUB 2046                                                       ; BASIC subroutine to scroll "MAZOGS" down the right hand side of the screen.

; 2036 PRINT AT 1,6;"press a key to start/"
; 2038 GOSUB 2046                                                       ; BASIC subroutine to scroll "MAZOGS" down the right hand side of the screen.

; 2040 GOTO 2032                                                        ; Repeat the title screen animation.

; ---------------------------
; Scroll "MAZOGS" Down Screen
; ---------------------------

; 2046 FOR A=4 TO 21
; 2050 GOSUB PR                                                         ; Toggle the maze codes and then display a screenful of sprites around the player location.
; 2054 PRINT AT A,25;"MAZOGS"
; 2063 IF INKEY$<>"" THEN GOTO 2080                                     ; Jump ahead if a key is pressed.
; 2064 NEXT A

; 2066 POKE 18619,5                                                     ; Specify that there are 5 sprites to display across the screen.
; 2068 GOSUB PR                                                         ; Toggle the maze codes and then display a screenful of sprites around the player location.

; 2070 POKE 18619,4                                                     ; Specify that there are 4 sprites to display across the screen.
; 2072 RETURN

; ----------------------
; Display "WHICH GAME ?"
; ----------------------

; 2080 POKE 18619,5                                                     ; Specify that there are 5 sprites to display across the screen.
; 2081 GOSUB BB                                                         ; Toggles the maze codes and then draw sprites on a black background.

; 2082 POKE N-128,189                                                   ; 'x' = Mazog with eyes closed. Continually setting it here prevents the eyes blinking.
; 2084 LET X=USR 18602                                                  ; Toggle the maze codes and then display a screenful of sprites around the player location.

; 2086 PRINT AT 1,10;"WHICH GAME ?"
; 2088 PRINT AT 10,5;"1. TRY IT OUT"
; 2090 PRINT AT 12,5;"2. FACE A CHALLENGE"
; 2092 PRINT AT 14,5;"3. MANIAC MOBILE MAZOGS"
; 2094 PRINT AT 18,5;"PRESS NUMBER TO CHOOSE"

; 2096 GOSUB INK                                                        ; Wait for new key press.
; 2098 LET K$=INKEY$                                                    ; Read the keyboard.
; 2110 IF K$="1" THEN GOTO 2150                                         ; Jump for TRY IT OUT.
; 2112 IF K$="2" THEN GOTO 2200                                         ; Jump for FACE A CHALLENGE.
; 2114 IF K$="3" THEN GOTO 2250                                         ; Jump for MANIAC MOBILE MAZOGS.

; 2116 GOTO 2080                                                        ; Jump back to await a new key press.

; ---------------------------
; Display "TRY IT OUT" Screen
; ---------------------------

; 2152 GOSUB BB                                                         ; Toggles the maze codes and then draw sprites on a black background.

; 2154 POKE N-128,35                                                    ; '7' = Running left holding the treasure #1.
; 2155 RAND USR 18602                                                   ; Toggle maze codes then display screenful of sprites around the player location.

; 2156 PRINT AT 1,11;"TRY IT OUT"
; 2162 GOSUB MDR                                                        ; Construct the maze.

; 2166 POKE 19212,1                                                     ; Indicate there is not a countdown.
; 2168 POKE 19213,0                                                     ; Indicate that the mazogs are static.

; 2170 POKE 19892,205                                                   ; Insert CALL $426D to introduce a 0.3 seconds delay in the game loop to slow the game loop down.
; 2171 POKE 19893,109
; 2172 POKE 19894,66

; 2174 GOTO 3000                                                        ; Jump ahead to continue.

; ---------------------------------
; Display "FACE A CHALLENGE" Screen
; ---------------------------------

; 2202 GOSUB BB                                                         ; Toggles the maze codes and then draw sprites on a black background.

; 2204 POKE N-128,39                                                    ; 'B' = Running right with sword #1.
; 2206 GOSUB PR                                                         ; Toggle the maze codes and then display a screenful of sprites around the player location.

; 2208 PRINT AT 1,8;"FACE A CHALLENGE"
; 2216 GOSUB MDR                                                        ; Construct the maze.

; 2220 POKE 19212,0                                                     ; Indicate there is a countdown.
; 2222 POKE 19213,0                                                     ; Indicate that the mazogs are static.
; 2223 POKE 20310,1                                                     ; Indicate that the mazogs are static.

; 2224 GOTO 3000                                                        ; Jump ahead to continue.

; -------------------------------------
; Display "MANIAC MOBILE MAZOGS" Screen
; -------------------------------------

; 2250 PRINT AT 1,6;"MANIAC MOBILE MAZOGS"

; 2254 POKE N-128,29                                                    ; '1' = Standing.
; 2256 POKE N-129,61                                                    ; 'X' = Mazog with eyes open.
; 2258 POKE N-127,61                                                    ; 'X' = Mazog with eyes open.

; 2260 FOR A=1 TO 10                                                    ; This loop animate the mazogs 5 times.
; 2262 GOSUB PR                                                         ; Toggle the maze codes and then display a screenful of sprites around the player location.
; 2264 NEXT A

; 2269 GOSUB MDR                                                        ; Construct the maze.

; 2270 POKE 19212,0                                                     ; Indicate there is a countdown.
; 2272 POKE 19213,1                                                     ; Indicate that the mazogs are mobile.
; 2276 POKE 20310,0                                                     ; Indicate that the mazogs are mobile.

; 2278 POKE 19273,253                                                   ; Set the View timeout threshold.

; 2280 GOTO 3000                                                        ; Jump ahead to continue.

; --------
; Run Game
; --------

; 3000 GOSUB SUR                                                        ; Fill the display with inverse chequerboard characters.

; 3002 RAND USR 20631                                                   ; Decrement the countdown timer and delay 0.3 seconds.
; 3010 RAND USR 19226                                                   ; Start the game loop, returning only when the game is over or a situation report has been requested.

; ----------------
; Game Loop Exited
; ----------------

; 3012 IF PEEK 19220 THEN GOTO 3100                                     ; Jump if starved to death, i.e. moves remaining countdown reached 0.
; 3014 IF PEEK 19221 THEN GOTO 3150                                     ; Jump if exited with the treasure.
; 3020 IF PEEK 19222 THEN GOTO 3060                                     ; Jump if a situation report with requested.

; 3026 GOSUB 6037                                                       ; Toggle the maze codes and then draw a screenful of sprites around the player location with a black border.

; 3030 FOR A=1 TO 40                                                    ; This loop causes the 'death' message to be flashed.
; 3031 RAND USR 18602                                                   ; Toggle the maze codes and then display a screenful of sprites around the player location.
; 3032 PRINT AT 18,1;"death  to all treasure seekers"
; 3034 NEXT A

; 3040 GOTO 3200                                                        ; Jump ahead to continue.

; --------------------------
; Situation Report Requested
; --------------------------

; 3060 GOSUB 6450                                                       ; Display the situation report, returning with a key press code in P$.

; 3062 IF P$<>"T" OR PEEK 19217 OR PEEK 19216 OR K$="1" THEN GOTO 3070  ; Jump if not requested to buy a sword, or holding the treasure, or holding a sword, or if playing TRY IT OUT.

; The player has requested to buy a sword.

; 3064 LET N=INT (ML/2)+1                                               ; The sword costs half the number of remaining moves.
; 3065 IF N<=2 THEN GOTO 3070                                           ; Jump ahead if there are not enough moves remaining to buy a sword.

; 3066 GOSUB POKE                                                       ; Update the number of moves remaining.
; 3068 POKE 19216,1                                                     ; Indicate that the player has a sword.

; 3070 GOSUB SUR                                                        ; Fill the display with inverse chequerboard characters.

; 3072 RAND USR 20631                                                   ; Decrement the countdown timer and delay 0.3 seconds.
; 3074 RAND USR 19239                                                   ; Rejoin the game loop.

; 3076 GOTO 3012                                                        ; Jump back to determine the reason for exiting the game loop.

; ----------------
; Starved to Death
; ----------------

; 3100 POKE 17370,128                                                   ; Select to fill the screen with black.
; 3116 GOSUB SUR                                                        ; Fill the display with black characters.

; 3118 FOR A=1 TO 35                                                    ; Flash the 'starved' message.
; 3120 PRINT AT 10,4;"YOU HAVE STARVED TO DEATH"
; 3122 PRINT AT 10,4;"you have starved to death"
; 3124 NEXT A

; 3140 GOTO 3214                                                        ; Jump ahead to continue.

; ------------------------
; Exited with the Treasure
; ------------------------

; 3160 IF D$="L" THEN GOTO 3180                                         ; Jump if entered the maze from the left.

; The player entered the maze from the right.

; 3162 POKE HM,29                                                       ; '1' = Insert the companion standing.
; 3164 POKE HM+1,33                                                     ; '5' = Insert the player holding the treasure.
; 3165 POKE HM-64,0                                                     ; Insert an empty location for the exit above the companion.

; 3166 GOSUB PR                                                         ; Toggle the maze codes and then display a screenful of sprites around the player location.

; 3168 PRINT AT 10,8;"EXIT"

; 3170 FOR A=1 TO 60                                                    ; Flash the 'welcome back' message to the left.
; 3172 PRINT AT 18,7;"welcome back"
; 3174 PRINT AT 18,7;"WELCOME BACK"
; 3176 NEXT A

; 3178 GOTO 3200                                                        ; Jump ahead to continue.

; The player entered the maze from the left.

; 3180 POKE HM,29                                                       ; '1' = Insert the companion standing.
; 3182 POKE HM-1,33                                                     ; '5' = Insert the player holding the treasure.
; 3184 POKE HM-64,0                                                     ; Insert an empty location for the exit above the companion.

; 3186 GOSUB PR                                                         ; Toggle the maze codes and then display a screenful of sprites around the player location.

; 3188 PRINT AT 10,20;"EXIT"

; 3190 FOR A=1 TO 60                                                    ; Flash the 'welcome back' message to the right.
; 3192 PRINT AT 18,13;"welcome back"
; 3194 PRINT AT 18,13;"WELCOME BACK"
; 3196 NEXT A

; Both paths join here.

; 3200 GOSUB SUR                                                        ; Fill the display with black characters.

; -------------
; Display Score
; -------------

; 3216 IF K$="1" OR NOT PEEK 19221 THEN GOTO 4500                       ; Jump if exited without the treasure or playing TRY IT OUT.

; 4000 PRINT AT 4,13;"score"
; 4030 PRINT AT 7,C;"MOVES ALLOWED = ";MA                               ; Display the initial number of moves.
; 4031 PRINT

; 4034 LET ML=PEEK 19214+PEEK 19215*256                                 ; Fetch the number of moves remaining.

; 4038 PRINT "//MOVES LEFT = ";ML                                       ; Display the number of moves remaining.
; 4040 PRINT
; 4046 PRINT "//SCORE = ";INT (ML/MA*100);" PER CENT"                   ; Display the score (as a percentage of the number of moves remaining against the initial number of moves allowed).

; 4500 PRINT AT 18,C;"PRESS ""M"" TO EXAMINE THE MAZE"
; 4520 PRINT AT 20,C;"PRESS ""G"" FOR ANOTHER GAME"

; 4522 GOSUB INK                                                        ; Wait for new key press.

; 4524 LET K$=INKEY$                                                    ; Read the keyboard.
; 4530 IF K$="M" THEN GOTO 1000                                         ; Jump if selected the examine the maze.
; 4532 IF K$="G" THEN RUN                                               ; Jump if selected to have another go of the game.

; 4534 GOTO 4524                                                        ; Jump back to wait for a new key press.

; -----------
; Double Poke
; -----------

; 6010 POKE AD,N-INT (N/256)*256                                        ; Poke AD with N.
; 6020 POKE AD+1,INT (N/256)
; 6024 RETURN

; --------------------------------------------
; Draw Screenful of Sprites for a Title Screen
; --------------------------------------------

; 6032 LET AD=16520                                                     ; The address of the program variable that holds the player's location.
; 6034 LET N=MST+480                                                    ; Offset 7 rows and 32 columns.
; 6036 GOSUB POKE                                                       ; Set the player's location.

; -------------------------------------------------------------------------------------------
; Toggle Maze Codes then Draw Screenful of Sprites Around Player Location on Black Background
; -------------------------------------------------------------------------------------------

; 6037 POKE 17370,128                                                   ; Select to fill the screen with black. 
; 6038 GOSUB SUR                                                        ; Fill the display with black characters.       

; 6040 RAND USR 18602                                                   ; Toggle the maze codes and then display a screenful of sprites around the player location.

; 6041 POKE 17370,136                                                   ; The character used fill the screen when BASIC subroutine at 6050 is called.
; 6042 RETURN

; ----------------------------------------------
; Fill Screen With Inverse Chequerboard or Black
; ----------------------------------------------

; 6052 LET X=USR 17365                                                  ; Fill the screen with the character previously poked to 17370.
; 6054 RETURN

; ----------------------
; Wait for New Key Press
; ----------------------

; 6062 IF INKEY$<>"" THEN GOTO 6062                                     ; Wait until a key is not being pressed.
; 6064 IF INKEY$="" THEN GOTO 6064                                      ; Wait until a key is being pressed.
; 6066 RETURN

; --------------------------------------------------------------------------
; Toggle Maze Codes then Display Screenful of Sprites Around Player Location
; --------------------------------------------------------------------------

; 6072 LET X=USR 18602                                                  ; Toggle the maze codes and then display a screenful of sprites around the player location.
; 6074 RETURN

; ------------------
; Calculate Distance
; ------------------

; 6082 LET X=USR 17128                                                  ; Clear the maze of mazogs, trails and 'This Way' codes.
; 6083 LET X=USR 17171                                                  ; Populate the maze with the route to the treasure.
; 6084 POKE 16527,23                                                    ; '*' = 'This Way'. Set the maze code to count when calculating the distance.
; 6085 LET X=USR 17028                                                  ; Calculate the distance to the treasure / exit.
; 6086 LET X=USR 17128                                                  ; Clear the maze of mazogs, trails and 'This Way' codes.
; 6088 LET MOVES=PEEK 16518+PEEK 16519*256                              ; Fetch the number of moves, i.e. the distance.
; 6089 RETURN

; ------------------
; Construct the Maze
; ------------------

; 6110 PRINT AT 14,C;" USE KEYS  W A D AND X   OR "                     ; Display key controls.
; 6112 PRINT AT 16,C;" W S H AND J.  V=VIEW,Y=STOP"
; 6114 PRINT AT 21,C;"the maze is now being drawn#"

; 6124 POKE 16677,128                                                   ; The code for an internal wall used to initially fill the maze.
; 6126 RAND USR 16672                                                   ; Construct the maze (consisting of an external wall filled with internal walls).

; 6130 POKE 16518,8                                                     ; The code for an external wall.
; 6132 RAND USR 16620                                                   ; Insert External Wall Into Maze Area

; 6141 RAND                                                             ; Seed the random number generator based on the TV frames counter.

; Select a random location for the treasure.

; 6142 LET N=MST+128+INT (RND*2810)                                     ; Select a random location between row 2 column 0 and row 45 column 58.
; 6144 IF PEEK N=8 OR PEEK (N+1)=8 OR PEEK (N-1)=8 THEN GOTO 6142       ; If an external wall has been selected then loop back and select a new random location.

; 6146 LET AD=16520                                                     ; The address of the program variable holding the location of the player within the maze.
; 6148 GOSUB POKE                                                       ; Set the player at the location of the treasure.

; 6150 POKE N,57                                                        ; Insert the treasure ['T'] into the maze.
; 6152 LET TR=N                                                         ; Note the initial location of the treasure.

; 6153 POKE 16437,INT (RND*120)+132                                     ; Initialise the countdown timer with random value.

; 6155 LET X=USR 16694                                                  ; Generate the maze (which takes between 5.12 and 10.24 seconds).

; 6157 IF PEEK 16518+PEEK 16519*256>1200 THEN GOTO 6170                 ; Fetch the number of empty locations. Jump ahead if the maze is complex enough.

; The maze is not complex enough.

; 6158 PRINT AT 21,C;" THE MAZE IS BEING REDRAWN  "
; 6160 GOTO 6120                                                        ; Jump back to regenerate the maze.

; The maze has been successfully constructed.

; 6170 RAND USR 20515                                                   ; Insert the entrance passageways into the maze.
; 6172 LET X=USR 20133                                                  ; Insert mazogs, swords and prisoners at random location within the maze.

; 6298 PRINT AT 21,C;" MAZE READY - PRESS ANY KEY "
; 6300 GOSUB INK                                                        ; Wait for new key press.

; --------------------------------
; Request Entry from Left or Right
; --------------------------------

; 6310 GOSUB SUR                                                        ; Fill the display with inverse chequerboard characters.
; 6314 RAND USR 20860                                                   ; Display the View around the player's location.

; 6316 PRINT AT 2,1;"WHICH WAY ?   PRESS ""L"" OR ""R"""

; 6318 LET N=PEEK 16520+PEEK 16521*256                                  ; Fetch the location of the player.
; 6319 LET HM=N                                                         ; Note the entrance position.

; 6320 LET AD=16522                                                     ; The address of the program variable that holds the exit location (which is the same as the entrance location).
; 6322 GOSUB POKE                                                       ; Store the exit location.

; 6324 GOSUB INK                                                        ; Wait for new key press.
; 6334 LET D$=INKEY$                                                    ; Read the keyboard.
; 6336 IF D$="R" THEN GOTO 6346                                         ; Jump if selected to enter from the right.
; 6338 IF D$="L" THEN GOTO 6350                                         ; Jump if selected to enter from the left.

; 6340 GOTO 6324                                                        ; Loop back to wait for a new key press.

; Enter maze from the right.

; 6346 POKE N-1,128                                                     ; Insert a wall to the left of the player.
; 6348 GOTO 6360                                                        ; Jump ahead to continue.

; Enter maze from the left.

; 6350 POKE N+1,128                                                     ; Insert a wall to the right of the player.

; Left and right paths join here.

; 6360 GOSUB SUR                                                        ; Fill the display with inverse chequerboard characters.
; 6362 RAND USR 20860                                                   ; Display the View around the player's location.

; 6364 PRINT AT 21,C;"PRESS ANY KEY FOR INFORMATION"
; 6366 GOSUB INK                                                        ; Wait for new key press.

; -------------------
; Display Information
; -------------------

; 6392 GOSUB SUR                                                        ; Fill the display with inverse chequerboard characters.
; 6394 PRINT AT 10,7;"CHECKING DISTANCE"

; 6398 GOSUB CT                                                         ; Calculate the distance to the treasure.
; 6410 IF MOVES>120 THEN GOTO 6440                                      ; Jump if the treasure is sufficiently far away.

; The treasure is not far enough away.

; 6412 POKE TR,0                                                        ; Remove the treasure from the maze.

; 6414 LET N=MST+128+INT (RND*2810)                                     ; Select a random location between row 2 column 0 and row 45 column 58.
; 6416 IF PEEK N<>0 THEN GOTO 6414                                      ; Loop back if the location is not empty.

; 6418 LET TR=N                                                         ; Note the initial location of the treasure.
; 6420 POKE TR,57                                                       ; Insert the treasure ['T'] into the maze.

; 6422 GOTO 6396                                                        ; Jump back to calculate the new distance to the treasure.

; The treasure is sufficiently far away.

; 6440 LET N=MOVES*4+10                                                 ; Calculate the number of moves allowed. Include an extra 10 to compensate for the cost of the situation report
                                                                        ; that is displayed before the game begins. Note that this extra 10 moves is not included in the figure show to
                                                                        ; the user in the initial situation report (it has already been deducted by then) but it is used in calculating
                                                                        ; the score should the player exit with the treasure.
; 6441 LET MA=N                                                         ; Note the number of moves allowed.

; 6442 LET AD=19214                                                     ; The address of the program variable holding the moves remaining countdown.
; 6443 GOSUB POKE                                                       ; Set the moves remaining countdown.

; 6444 LET X=INT (MOVES/5*VAL K$)                                       ; Calculate the number of moves gained for killing a mazog.
; 6445 IF X>255 THEN LET X=255                                          ; Cap the moves gained.
; 6446 POKE 18779,X                                                     ; Store the number of moves gained for killing a mazog.

; 6448 POKE 19225,30/VAL K$                                             ; Store the number of moves lost for requesting a View.

; ------------------------
; Display Situation Report
; ------------------------

; 6452 GOSUB SUR                                                        ; Fill the display with inverse chequerboard characters.
; 6456 PRINT AT 2,7;"situation report"

; 6458 GOSUB CT                                                         ; Calculate the distance to the treasure.

; 6470 IF NOT PEEK 19217 THEN
;      PRINT AT 5,C;"MOVES TO THE TREASURE = ";MOVES                    ; If the player is not holding the treasure then display the moves to the treasure.
; 6472 IF PEEK 19217 THEN
;      PRINT AT 5,C;"MOVES BACK TO ""BASE"" = ";MOVES                   ; If the player is holding the treasure then display the moves to the exit.

; 6474 IF K$="1" THEN GOTO 6500                                         ; Jump ahead if playing TRY IT OUT.

; 6476 LET ML=PEEK 19214+PEEK 19215*256                                 ; Fetch the moves remaining countdown.
; 6477 IF ML>11 THEN LET ML=ML-10                                       ; The situation report costs 10 moves.
; 6478 PRINT AT 7,C;"YOU HAVE ";ML; " MOVES TO GO"                      ; Display the number of moves remaining.
; 6480 IF ML>=MOVES THEN GOTO 6489                                      ; Jump ahead if there are insufficient moves remaining.

; There are insufficient moves remaining. It is necessary to kill a mazog to gain moves.

; 6482 LET X=INT ((MOVES-ML)/PEEK 18779)+1                              ; Calculate the number of mazogs that must be killed.

; 6484 PRINT AT 9,C;"YOU NEED TO KILL AT LEAST"                         ; Display the number of mazogs that must be killed.
; 6485 PRINT AT 10,C;X;" MAZOG";
; 6487 IF X>1 THEN PRINT "S";
; 6488 PRINT " TO GET THERE"

; 6489 PRINT AT 13,C;"YOU GAIN ";PEEK 18779; " FOR A ""KILL"""          ; Display the number of moves gained for killing a mazog.
; 6490 PRINT AT 15,C;"YOU LOSE ";PEEK 19225; " FOR EACH ""VIEW"""       ; Display the number of moves lost for displaying a View.
; 6492 PRINT AT 17,C;"THIS REPORT TAKES 10 MOVES"                       ; Display the number of moves lost for displaying a Situation Report.

; 6494 LET N=ML+1                                                       ; The act of requesting a Situation Report inherently takes an additional move so reverse this.
; 6496 GOSUB POKE                                                       ; Update the moves remaining countdown.

; 6498 PRINT AT 19,C;"PRESS  T  TO ""BUY"" A SWORD"
; 6500 PRINT AT 21,C;"PRESS ANY KEY FOR THE GAME"

; 6502 POKE 19222,0                                                     ; Clear the Situation Report requested flag.

; 6504 GOSUB INK                                                        ; Wait for new key press.
; 6506 LET P$=INKEY$                                                    ; Read the keyboard.
; 6999 RETURN

; ------------
; Save Program
; ------------

; 9000 CLEAR                                                            ; Discard all BASIC variables.
; 9010 SAVE "MAZOGs"                                                    ; Save the program so that it auto-runs upon loading.
; 9020 RUN

; ------------------------------------------------------------------------------------------------------------------------------------------------------

; ===================
; BASIC Program Bytes
; ===================

L51D8:  DEFB 2 >> 8
        DEFB 2 & $FF
        DEFW $0002
        DEFB _REM, _NEWLINE

        DEFB 3 >> 8
        DEFB 3 & $FF
        DEFW $0002
        DEFB _REM, _NEWLINE

        DEFB 4 >> 8
        DEFB 4 & $FF
        DEFW $0019
        DEFB _REM, _M, _A, _Z, _O, _G, _S, _SPACE, _OPENBRACKET, _C
        DEFB _CLOSEBRACKET, _1, _9, _8, _1, _SPACE, _B, _U, _G, _MINUS
        DEFB _B, _Y, _T, _E, _NEWLINE

        DEFB 5 >> 8
        DEFB 5 & $FF
        DEFW $0017
        DEFB _REM, _A, _U, _T, _H, _O, _R, _COLON, _SPACE, _D, _O, _N
        DEFB _SPACE, _P, _R, _I, _E, _S, _T, _L, _E, _Y, _NEWLINE

        DEFB 6 >> 8
        DEFB 6 & $FF
        DEFW $0002
        DEFB _REM, _NEWLINE

        DEFB 7 >> 8
        DEFB 7 & $FF
        DEFW $0002
        DEFB _REM, _NEWLINE

        DEFB 8 >> 8
        DEFB 8 & $FF
        DEFW $0002
        DEFB _REM, _NEWLINE

        DEFB 108 >> 8
        DEFB 108 & $FF
        DEFW $0011
        DEFB _LET, _M, _S, _T, _EQUALS, _2, _9, _4, _5, _0
        DEFB _NUMBER, $8F, $66, $14, $00, $00, _NEWLINE

        DEFB 110 >> 8
        DEFB 110 & $FF
        DEFW $0010
        DEFB _LET, _M, _D, _R, _EQUALS, _6, _1, _0, _0
        DEFB _NUMBER, $8D, $3E, $A0, $00, $00, _NEWLINE

        DEFB 112 >> 8
        DEFB 112 & $FF
        DEFW $000F
        DEFB _LET, _B, _B, _EQUALS, _6, _0, _3, _0
        DEFB _NUMBER, $8D, $3C, $70, $00, $00, _NEWLINE

        DEFB 114 >> 8
        DEFB 114 & $FF
        DEFW $0010
        DEFB _LET, _S, _U, _R, _EQUALS, _6, _0, _5, _2
        DEFB _NUMBER, $8D, $3D, $20, $00, $00, _NEWLINE

        DEFB 116 >> 8
        DEFB 116 & $FF
        DEFW $000B
        DEFB _LET, _C, _EQUALS, _2
        DEFB _NUMBER, $82, $00, $00, $00, $00, _NEWLINE

        DEFB 120 >> 8
        DEFB 120 & $FF
        DEFW $0011
        DEFB _LET, _P, _O, _K, _E, _EQUALS, _6, _0, _0, _0
        DEFB _NUMBER, $8D, $3B, $80, $00, $00, _NEWLINE

        DEFB 122 >> 8
        DEFB 122 & $FF
        DEFW $0010
        DEFB _LET, _I, _N, _K, _EQUALS, _6, _0, _6, _0
        DEFB _NUMBER, $8D, $3D, $60, $00, $00, _NEWLINE

        DEFB 124 >> 8
        DEFB 124 & $FF
        DEFW $000E
        DEFB _LET, _T, _EQUALS, _2, _0, _0, _0
        DEFB _NUMBER, $8B, $7A, $00, $00, $00, _NEWLINE

        DEFB 126 >> 8
        DEFB 126 & $FF
        DEFW $000F
        DEFB _LET, _P, _R, _EQUALS, _6, _0, _7, _0
        DEFB _NUMBER, $8D, $3D, $B0, $00, $00, _NEWLINE

        DEFB 128 >> 8
        DEFB 128 & $FF
        DEFW $000F
        DEFB _LET, _C, _T, _EQUALS, _6, _0, _8, _0
        DEFB _NUMBER, $8D, $3E, $00, $00, $00, _NEWLINE

        DEFB 198 >> 8
        DEFB 198 & $FF
        DEFW $0017
        DEFB _POKE, _1, _9, _2, _7, _3, _NUMBER, $8F, $16, $92, $00, $00
        DEFB _COMMA, _2, _5, _4, _NUMBER, $88, $7E, $00, $00, $00
        DEFB _NEWLINE

        DEFB 200 >> 8
        DEFB 200 & $FF
        DEFW $0010
        DEFB _LET, _A, _D, _EQUALS, _1, _6, _5, _2, _5
        DEFB _NUMBER, $8F, $01, $1A, $00, $00, _NEWLINE

        DEFB 202 >> 8
        DEFB 202 & $FF
        DEFW $0007
        DEFB _LET, _N, _EQUALS, _M, _S, _T, _NEWLINE

        DEFB 204 >> 8
        DEFB 204 & $FF
        DEFW $0006
        DEFB _GOSUB, _P, _O, _K, _E, _NEWLINE

        DEFB 206 >> 8
        DEFB 206 & $FF
        DEFW $0015
        DEFB _POKE, _1, _9, _2, _1, _7, _NUMBER, $8F, $16, $22, $00, $00
        DEFB _COMMA, _0, _NUMBER, $00, $00, $00, $00, $00, _NEWLINE

        DEFB 208 >> 8
        DEFB 208 & $FF
        DEFW $001B
        DEFB _FOR, _A, _EQUALS, _1, _9, _8, _9, _2
        DEFB _NUMBER, $8F, $1B, $68, $00, $00
        DEFB _TO, _1, _9, _8, _9, _4, _NUMBER, $8F, $1B, $6C, $00, $00
        DEFB _NEWLINE

        DEFB 210 >> 8
        DEFB 210 & $FF
        DEFW $000B
        DEFB _POKE, _A, _COMMA, _0, _NUMBER, $00, $00, $00, $00, $00
        DEFB _NEWLINE

        DEFB 212 >> 8
        DEFB 212 & $FF
        DEFW $0003
        DEFB _NEXT, _A, _NEWLINE

        DEFB 214 >> 8
        DEFB 214 & $FF
        DEFW $0017
        DEFB _POKE, _1, _7, _3, _7, _0, _NUMBER, $8F, $07, $B4, $00, $00
        DEFB _COMMA, _1, _3, _6, _NUMBER, $88, $08, $00, $00, $00
        DEFB _NEWLINE

        DEFB 216 >> 8
        DEFB 216 & $FF
        DEFW $0015
        DEFB _POKE, _1, _8, _8, _1, _0, _NUMBER, $8F, $12, $F4, $00, $00
        DEFB _COMMA, _0, _NUMBER, $00, $00, $00, $00, $00, _NEWLINE

        DEFB 250 >> 8
        DEFB 250 & $FF
        DEFW $000C
        DEFB _GOTO, _2, _0, _0, _0, _NUMBER, $8B, $7A, $00, $00, $00
        DEFB _NEWLINE

        DEFB 1000 >> 8
        DEFB 1000 & $FF
        DEFW $0028
        DEFB _LET, _T, _D, _EQUALS, _PEEK, _1, _8, _8, _1, _0
        DEFB _NUMBER, $8F, $12, $F4, $00, $00, _PLUS, _PEEK
        DEFB _1, _8, _8, _1, _1, _NUMBER, $8F, $12, $F6, $00, $00
        DEFB _ASTERISK, _2, _5, _6, _NUMBER, $89, $00, $00, $00, $00
        DEFB _NEWLINE

        DEFB 1002 >> 8
        DEFB 1002 & $FF
        DEFW $002A
        DEFB _IF, _PEEK, _T, _D, _EQUALS, _5, _7
        DEFB _NUMBER, $86, $64, $00, $00, $00, _OR, _PEEK, _T, _D
        DEFB _EQUALS, _1, _8, _5, _NUMBER, $88, $39, $00, $00, $00
        DEFB _THEN, _POKE, _T, _D, _COMMA, _1, _5, _1
        DEFB _NUMBER, $88, $17, $00, $00, $00, _NEWLINE

        DEFB 1006 >> 8
        DEFB 1006 & $FF
        DEFW $0029
        DEFB _LET, _P, _O, _S, _EQUALS, _PEEK, _1, _6, _5, _2, _0
        DEFB _NUMBER, $8F, $01, $10, $00, $00, _PLUS, _2, _5, _6
        DEFB _NUMBER, $89, $00, $00, $00, $00, _ASTERISK, _PEEK
        DEFB _1, _6, _5, _2, _1, _NUMBER, $8F, $01, $12, $00, $00
        DEFB _NEWLINE

        DEFB 1010 >> 8
        DEFB 1010 & $FF
        DEFW $0007
        DEFB _LET, _X, _EQUALS, _M, _S, _T, _NEWLINE

        DEFB 1020 >> 8
        DEFB 1020 & $FF
        DEFW $0028
        DEFB _POKE, _1, _6, _5, _2, _5, _NUMBER, $8F, $01, $1A, $00, $00
        DEFB _COMMA, _X, _MINUS, _INT, _OPENBRACKET, _X, _DIVIDE
        DEFB _2, _5, _6, _NUMBER, $89, $00, $00, $00, $00, _CLOSEBRACKET
        DEFB _ASTERISK, _2, _5, _6, _NUMBER, $89, $00, $00, $00, $00
        DEFB _NEWLINE

        DEFB 1022 >> 8
        DEFB 1022 & $FF
        DEFW $001C
        DEFB _POKE, _1, _6, _5, _2, _6, _NUMBER, $8F, $01, $1C, $00, $00
        DEFB _COMMA, _INT, _OPENBRACKET, _X, _DIVIDE, _2, _5, _6
        DEFB _NUMBER, $89, $00, $00, $00, $00, _CLOSEBRACKET, _NEWLINE

        DEFB 1030 >> 8
        DEFB 1030 & $FF
        DEFW $000E
        DEFB _RAND, _USR, _1, _7, _3, _1, _0
        DEFB _NUMBER, $8F, $07, $3C, $00, $00, _NEWLINE

        DEFB 1040 >> 8
        DEFB 1040 & $FF
        DEFW $0006
        DEFB _LET, _K, _DOLLAR, _EQUALS, _INKEY, _NEWLINE

        DEFB 1050 >> 8
        DEFB 1050 & $FF
        DEFW $0068
        DEFB _LET, _X, _EQUALS, _X, _PLUS, _OPENBRACKET, _K, _DOLLAR
        DEFB _EQUALS, _QUOTE, _J, _QUOTE, _CLOSEBRACKET, _MINUS
        DEFB _OPENBRACKET, _K, _DOLLAR, _EQUALS, _QUOTE, _H, _QUOTE
        DEFB _CLOSEBRACKET, _PLUS, _OPENBRACKET, _K, _DOLLAR, _EQUALS
        DEFB _QUOTE, _S, _QUOTE, _CLOSEBRACKET, _ASTERISK, _6, _4
        DEFB _NUMBER, $87, $00, $00, $00, $00, _MINUS, _OPENBRACKET
        DEFB _K, _DOLLAR, _EQUALS, _QUOTE, _W, _QUOTE, _CLOSEBRACKET
        DEFB _ASTERISK, _6, _4, _NUMBER, $87, $00, $00, $00, $00, _PLUS
        DEFB _OPENBRACKET, _X, _LESSTHAN, _M, _S, _T, _CLOSEBRACKET
        DEFB _ASTERISK, _6, _4, _NUMBER, $87, $00, $00, $00, $00, _MINUS
        DEFB _OPENBRACKET, _X, _GREATERTHAN, _M, _S, _T, _PLUS
        DEFB _1, _5, _6, _8, _NUMBER, $8B, $44, $00, $00, $00
        DEFB _CLOSEBRACKET, _ASTERISK, _6, _4
        DEFB _NUMBER, $87, $00, $00, $00, $00, _NEWLINE

        DEFB 1052 >> 8
        DEFB 1052 & $FF
        DEFW $0014
        DEFB _IF, _K, _DOLLAR, _EQUALS, _QUOTE, _P, _QUOTE, _THEN, _GOTO
        DEFB _1, _1, _0, _0, _NUMBER, $8B, $09, $80, $00, $00, _NEWLINE

        DEFB 1054 >> 8
        DEFB 1054 & $FF
        DEFW $0014
        DEFB _IF, _K, _DOLLAR, _EQUALS, _QUOTE, _0, _QUOTE, _THEN, _GOTO
        DEFB _1, _2, _0, _0, _NUMBER, $8B, $16, $00, $00, $00, _NEWLINE

        DEFB 1056 >> 8
        DEFB 1056 & $FF
        DEFW $000A
        DEFB _IF, _K, _DOLLAR, _EQUALS, _QUOTE, _G, _QUOTE, _THEN, _RUN
        DEFB _NEWLINE

        DEFB 1060 >> 8
        DEFB 1060 & $FF
        DEFW $000C
        DEFB _GOTO, _1, _0, _2, _0, _NUMBER, $8A, $7F, $00, $00, $00
        DEFB _NEWLINE

        DEFB 1100 >> 8
        DEFB 1100 & $FF
        DEFW $0025
        DEFB _PRINT, _AT, _0, _NUMBER, $00, $00, $00, $00, $00, _COMMA
        DEFB _8, _NUMBER, $84, $00, $00, $00, $00, _SEMICOLON, _QUOTE
        DEFB _BLACK, _BLACK, _BLACK, _BLACK, _BLACK, _S, _O, _L, _V, _I, _N, _G
        DEFB _BLACK, _BLACK, _BLACK, _BLACK, _QUOTE, _NEWLINE

        DEFB 1104 >> 8
        DEFB 1104 & $FF
        DEFW $000D
        DEFB _POKE, _T, _R, _COMMA, _5, _7
        DEFB _NUMBER, $86, $64, $00, $00, $00, _NEWLINE

        DEFB 1106 >> 8
        DEFB 1106 & $FF
        DEFW $000C
        DEFB _GOSUB, _1, _2, _5, _0, _NUMBER, $8B, $1C, $40, $00, $00
        DEFB _NEWLINE

        DEFB 1110 >> 8
        DEFB 1110 & $FF
        DEFW $000E
        DEFB _RAND, _USR, _1, _7, _1, _2, _8
        DEFB _NUMBER, $8F, $05, $D0, $00, $00, _NEWLINE

        DEFB 1114 >> 8
        DEFB 1114 & $FF
        DEFW $000E
        DEFB _RAND, _USR, _1, _7, _1, _7, _1
        DEFB _NUMBER, $8F, $06, $26, $00, $00, _NEWLINE

        DEFB 1116 >> 8
        DEFB 1116 & $FF
        DEFW $000C
        DEFB _GOTO, _1, _2, _1, _0, _NUMBER, $8B, $17, $40, $00, $00
        DEFB _NEWLINE

        DEFB 1200 >> 8
        DEFB 1200 & $FF
        DEFW $000C
        DEFB _GOSUB, _1, _2, _5, _0, _NUMBER, $8B, $1C, $40, $00, $00
        DEFB _NEWLINE

        DEFB 1206 >> 8
        DEFB 1206 & $FF
        DEFW $000E
        DEFB _RAND, _USR, _1, _7, _1, _2, _8
        DEFB _NUMBER, $8F, $05, $D0, $00, $00, _NEWLINE

        DEFB 1210 >> 8
        DEFB 1210 & $FF
        DEFW $000E
        DEFB _RAND, _USR, _2, _0, _1, _9, _9
        DEFB _NUMBER, $8F, $1D, $CE, $00, $00, _NEWLINE

        DEFB 1212 >> 8
        DEFB 1212 & $FF
        DEFW $000D
        DEFB _POKE, _P, _O, _S, _COMMA, _8
        DEFB _NUMBER, $84, $00, $00, $00, $00, _NEWLINE

        DEFB 1220 >> 8
        DEFB 1220 & $FF
        DEFW $000C
        DEFB _GOTO, _1, _0, _2, _0, _NUMBER, $8A, $7F, $00, $00, $00
        DEFB _NEWLINE

        DEFB 1250 >> 8
        DEFB 1250 & $FF
        DEFW $0010
        DEFB _LET, _A, _D, _EQUALS, _1, _6, _5, _2, _5
        DEFB _NUMBER, $8F, $01, $1A, $00, $00, _NEWLINE

        DEFB 1252 >> 8
        DEFB 1252 & $FF
        DEFW $0007
        DEFB _LET, _N, _EQUALS, _M, _S, _T, _NEWLINE

        DEFB 1254 >> 8
        DEFB 1254 & $FF
        DEFW $0006
        DEFB _GOSUB, _P, _O, _K, _E, _NEWLINE

        DEFB 1258 >> 8
        DEFB 1258 & $FF
        DEFW $0010
        DEFB _LET, _A, _D, _EQUALS, _1, _6, _5, _2, _0
        DEFB _NUMBER, $8F, $01, $10, $00, $00, _NEWLINE

        DEFB 1260 >> 8
        DEFB 1260 & $FF
        DEFW $0006
        DEFB _LET, _N, _EQUALS, _H, _M, _NEWLINE

        DEFB 1262 >> 8
        DEFB 1262 & $FF
        DEFW $0006
        DEFB _GOSUB, _P, _O, _K, _E, _NEWLINE

        DEFB 1264 >> 8
        DEFB 1264 & $FF
        DEFW $000D
        DEFB _POKE, _P, _O, _S, _COMMA, _0
        DEFB _NUMBER, $00, $00, $00, $00, $00, _NEWLINE

        DEFB 1266 >> 8
        DEFB 1266 & $FF
        DEFW $0002
        DEFB _RETURN, _NEWLINE

        DEFB 2000 >> 8
        DEFB 2000 & $FF
        DEFW $0002
        DEFB _SLOW, _NEWLINE

        DEFB 2004 >> 8
        DEFB 2004 & $FF
        DEFW $0017
        DEFB _POKE, _1, _6, _6, _7, _7, _NUMBER, $8F, $02, $4A, $00, $00
        DEFB _COMMA, _1, _2, _8, _NUMBER, $88, $00, $00, $00, $00
        DEFB _NEWLINE

        DEFB 2006 >> 8
        DEFB 2006 & $FF
        DEFW $000E
        DEFB _RAND, _USR, _1, _6, _6, _7, _2
        DEFB _NUMBER, $8F, $02, $40, $00, $00, _NEWLINE

        DEFB 2007 >> 8
        DEFB 2007 & $FF
        DEFW $0015
        DEFB _POKE, _1, _6, _5, _1, _8, _NUMBER, $8F, $01, $0C, $00, $00
        DEFB _COMMA, _8, _NUMBER, $84, $00, $00, $00, $00, _NEWLINE

        DEFB 2008 >> 8
        DEFB 2008 & $FF
        DEFW $000E
        DEFB _RAND, _USR, _1, _6, _6, _2, _0
        DEFB _NUMBER, $8F, $01, $D8, $00, $00, _NEWLINE

        DEFB 2010 >> 8
        DEFB 2010 & $FF
        DEFW $0010
        DEFB _LET, _A, _D, _EQUALS, _1, _6, _5, _2, _0
        DEFB _NUMBER, $8F, $01, $10, $00, $00, _NEWLINE

        DEFB 2012 >> 8
        DEFB 2012 & $FF
        DEFW $0011
        DEFB _LET, _N, _EQUALS, _M, _S, _T, _PLUS, _4, _7, _0
        DEFB _NUMBER, $89, $6B, $00, $00, $00, _NEWLINE

        DEFB 2014 >> 8
        DEFB 2014 & $FF
        DEFW $0006
        DEFB _GOSUB, _P, _O, _K, _E, _NEWLINE

        DEFB 2016 >> 8
        DEFB 2016 & $FF
        DEFW $0016
        DEFB _POKE, _N, _MINUS, _1, _3, _0
        DEFB _NUMBER, $88, $02, $00, $00, $00, _COMMA, _3, _3
        DEFB _NUMBER, $86, $04, $00, $00, $00, _NEWLINE

        DEFB 2017 >> 8
        DEFB 2017 & $FF
        DEFW $0016
        DEFB _POKE, _N, _MINUS, _1, _2, _9
        DEFB _NUMBER, $88, $01, $00, $00, $00, _COMMA, _5, _7
        DEFB _NUMBER, $86, $64, $00, $00, $00, _NEWLINE

        DEFB 2018 >> 8
        DEFB 2018 & $FF
        DEFW $0015
        DEFB _POKE, _N, _MINUS, _6, _6, _NUMBER, $87, $04, $00, $00, $00
        DEFB _COMMA, _2, _7, _NUMBER, $85, $58, $00, $00, $00, _NEWLINE

        DEFB 2019 >> 8
        DEFB 2019 & $FF
        DEFW $0015
        DEFB _POKE, _N, _MINUS, _6, _5, _NUMBER, $87, $02, $00, $00, $00
        DEFB _COMMA, _2, _7, _NUMBER, $85, $58, $00, $00, $00, _NEWLINE

        DEFB 2020 >> 8
        DEFB 2020 & $FF
        DEFW $0015
        DEFB _POKE, _N, _MINUS, _6, _4, _NUMBER, $87, $00, $00, $00, $00
        DEFB _COMMA, _3, _9, _NUMBER, $86, $1C, $00, $00, $00, _NEWLINE

        DEFB 2021 >> 8
        DEFB 2021 & $FF
        DEFW $0015
        DEFB _POKE, _N, _MINUS, _6, _3, _NUMBER, $86, $7C, $00, $00, $00
        DEFB _COMMA, _6, _1, _NUMBER, $86, $74, $00, $00, $00, _NEWLINE

        DEFB 2022 >> 8
        DEFB 2022 & $FF
        DEFW $0014
        DEFB _POKE, _N, _MINUS, _1, _NUMBER, $81, $00, $00, $00, $00
        DEFB _COMMA, _2, _3, _NUMBER, $85, $38, $00, $00, $00, _NEWLINE

        DEFB 2023 >> 8
        DEFB 2023 & $FF
        DEFW $000C
        DEFB _POKE, _N, _COMMA, _5, _3, _NUMBER, $86, $54, $00, $00, $00
        DEFB _NEWLINE

        DEFB 2024 >> 8
        DEFB 2024 & $FF
        DEFW $0013
        DEFB _POKE, _N, _PLUS, _1, _NUMBER, $81, $00, $00, $00, $00
        DEFB _COMMA, _0, _NUMBER, $00, $00, $00, $00, $00, _NEWLINE

        DEFB 2025 >> 8
        DEFB 2025 & $FF
        DEFW $0016
        DEFB _POKE, _N, _PLUS, _6, _5, _NUMBER, $87, $02, $00, $00, $00
        DEFB _COMMA, _1, _8, _4, _NUMBER, $88, $38, $00, $00, $00
        DEFB _NEWLINE

        DEFB 2026 >> 8
        DEFB 2026 & $FF
        DEFW $0015
        DEFB _POKE, _N, _PLUS, _6, _3, _NUMBER, $86, $7C, $00, $00, $00
        DEFB _COMMA, _2, _3, _NUMBER, $85, $38, $00, $00, $00, _NEWLINE

        DEFB 2027 >> 8
        DEFB 2027 & $FF
        DEFW $0016
        DEFB _POKE, _N, _PLUS, _6, _2, _NUMBER, $86, $78, $00, $00, $00
        DEFB _COMMA, _1, _8, _9, _NUMBER, $88, $3D, $00, $00, $00
        DEFB _NEWLINE

        DEFB 2030 >> 8
        DEFB 2030 & $FF
        DEFW $0005
        DEFB _GOSUB, _S, _U, _R, _NEWLINE

        DEFB 2031 >> 8
        DEFB 2031 & $FF
        DEFW $0004
        DEFB _GOSUB, _P, _R, _NEWLINE

        DEFB 2032 >> 8
        DEFB 2032 & $FF
        DEFW $002A
        DEFB _PRINT, _AT, _1, _NUMBER, $81, $00, $00, $00, $00, _COMMA
        DEFB _6, _NUMBER, $83, $40, $00, $00, $00, _SEMICOLON, _QUOTE
        DEFB _A, _SPACE, _M, _A, _Z, _E, _SPACE, _A, _D, _V, _E, _N, _T
        DEFB _U, _R, _E, _SPACE, _G, _A, _M, _E, _QUOTE, _NEWLINE

        DEFB 2034 >> 8
        DEFB 2034 & $FF
        DEFW $000C
        DEFB _GOSUB, _2, _0, _4, _6, _NUMBER, $8B, $7F, $C0, $00, $00
        DEFB _NEWLINE

        DEFB 2036 >> 8
        DEFB 2036 & $FF
        DEFW $002A
        DEFB _PRINT, _AT, _1, _NUMBER, $81, $00, $00, $00, $00, _COMMA
        DEFB _6, _NUMBER, $83, $40, $00, $00, $00, _SEMICOLON, _QUOTE
        DEFB _INVP, _INVR, _INVE, _INVS, _INVS, _BLACK, _INVA, _BLACK
        DEFB _INVK, _INVE, _INVY, _BLACK, _INVT, _INVO, _BLACK
        DEFB _INVS, _INVT, _INVA, _INVR, _INVT, _INVCHEQUERBOARD, _QUOTE
        DEFB _NEWLINE

        DEFB 2038 >> 8
        DEFB 2038 & $FF
        DEFW $000C
        DEFB _GOSUB, _2, _0, _4, _6, _NUMBER, $8B, $7F, $C0, $00, $00
        DEFB _NEWLINE

        DEFB 2040 >> 8
        DEFB 2040 & $FF
        DEFW $000C
        DEFB _GOTO, _2, _0, _3, _2, _NUMBER, $8B, $7E, $00, $00, $00
        DEFB _NEWLINE

        DEFB 2046 >> 8
        DEFB 2046 & $FF
        DEFW $0014
        DEFB _FOR, _A, _EQUALS, _4, _NUMBER, $83, $00, $00, $00, $00
        DEFB _TO, _2, _1, _NUMBER, $85, $28, $00, $00, $00, _NEWLINE

        DEFB 2050 >> 8
        DEFB 2050 & $FF
        DEFW $0004
        DEFB _GOSUB, _P, _R, _NEWLINE

        DEFB 2054 >> 8
        DEFB 2054 & $FF
        DEFW $0016
        DEFB _PRINT, _AT, _A, _COMMA, _2, _5
        DEFB _NUMBER, $85, $48, $00, $00, $00, _SEMICOLON, _QUOTE
        DEFB _M, _A, _Z, _O, _G, _S, _QUOTE, _NEWLINE

        DEFB 2063 >> 8
        DEFB 2063 & $FF
        DEFW $0012
        DEFB _IF, _INKEY, _NOTEQUAL, _QUOTE, _QUOTE, _THEN, _GOTO
        DEFB _2, _0, _8, _0, _NUMBER, $8C, $02, $00, $00, $00, _NEWLINE

        DEFB 2064 >> 8
        DEFB 2064 & $FF
        DEFW $0003
        DEFB _NEXT, _A, _NEWLINE

        DEFB 2066 >> 8
        DEFB 2066 & $FF
        DEFW $0015
        DEFB _POKE, _1, _8, _6, _1, _9, _NUMBER, $8F, $11, $76, $00, $00
        DEFB _COMMA, _5, _NUMBER, $83, $20, $00, $00, $00, _NEWLINE

        DEFB 2068 >> 8
        DEFB 2068 & $FF
        DEFW $0004
        DEFB _GOSUB, _P, _R, _NEWLINE

        DEFB 2070 >> 8
        DEFB 2070 & $FF
        DEFW $0015
        DEFB _POKE, _1, _8, _6, _1, _9, _NUMBER, $8F, $11, $76, $00, $00
        DEFB _COMMA, _4, _NUMBER, $83, $00, $00, $00, $00, _NEWLINE

        DEFB 2072 >> 8
        DEFB 2072 & $FF
        DEFW $0002
        DEFB _RETURN, _NEWLINE 

        DEFB 2080 >> 8
        DEFB 2080 & $FF
        DEFW $0015
        DEFB _POKE, _1, _8, _6, _1, _9, _NUMBER, $8F, $11, $76, $00, $00
        DEFB _COMMA, _5, _NUMBER, $83, $20, $00, $00, $00, _NEWLINE

        DEFB 2081 >> 8
        DEFB 2081 & $FF
        DEFW $0004
        DEFB _GOSUB, _B, _B, _NEWLINE

        DEFB 2082 >> 8
        DEFB 2082 & $FF
        DEFW $0017
        DEFB _POKE, _N, _MINUS, _1, _2, _8
        DEFB _NUMBER, $88, $00, $00, $00, $00, _COMMA, _1, _8, _9
        DEFB _NUMBER, $88, $3D, $00, $00, $00, _NEWLINE

        DEFB 2084 >> 8
        DEFB 2084 & $FF
        DEFW $0010
        DEFB _LET, _X, _EQUALS, _USR, _1, _8, _6, _0, _2
        DEFB _NUMBER, $8F, $11, $54, $00, $00, _NEWLINE

        DEFB 2086 >> 8
        DEFB 2086 & $FF
        DEFW $0022
        DEFB _PRINT, _AT, _1, _NUMBER, $81, $00, $00, $00, $00, _COMMA
        DEFB _1, _0, _NUMBER, $84, $20, $00, $00, $00, _SEMICOLON, _QUOTE
        DEFB _W, _H, _I, _C, _H, _SPACE, _G, _A, _M, _E, _SPACE
        DEFB _QUESTIONMARK, _QUOTE, _NEWLINE

        DEFB 2088 >> 8
        DEFB 2088 & $FF
        DEFW $0023
        DEFB _PRINT, _AT, _1, _0, _NUMBER, $84, $20, $00, $00, $00
        DEFB _COMMA, _5, _NUMBER, $83, $20, $00, $00, $00, _SEMICOLON
        DEFB _QUOTE, _1, _FULLSTOP, _SPACE, _T, _R, _Y, _SPACE, _I, _T
        DEFB _SPACE, _O, _U, _T, _QUOTE, _NEWLINE

        DEFB 2090 >> 8
        DEFB 2090 & $FF
        DEFW $0029
        DEFB _PRINT, _AT, _1, _2, _NUMBER, $84, $40, $00, $00, $00
        DEFB _COMMA, _5, _NUMBER, $83, $20, $00, $00, $00, _SEMICOLON
        DEFB _QUOTE, _2, _FULLSTOP, _SPACE, _F, _A, _C, _E, _SPACE, _A
        DEFB _SPACE, _C, _H, _A, _L, _L, _E, _N, _G, _E, _QUOTE, _NEWLINE

        DEFB 2092 >> 8
        DEFB 2092 & $FF
        DEFW $002D
        DEFB _PRINT, _AT, _1, _4, _NUMBER, $84, $60, $00, $00, $00
        DEFB _COMMA, _5, _NUMBER, $83, $20, $00, $00, $00, _SEMICOLON
        DEFB _QUOTE, _3, _FULLSTOP, _SPACE, _M, _A, _N, _I, _A, _C
        DEFB _SPACE, _M, _O, _B, _I, _L, _E, _SPACE, _M, _A, _Z, _O, _G
        DEFB _S, _QUOTE, _NEWLINE

        DEFB 2094 >> 8
        DEFB 2094 & $FF
        DEFW $002C
        DEFB _PRINT, _AT, _1, _8, _NUMBER, $85, $10, $00, $00, $00
        DEFB _COMMA, _5, _NUMBER, $83, $20, $00, $00, $00, _SEMICOLON
        DEFB _QUOTE, _P, _R, _E, _S, _S, _SPACE, _N, _U, _M, _B, _E, _R
        DEFB _SPACE, _T, _O, _SPACE, _C, _H, _O, _O, _S, _E, _QUOTE
        DEFB _NEWLINE

        DEFB 2096 >> 8
        DEFB 2096 & $FF
        DEFW $0005
        DEFB _GOSUB, _I, _N, _K, _NEWLINE

        DEFB 2098 >> 8
        DEFB 2098 & $FF
        DEFW $0006
        DEFB _LET, _K, _DOLLAR, _EQUALS, _INKEY, _NEWLINE

        DEFB 2110 >> 8
        DEFB 2110 & $FF
        DEFW $0014
        DEFB _IF, _K, _DOLLAR, _EQUALS, _QUOTE, _1, _QUOTE, _THEN, _GOTO
        DEFB _2, _1, _5, _0, _NUMBER, $8C, $06, $60, $00, $00, _NEWLINE

        DEFB 2112 >> 8
        DEFB 2112 & $FF
        DEFW $0014
        DEFB _IF, _K, _DOLLAR, _EQUALS, _QUOTE, _2, _QUOTE, _THEN, _GOTO
        DEFB _2, _2, _0, _0, _NUMBER, $8C, $09, $80, $00, $00, _NEWLINE

        DEFB 2114 >> 8
        DEFB 2114 & $FF
        DEFW $0014
        DEFB _IF, _K, _DOLLAR, _EQUALS, _QUOTE, _3, _QUOTE, _THEN, _GOTO
        DEFB _2, _2, _5, _0, _NUMBER, $8C, $0C, $A0, $00, $00, _NEWLINE

        DEFB 2116 >> 8
        DEFB 2116 & $FF
        DEFW $000C
        DEFB _GOTO, _2, _0, _8, _0, _NUMBER, $8C, $02, $00, $00, $00
        DEFB _NEWLINE

        DEFB 2152 >> 8
        DEFB 2152 & $FF
        DEFW $0004
        DEFB _GOSUB, _B, _B, _NEWLINE

        DEFB 2154 >> 8
        DEFB 2154 & $FF
        DEFW $0016
        DEFB _POKE, _N, _MINUS, _1, _2, _8
        DEFB _NUMBER, $88, $00, $00, $00, $00, _COMMA, _3, _5
        DEFB _NUMBER, $86, $0C, $00, $00, $00, _NEWLINE

        DEFB 2155 >> 8
        DEFB 2155 & $FF
        DEFW $000E
        DEFB _RAND, _USR, _1, _8, _6, _0, _2
        DEFB _NUMBER, $8F, $11, $54, $00, $00, _NEWLINE

        DEFB 2156 >> 8
        DEFB 2156 & $FF
        DEFW $0020
        DEFB _PRINT, _AT, _1, _NUMBER, $81, $00, $00, $00, $00, _COMMA
        DEFB _1, _1, _NUMBER, $84, $30, $00, $00, $00, _SEMICOLON
        DEFB _QUOTE, _T, _R, _Y, _SPACE, _I, _T, _SPACE, _O, _U, _T
        DEFB _QUOTE, _NEWLINE

        DEFB 2162 >> 8
        DEFB 2162 & $FF
        DEFW $0005
        DEFB _GOSUB, _M, _D, _R, _NEWLINE

        DEFB 2166 >> 8
        DEFB 2166 & $FF
        DEFW $0015
        DEFB _POKE, _1, _9, _2, _1, _2, _NUMBER, $8F, $16, $18, $00, $00
        DEFB _COMMA, _1, _NUMBER, $81, $00, $00, $00, $00, _NEWLINE

        DEFB 2168 >> 8
        DEFB 2168 & $FF
        DEFW $0015
        DEFB _POKE, _1, _9, _2, _1, _3, _NUMBER, $8F, $16, $1A, $00, $00
        DEFB _COMMA, _0, _NUMBER, $00, $00, $00, $00, $00, _NEWLINE

        DEFB 2170 >> 8
        DEFB 2170 & $FF
        DEFW $0017
        DEFB _POKE, _1, _9, _8, _9, _2, _NUMBER, $8F, $1B, $68, $00, $00
        DEFB _COMMA, _2, _0, _5, _NUMBER, $88, $4D, $00, $00, $00
        DEFB _NEWLINE

        DEFB 2171 >> 8
        DEFB 2171 & $FF
        DEFW $0017
        DEFB _POKE, _1, _9, _8, _9, _3, _NUMBER, $8F, $1B, $6A, $00, $00
        DEFB _COMMA, _1, _0, _9, _NUMBER, $87, $5A, $00, $00, $00
        DEFB _NEWLINE

        DEFB 2172 >> 8
        DEFB 2172 & $FF
        DEFW $0016
        DEFB _POKE, _1, _9, _8, _9, _4, _NUMBER, $8F, $1B, $6C, $00, $00
        DEFB _COMMA, _6, _6, _NUMBER, $87, $04, $00, $00, $00, _NEWLINE

        DEFB 2174 >> 8
        DEFB 2174 & $FF
        DEFW $000C
        DEFB _GOTO, _3, _0, _0, _0, _NUMBER, $8C, $3B, $80, $00, $00
        DEFB _NEWLINE

        DEFB 2202 >> 8
        DEFB 2202 & $FF
        DEFW $0004
        DEFB _GOSUB, _B, _B, _NEWLINE

        DEFB 2204 >> 8
        DEFB 2204 & $FF
        DEFW $0016
        DEFB _POKE, _N, _MINUS, _1, _2, _8
        DEFB _NUMBER, $88, $00, $00, $00, $00, _COMMA, _3, _9
        DEFB _NUMBER, $86, $1C, $00, $00, $00, _NEWLINE

        DEFB 2206 >> 8
        DEFB 2206 & $FF
        DEFW $0004
        DEFB _GOSUB, _P, _R, _NEWLINE

        DEFB 2208 >> 8
        DEFB 2208 & $FF
        DEFW $0025
        DEFB _PRINT, _AT, _1, _NUMBER, $81, $00, $00, $00, $00, _COMMA
        DEFB _8, _NUMBER, $84, $00, $00, $00, $00, _SEMICOLON, _QUOTE
        DEFB _F, _A, _C, _E, _SPACE, _A, _SPACE, _C, _H, _A, _L, _L, _E
        DEFB _N, _G, _E, _QUOTE, _NEWLINE

        DEFB 2216 >> 8
        DEFB 2216 & $FF
        DEFW $0005
        DEFB _GOSUB, _M, _D, _R, _NEWLINE

        DEFB 2220 >> 8
        DEFB 2220 & $FF
        DEFW $0015
        DEFB _POKE, _1, _9, _2, _1, _2, _NUMBER, $8F, $16, $18, $00, $00
        DEFB _COMMA, _0, _NUMBER, $00, $00, $00, $00, $00, _NEWLINE

        DEFB 2222 >> 8
        DEFB 2222 & $FF
        DEFW $0015
        DEFB _POKE, _1, _9, _2, _1, _3, _NUMBER, $8F, $16, $1A, $00, $00
        DEFB _COMMA, _0, _NUMBER, $00, $00, $00, $00, $00, _NEWLINE

        DEFB 2223 >> 8
        DEFB 2223 & $FF
        DEFW $0015
        DEFB _POKE, _2, _0, _3, _1, _0, _NUMBER, $8F, $1E, $AC, $00, $00
        DEFB _COMMA, _1, _NUMBER, $81, $00, $00, $00, $00, _NEWLINE

        DEFB 2224 >> 8
        DEFB 2224 & $FF
        DEFW $000C
        DEFB _GOTO, _3, _0, _0, _0, _NUMBER, $8C, $3B, $80, $00, $00
        DEFB _NEWLINE

        DEFB 2250 >> 8
        DEFB 2250 & $FF
        DEFW $0029
        DEFB _PRINT, _AT, _1, _NUMBER, $81, $00, $00, $00, $00, _COMMA
        DEFB _6, _NUMBER, $83, $40, $00, $00, $00, _SEMICOLON, _QUOTE
        DEFB _M, _A, _N, _I, _A, _C, _SPACE, _M, _O, _B, _I, _L, _E
        DEFB _SPACE, _M, _A, _Z, _O, _G, _S, _QUOTE, _NEWLINE

        DEFB 2254 >> 8
        DEFB 2254 & $FF
        DEFW $0016
        DEFB _POKE, _N, _MINUS, _1, _2, _8
        DEFB _NUMBER, $88, $00, $00, $00, $00, _COMMA, _2, _9
        DEFB _NUMBER, $85, $68, $00, $00, $00, _NEWLINE

        DEFB 2256 >> 8
        DEFB 2256 & $FF
        DEFW $0016
        DEFB _POKE, _N, _MINUS, _1, _2, _9
        DEFB _NUMBER, $88, $01, $00, $00, $00, _COMMA, _6, _1
        DEFB _NUMBER, $86, $74, $00, $00, $00, _NEWLINE

        DEFB 2258 >> 8
        DEFB 2258 & $FF
        DEFW $0016
        DEFB _POKE, _N, _MINUS, _1, _2, _7
        DEFB _NUMBER, $87, $7E, $00, $00, $00, _COMMA, _6, _1
        DEFB _NUMBER, $86, $74, $00, $00, $00, _NEWLINE

        DEFB 2260 >> 8
        DEFB 2260 & $FF
        DEFW $0014
        DEFB _FOR, _A, _EQUALS, _1, _NUMBER, $81, $00, $00, $00, $00
        DEFB _TO, _1, _0, _NUMBER, $84, $20, $00, $00, $00, _NEWLINE

        DEFB 2262 >> 8
        DEFB 2262 & $FF
        DEFW $0004
        DEFB _GOSUB, _P, _R, _NEWLINE

        DEFB 2264 >> 8
        DEFB 2264 & $FF
        DEFW $0003
        DEFB _NEXT, _A, _NEWLINE

        DEFB 2269 >> 8
        DEFB 2269 & $FF
        DEFW $0005
        DEFB _GOSUB, _M, _D, _R, _NEWLINE

        DEFB 2270 >> 8
        DEFB 2270 & $FF
        DEFW $0015
        DEFB _POKE, _1, _9, _2, _1, _2, _NUMBER, $8F, $16, $18, $00, $00
        DEFB _COMMA, _0, _NUMBER, $00, $00, $00, $00, $00, _NEWLINE

        DEFB 2272 >> 8
        DEFB 2272 & $FF
        DEFW $0015
        DEFB _POKE, _1, _9, _2, _1, _3, _NUMBER, $8F, $16, $1A, $00, $00
        DEFB _COMMA, _1, _NUMBER, $81, $00, $00, $00, $00, _NEWLINE

        DEFB 2276 >> 8
        DEFB 2276 & $FF
        DEFW $0015
        DEFB _POKE, _2, _0, _3, _1, _0, _NUMBER, $8F, $1E, $AC, $00, $00
        DEFB _COMMA, _0, _NUMBER, $00, $00, $00, $00, $00, _NEWLINE

        DEFB 2278 >> 8
        DEFB 2278 & $FF
        DEFW $0017
        DEFB _POKE, _1, _9, _2, _7, _3, _NUMBER, $8F, $16, $92, $00, $00
        DEFB _COMMA, _2, _5, _3, _NUMBER, $88, $7D, $00, $00, $00
        DEFB _NEWLINE

        DEFB 2280 >> 8
        DEFB 2280 & $FF
        DEFW $000C
        DEFB _GOTO, _3, _0, _0, _0, _NUMBER, $8C, $3B, $80, $00, $00
        DEFB _NEWLINE

        DEFB 3000 >> 8
        DEFB 3000 & $FF
        DEFW $0005
        DEFB _GOSUB, _S, _U, _R, _NEWLINE

        DEFB 3002 >> 8
        DEFB 3002 & $FF
        DEFW $000E
        DEFB _RAND, _USR, _2, _0, _6, _3, _1
        DEFB _NUMBER, $8F, $21, $2E, $00, $00, _NEWLINE

        DEFB 3010 >> 8
        DEFB 3010 & $FF
        DEFW $000E
        DEFB _RAND, _USR, _1, _9, _2, _2, _6
        DEFB _NUMBER, $8F, $16, $34, $00, $00, _NEWLINE

        DEFB 3012 >> 8
        DEFB 3012 & $FF
        DEFW $001A
        DEFB _IF, _PEEK, _1, _9, _2, _2, _0
        DEFB _NUMBER, $8F, $16, $28, $00, $00, _THEN, _GOTO
        DEFB _3, _1, _0, _0, _NUMBER, $8C, $41, $C0, $00, $00, _NEWLINE

        DEFB 3014 >> 8
        DEFB 3014 & $FF
        DEFW $001A
        DEFB _IF, _PEEK, _1, _9, _2, _2, _1
        DEFB _NUMBER, $8F, $16, $2A, $00, $00, _THEN, _GOTO
        DEFB _3, _1, _5, _0, _NUMBER, $8C, $44, $E0, $00, $00, _NEWLINE

        DEFB 3020 >> 8
        DEFB 3020 & $FF
        DEFW $001A
        DEFB _IF, _PEEK, _1, _9, _2, _2, _2
        DEFB _NUMBER, $8F, $16, $2C, $00, $00, _THEN, _GOTO
        DEFB _3, _0, _6, _0, _NUMBER, $8C, $3F, $40, $00, $00, _NEWLINE

        DEFB 3026 >> 8
        DEFB 3026 & $FF
        DEFW $000C
        DEFB _GOSUB, _6, _0, _3, _7, _NUMBER, $8D, $3C, $A8, $00, $00
        DEFB _NEWLINE

        DEFB 3030 >> 8
        DEFB 3030 & $FF
        DEFW $0014
        DEFB _FOR, _A, _EQUALS, _1, _NUMBER, $81, $00, $00, $00, $00
        DEFB _TO, _4, _0, _NUMBER, $86, $20, $00, $00, $00, _NEWLINE

        DEFB 3031 >> 8
        DEFB 3031 & $FF
        DEFW $000E
        DEFB _RAND, _USR, _1, _8, _6, _0, _2
        DEFB _NUMBER, $8F, $11, $54, $00, $00, _NEWLINE

        DEFB 3032 >> 8
        DEFB 3032 & $FF
        DEFW $0034
        DEFB _PRINT, _AT, _1, _8, _NUMBER, $85, $10, $00, $00, $00, _COMMA
        DEFB _1, _NUMBER, $81, $00, $00, $00, $00, _SEMICOLON, _QUOTE
        DEFB _INVD, _INVE, _INVA, _INVT, _INVH, _BLACK, _BLACK, _INVT, _INVO
        DEFB _BLACK, _INVA, _INVL, _INVL, _BLACK, _INVT, _INVR, _INVE
        DEFB _INVA, _INVS, _INVU, _INVR, _INVE, _BLACK, _INVS, _INVE
        DEFB _INVE, _INVK, _INVE, _INVR, _INVS, _QUOTE, _NEWLINE

        DEFB 3034 >> 8
        DEFB 3034 & $FF
        DEFW $0003
        DEFB _NEXT, _A, _NEWLINE

        DEFB 3040 >> 8
        DEFB 3040 & $FF
        DEFW $000C
        DEFB _GOTO, _3, _2, _0, _0, _NUMBER, $8C, $48, $00, $00, $00
        DEFB _NEWLINE

        DEFB 3060 >> 8
        DEFB 3060 & $FF
        DEFW $000C
        DEFB _GOSUB, _6, _4, _5, _0, _NUMBER, $8D, $49, $90, $00, $00
        DEFB _NEWLINE

        DEFB 3062 >> 8
        DEFB 3062 & $FF
        DEFW $0035
        DEFB _IF, _P, _DOLLAR, _NOTEQUAL, _QUOTE, _T, _QUOTE, _OR, _PEEK
        DEFB _1, _9, _2, _1, _7, _NUMBER, $8F, $16, $22, $00, $00, _OR
        DEFB _PEEK, _1, _9, _2, _1, _6, _NUMBER, $8F, $16, $20, $00, $00
        DEFB _OR, _K, _DOLLAR, _EQUALS, _QUOTE, _1, _QUOTE, _THEN, _GOTO
        DEFB _3, _0, _7, _0, _NUMBER, $8C, $3F, $E0, $00, $00, _NEWLINE

        DEFB 3064 >> 8
        DEFB 3064 & $FF
        DEFW $0019
        DEFB _LET, _N, _EQUALS, _INT, _OPENBRACKET, _M, _L, _DIVIDE
        DEFB _2, _NUMBER, $82, $00, $00, $00, $00, _CLOSEBRACKET, _PLUS
        DEFB _1, _NUMBER, $81, $00, $00, $00, $00, _NEWLINE

        DEFB 3065 >> 8
        DEFB 3065 & $FF
        DEFW $0017
        DEFB _IF, _N, _LESSTHANEQUAL, _2
        DEFB _NUMBER, $82, $00, $00, $00, $00, _THEN, _GOTO
        DEFB _3, _0, _7, _0, _NUMBER, $8C, $3F, $E0, $00, $00, _NEWLINE

        DEFB 3066 >> 8
        DEFB 3066 & $FF
        DEFW $0006
        DEFB _GOSUB, _P, _O, _K, _E, _NEWLINE

        DEFB 3068 >> 8
        DEFB 3068 & $FF
        DEFW $0015
        DEFB _POKE, _1, _9, _2, _1, _6, _NUMBER, $8F, $16, $20, $00, $00
        DEFB _COMMA, _1, _NUMBER, $81, $00, $00, $00, $00, _NEWLINE

        DEFB 3070 >> 8
        DEFB 3070 & $FF
        DEFW $0005
        DEFB _GOSUB, _S, _U, _R, _NEWLINE

        DEFB 3072 >> 8
        DEFB 3072 & $FF
        DEFW $000E
        DEFB _RAND, _USR, _2, _0, _6, _3, _1
        DEFB _NUMBER, $8F, $21, $2E, $00, $00, _NEWLINE

        DEFB 3074 >> 8
        DEFB 3074 & $FF
        DEFW $000E
        DEFB _RAND, _USR, _1, _9, _2, _3, _9
        DEFB _NUMBER, $8F, $16, $4E, $00, $00, _NEWLINE

        DEFB 3076 >> 8
        DEFB 3076 & $FF
        DEFW $000C
        DEFB _GOTO, _3, _0, _1, _2, _NUMBER, $8C, $3C, $40, $00, $00
        DEFB _NEWLINE

        DEFB 3100 >> 8
        DEFB 3100 & $FF
        DEFW $0017
        DEFB _POKE, _1, _7, _3, _7, _0, _NUMBER, $8F, $07, $B4, $00, $00
        DEFB _COMMA, _1, _2, _8, _NUMBER, $88, $00, $00, $00, $00
        DEFB _NEWLINE

        DEFB 3116 >> 8
        DEFB 3116 & $FF
        DEFW $0005
        DEFB _GOSUB, _S, _U, _R, _NEWLINE

        DEFB 3118 >> 8
        DEFB 3118 & $FF
        DEFW $0014
        DEFB _FOR, _A, _EQUALS, _1, _NUMBER, $81, $00, $00, $00, $00
        DEFB _TO, _3, _5, _NUMBER, $86, $0C, $00, $00, $00, _NEWLINE

        DEFB 3120 >> 8
        DEFB 3120 & $FF
        DEFW $002F
        DEFB _PRINT, _AT, _1, _0, _NUMBER, $84, $20, $00, $00, $00
        DEFB _COMMA, _4, _NUMBER, $83, $00, $00, $00, $00, _SEMICOLON
        DEFB _QUOTE, _Y, _O, _U, _SPACE, _H, _A, _V, _E, _SPACE
        DEFB _S, _T, _A, _R, _V, _E, _D, _SPACE, _T, _O, _SPACE
        DEFB _D, _E, _A, _T, _H, _QUOTE, _NEWLINE

        DEFB 3122 >> 8
        DEFB 3122 & $FF
        DEFW $002F
        DEFB _PRINT, _AT, _1, _0, _NUMBER, $84, $20, $00, $00, $00
        DEFB _COMMA, _4, _NUMBER, $83, $00, $00, $00, $00, _SEMICOLON
        DEFB _QUOTE, _INVY, _INVO, _INVU, _BLACK, _INVH, _INVA, _INVV
        DEFB _INVE, _BLACK, _INVS, _INVT, _INVA, _INVR, _INVV, _INVE
        DEFB _INVD, _BLACK, _INVT, _INVO, _BLACK, _INVD, _INVE, _INVA
        DEFB _INVT, _INVH, _QUOTE, _NEWLINE

        DEFB 3124 >> 8
        DEFB 3124 & $FF
        DEFW $0003
        DEFB _NEXT, _A, _NEWLINE

        DEFB 3140 >> 8
        DEFB 3140 & $FF
        DEFW $000C
        DEFB _GOTO, _3, _2, _1, _4, _NUMBER, $8C, $48, $E0, $00, $00
        DEFB _NEWLINE

        DEFB 3160 >> 8
        DEFB 3160 & $FF
        DEFW $0014
        DEFB _IF, _D, _DOLLAR, _EQUALS, _QUOTE, _L, _QUOTE, _THEN, _GOTO
        DEFB _3, _1, _8, _0, _NUMBER, $8C, $46, $C0, $00, $00, _NEWLINE

        DEFB 3162 >> 8
        DEFB 3162 & $FF
        DEFW $000D
        DEFB _POKE, _H, _M, _COMMA, _2, _9
        DEFB _NUMBER, $85, $68, $00, $00, $00, _NEWLINE

        DEFB 3164 >> 8
        DEFB 3164 & $FF
        DEFW $0015
        DEFB _POKE, _H, _M, _PLUS, _1, _NUMBER, $81, $00, $00, $00, $00
        DEFB _COMMA, _3, _3, _NUMBER, $86, $04, $00, $00, $00, _NEWLINE

        DEFB 3165 >> 8
        DEFB 3165 & $FF
        DEFW $0015
        DEFB _POKE, _H, _M, _MINUS, _6, _4
        DEFB _NUMBER, $87, $00, $00, $00, $00, _COMMA, _0
        DEFB _NUMBER, $00, $00, $00, $00, $00, _NEWLINE

        DEFB 3166 >> 8
        DEFB 3166 & $FF
        DEFW $0004
        DEFB _GOSUB, _P, _R, _NEWLINE

        DEFB 3168 >> 8
        DEFB 3168 & $FF
        DEFW $001A
        DEFB _PRINT, _AT, _1, _0, _NUMBER, $84, $20, $00, $00, $00
        DEFB _COMMA, _8, _NUMBER, $84, $00, $00, $00, $00, _SEMICOLON
        DEFB _QUOTE,  _E, _X, _I, _T, _QUOTE, _NEWLINE

        DEFB 3170 >> 8
        DEFB 3170 & $FF
        DEFW $0014
        DEFB _FOR, _A, _EQUALS, _1, _NUMBER, $81, $00, $00, $00, $00
        DEFB _TO, _6, _0, _NUMBER, $86, $70, $00, $00, $00, _NEWLINE

        DEFB 3172 >> 8
        DEFB 3172 & $FF
        DEFW $0022
        DEFB _PRINT, _AT, _1, _8, _NUMBER, $85, $10, $00, $00, $00
        DEFB _COMMA, _7, _NUMBER, $83, $60, $00, $00, $00, _SEMICOLON
        DEFB _QUOTE, _INVW, _INVE, _INVL, _INVC, _INVO, _INVM, _INVE
        DEFB _BLACK, _INVB, _INVA, _INVC, _INVK, _QUOTE, _NEWLINE

        DEFB 3174 >> 8
        DEFB 3174 & $FF
        DEFW $0022
        DEFB _PRINT, _AT, _1, _8, _NUMBER, $85, $10, $00, $00, $00
        DEFB _COMMA, _7, _NUMBER, $83, $60, $00, $00, $00, _SEMICOLON
        DEFB _QUOTE, _W, _E, _L, _C, _O, _M, _E, _SPACE, _B, _A, _C, _K
        DEFB _QUOTE, _NEWLINE

        DEFB 3176 >> 8
        DEFB 3176 & $FF
        DEFW $0003
        DEFB _NEXT, _A, _NEWLINE

        DEFB 3178 >> 8
        DEFB 3178 & $FF
        DEFW $000C
        DEFB _GOTO, _3, _2, _0, _0, _NUMBER, $8C, $48, $00, $00, $00
        DEFB _NEWLINE

        DEFB 3180 >> 8
        DEFB 3180 & $FF
        DEFW $000D
        DEFB _POKE, _H, _M, _COMMA, _2, _9
        DEFB _NUMBER, $85, $68, $00, $00, $00, _NEWLINE

        DEFB 3182 >> 8
        DEFB 3182 & $FF
        DEFW $0015
        DEFB _POKE, _H, _M, _MINUS, _1, _NUMBER, $81, $00, $00, $00, $00
        DEFB _COMMA, _3, _3, _NUMBER, $86, $04, $00, $00, $00, _NEWLINE

        DEFB 3184 >> 8
        DEFB 3184 & $FF
        DEFW $0015
        DEFB _POKE, _H, _M, _MINUS, _6, _4
        DEFB _NUMBER, $87, $00, $00, $00, $00, _COMMA, _0
        DEFB _NUMBER, $00, $00, $00, $00, $00, _NEWLINE

        DEFB 3186 >> 8
        DEFB 3186 & $FF
        DEFW $0004
        DEFB _GOSUB, _P, _R, _NEWLINE

        DEFB 3188 >> 8
        DEFB 3188 & $FF
        DEFW $001B
        DEFB _PRINT, _AT, _1, _0, _NUMBER, $84, $20, $00, $00, $00
        DEFB _COMMA, _2, _0, _NUMBER, $85, $20, $00, $00, $00, _SEMICOLON
        DEFB _QUOTE, _E, _X, _I, _T, _QUOTE, _NEWLINE

        DEFB 3190 >> 8
        DEFB 3190 & $FF
        DEFW $0014
        DEFB _FOR, _A, _EQUALS, _1, _NUMBER, $81, $00, $00, $00, $00
        DEFB _TO, _6, _0, _NUMBER, $86, $70, $00, $00, $00, _NEWLINE

        DEFB 3192 >> 8
        DEFB 3192 & $FF
        DEFW $0023
        DEFB _PRINT, _AT, _1, _8, _NUMBER, $85, $10, $00, $00, $00
        DEFB _COMMA, _1, _3, _NUMBER, $84, $50, $00, $00, $00, _SEMICOLON
        DEFB _QUOTE, _INVW, _INVE, _INVL, _INVC, _INVO, _INVM, _INVE
        DEFB _BLACK, _INVB, _INVA, _INVC, _INVK, _QUOTE, _NEWLINE

        DEFB 3194 >> 8
        DEFB 3194 & $FF
        DEFW $0023
        DEFB _PRINT, _AT, _1, _8, _NUMBER, $85, $10, $00, $00, $00
        DEFB _COMMA, _1, _3, _NUMBER, $84, $50, $00, $00, $00, _SEMICOLON
        DEFB _QUOTE, _W, _E, _L, _C, _O, _M, _E, _SPACE, _B, _A, _C, _K
        DEFB _QUOTE, _NEWLINE

        DEFB 3196 >> 8
        DEFB 3196 & $FF
        DEFW $0003
        DEFB _NEXT, _A, _NEWLINE

        DEFB 3200 >> 8
        DEFB 3200 & $FF
        DEFW $0005
        DEFB _GOSUB, _S, _U, _R, _NEWLINE

        DEFB 3216 >> 8
        DEFB 3216 & $FF
        DEFW $0022
        DEFB _IF, _K, _DOLLAR, _EQUALS, _QUOTE, _1, _QUOTE, _OR, _NOT
        DEFB _PEEK, _1, _9, _2, _2, _1, _NUMBER, $8F, $16, $2A, $00, $00
        DEFB _THEN, _GOTO, _4, _5, _0, _0
        DEFB _NUMBER, $8D, $0C, $A0, $00, $00, _NEWLINE

        DEFB 4000 >> 8
        DEFB 4000 & $FF
        DEFW $001B
        DEFB _PRINT, _AT, _4, _NUMBER, $83, $00, $00, $00, $00, _COMMA
        DEFB _1, _3, _NUMBER, $84, $50, $00, $00, $00, _SEMICOLON, _QUOTE
        DEFB _INVS, _INVC, _INVO, _INVR, _INVE, _QUOTE, _NEWLINE

        DEFB 4030 >> 8
        DEFB 4030 & $FF
        DEFW $0022
        DEFB _PRINT, _AT, _7, _NUMBER, $83, $60, $00, $00, $00, _COMMA
        DEFB _C, _SEMICOLON, _QUOTE, _M, _O, _V, _E, _S, _SPACE
        DEFB _A, _L, _L, _O, _W, _E, _D, _SPACE, _EQUALS, _SPACE, _QUOTE
        DEFB _SEMICOLON, _M, _A, _NEWLINE

        DEFB 4031 >> 8
        DEFB 4031 & $FF
        DEFW $0002
        DEFB _PRINT, _NEWLINE

        DEFB 4034 >> 8
        DEFB 4034 & $FF
        DEFW $0028
        DEFB _LET, _M, _L, _EQUALS, _PEEK, _1, _9, _2, _1, _4
        DEFB _NUMBER, $8F, $16, $1C, $00, $00, _PLUS, _PEEK
        DEFB _1, _9, _2, _1, _5, _NUMBER, $8F, $16, $1E, $00, $00
        DEFB _ASTERISK, _2, _5, _6, _NUMBER, $89, $00, $00, $00, $00
        DEFB _NEWLINE

        DEFB 4038 >> 8
        DEFB 4038 & $FF
        DEFW $0016
        DEFB _PRINT, _QUOTE, _INVCHEQUERBOARD, _INVCHEQUERBOARD, _M, _O
        DEFB _V, _E, _S, _SPACE, _L, _E, _F, _T, _SPACE, _EQUALS, _SPACE
        DEFB _QUOTE, _SEMICOLON, _M, _L, _NEWLINE

        DEFB 4040 >> 8
        DEFB 4040 & $FF
        DEFW $0002
        DEFB _PRINT, _NEWLINE

        DEFB 4046 >> 8
        DEFB 4046 & $FF
        DEFW $002D
        DEFB _PRINT, _QUOTE, _INVCHEQUERBOARD, _INVCHEQUERBOARD, _S, _C
        DEFB _O, _R, _E, _SPACE, _EQUALS, _SPACE, _QUOTE, _SEMICOLON
        DEFB _INT, _OPENBRACKET, _M, _L, _DIVIDE, _M, _A, _ASTERISK
        DEFB _1, _0, _0, _NUMBER, $87, $48, $00, $00, $00, _CLOSEBRACKET
        DEFB _SEMICOLON, _QUOTE, _SPACE, _P, _E, _R, _SPACE
        DEFB _C, _E, _N, _T, _QUOTE, _NEWLINE

        DEFB 4500 >> 8
        DEFB 4500 & $FF
        DEFW $002D
        DEFB _PRINT, _AT, _1, _8, _NUMBER, $85, $10, $00, $00, $00
        DEFB _COMMA, _C, _SEMICOLON, _QUOTE, _P, _R, _E, _S, _S, _SPACE
        DEFB _DOUBLEQUOTE, _M, _DOUBLEQUOTE, _SPACE, _T, _O, _SPACE
        DEFB _E, _X, _A, _M, _I, _N, _E, _SPACE, _T, _H, _E, _SPACE
        DEFB _M, _A, _Z, _E, _QUOTE, _NEWLINE

        DEFB 4520 >> 8
        DEFB 4520 & $FF
        DEFW $0027
        DEFB _PRINT, _AT, _2, _0, _NUMBER, $85, $20, $00, $00, $00
        DEFB _COMMA, _C, _SEMICOLON, _QUOTE, _P, _R, _E, _S, _S, _SPACE
        DEFB _DOUBLEQUOTE, _G, _DOUBLEQUOTE, _SPACE, _FOR, _A, _N, _O
        DEFB _T, _H, _E, _R, _SPACE, _G, _A, _M, _E, _QUOTE, _NEWLINE

        DEFB 4522 >> 8
        DEFB 4522 & $FF
        DEFW $0005
        DEFB _GOSUB, _I, _N, _K, _NEWLINE

        DEFB 4524 >> 8
        DEFB 4524 & $FF
        DEFW $0006
        DEFB _LET, _K, _DOLLAR, _EQUALS, _INKEY, _NEWLINE

        DEFB 4530 >> 8
        DEFB 4530 & $FF
        DEFW $0014
        DEFB _IF, _K, _DOLLAR, _EQUALS, _QUOTE, _M, _QUOTE, _THEN, _GOTO
        DEFB _1, _0, _0, _0, _NUMBER, $8A, $7A, $00, $00, $00, _NEWLINE

        DEFB 4532 >> 8
        DEFB 4532 & $FF
        DEFW $000A
        DEFB _IF, _K, _DOLLAR, _EQUALS, _QUOTE, _G, _QUOTE, _THEN, _RUN
        DEFB _NEWLINE

        DEFB 4534 >> 8
        DEFB 4534 & $FF
        DEFW $000C
        DEFB _GOTO, _4, _5, _2, _4, _NUMBER, $8D, $0D, $60, $00, $00
        DEFB _NEWLINE

        DEFB 6010 >> 8
        DEFB 6010 & $FF
        DEFW $001F
        DEFB _POKE, _A, _D, _COMMA, _N, _MINUS, _INT, _OPENBRACKET, _N
        DEFB _DIVIDE, _2, _5, _6, _NUMBER, $89, $00, $00, $00, $00
        DEFB _CLOSEBRACKET, _ASTERISK, _2, _5, _6
        DEFB _NUMBER, $89, $00, $00, $00, $00, _NEWLINE

        DEFB 6020 >> 8
        DEFB 6020 & $FF
        DEFW $001B
        DEFB _POKE, _A, _D, _PLUS, _1, _NUMBER, $81, $00, $00, $00, $00
        DEFB _COMMA, _INT, _OPENBRACKET, _N, _DIVIDE, _2, _5, _6
        DEFB _NUMBER, $89, $00, $00, $00, $00, _CLOSEBRACKET, _NEWLINE

        DEFB 6024 >> 8
        DEFB 6024 & $FF
        DEFW $0002
        DEFB _RETURN, _NEWLINE

        DEFB 6032 >> 8
        DEFB 6032 & $FF
        DEFW $0010
        DEFB _LET, _A, _D, _EQUALS, _1, _6, _5, _2, _0
        DEFB _NUMBER, $8F, $01, $10, $00, $00, _NEWLINE

        DEFB 6034 >> 8
        DEFB 6034 & $FF
        DEFW $0011
        DEFB _LET, _N, _EQUALS, _M, _S, _T, _PLUS, _4, _8, _0
        DEFB _NUMBER, $89, $70, $00, $00, $00, _NEWLINE

        DEFB 6036 >> 8
        DEFB 6036 & $FF
        DEFW $0006
        DEFB _GOSUB, _P, _O, _K, _E, _NEWLINE

        DEFB 6037 >> 8
        DEFB 6037 & $FF
        DEFW $0017
        DEFB _POKE, _1, _7, _3, _7, _0, _NUMBER, $8F, $07, $B4, $00, $00
        DEFB _COMMA, _1, _2, _8, _NUMBER, $88, $00, $00, $00, $00
        DEFB _NEWLINE

        DEFB 6038 >> 8
        DEFB 6038 & $FF
        DEFW $0005
        DEFB _GOSUB, _S, _U, _R, _NEWLINE

        DEFB 6040 >> 8
        DEFB 6040 & $FF
        DEFW $000E
        DEFB _RAND, _USR, _1, _8, _6, _0, _2
        DEFB _NUMBER, $8F, $11, $54, $00, $00, _NEWLINE

        DEFB 6041 >> 8
        DEFB 6041 & $FF
        DEFW $0017
        DEFB _POKE, _1, _7, _3, _7, _0, _NUMBER, $8F, $07, $B4, $00, $00
        DEFB _COMMA, _1, _3, _6, _NUMBER, $88, $08, $00, $00, $00
        DEFB _NEWLINE

        DEFB 6042 >> 8
        DEFB 6042 & $FF
        DEFW $0002
        DEFB _RETURN, _NEWLINE

        DEFB 6052 >> 8
        DEFB 6052 & $FF
        DEFW $0010
        DEFB _LET, _X, _EQUALS, _USR, _1, _7, _3, _6, _5
        DEFB _NUMBER, $8F, $07, $AA, $00, $00, _NEWLINE

        DEFB 6054 >> 8
        DEFB 6054 & $FF
        DEFW $0002
        DEFB _RETURN, _NEWLINE

        DEFB 6062 >> 8
        DEFB 6062 & $FF
        DEFW $0012
        DEFB _IF, _INKEY, _NOTEQUAL, _QUOTE, _QUOTE, _THEN, _GOTO
        DEFB _6, _0, _6, _2, _NUMBER, $8D, $3D, $70, $00, $00, _NEWLINE

        DEFB 6064 >> 8
        DEFB 6064 & $FF
        DEFW $0012
        DEFB _IF, _INKEY, _EQUALS, _QUOTE, _QUOTE, _THEN, _GOTO
        DEFB _6, _0, _6, _4, _NUMBER, $8D, $3D, $80, $00, $00, _NEWLINE

        DEFB 6066 >> 8
        DEFB 6066 & $FF
        DEFW $0002
        DEFB _RETURN, _NEWLINE

        DEFB 6072 >> 8
        DEFB 6072 & $FF
        DEFW $0010
        DEFB _LET, _X, _EQUALS, _USR, _1, _8, _6, _0, _2
        DEFB _NUMBER, $8F, $11, $54, $00, $00, _NEWLINE

        DEFB 6074 >> 8
        DEFB 6074 & $FF
        DEFW $0002
        DEFB _RETURN, _NEWLINE

        DEFB 6082 >> 8
        DEFB 6082 & $FF
        DEFW $0010
        DEFB _LET, _X, _EQUALS, _USR, _1, _7, _1, _2, _8
        DEFB _NUMBER, $8F, $05, $D0, $00, $00, _NEWLINE

        DEFB 6083 >> 8
        DEFB 6083 & $FF
        DEFW $0010
        DEFB _LET, _X, _EQUALS, _USR, _1, _7, _1, _7, _1
        DEFB _NUMBER, $8F, $06, $26, $00, $00, _NEWLINE

        DEFB 6084 >> 8
        DEFB 6084 & $FF
        DEFW $0016
        DEFB _POKE, _1, _6, _5, _2, _7, _NUMBER, $8F, $01, $1E, $00, $00
        DEFB _COMMA, _2, _3, _NUMBER, $85, $38, $00, $00, $00, _NEWLINE

        DEFB 6085 >> 8
        DEFB 6085 & $FF
        DEFW $0010
        DEFB _LET, _X, _EQUALS, _USR, _1, _7, _0, _2, _8
        DEFB _NUMBER, $8F, $05, $08, $00, $00, _NEWLINE

        DEFB 6086 >> 8
        DEFB 6086 & $FF
        DEFW $0010
        DEFB _LET, _X, _EQUALS, _USR, _1, _7, _1, _2, _8
        DEFB _NUMBER, $8F, $05, $D0, $00, $00, _NEWLINE

        DEFB 6088 >> 8
        DEFB 6088 & $FF
        DEFW $002B
        DEFB _LET, _M, _O, _V, _E, _S, _EQUALS, _PEEK, _1, _6, _5, _1, _8
        DEFB _NUMBER, $8F, $01, $0C, $00, $00, _PLUS, _PEEK
        DEFB _1, _6, _5, _1, _9, _NUMBER, $8F, $01, $0E, $00, $00
        DEFB _ASTERISK, _2, _5, _6, _NUMBER, $89, $00, $00, $00, $00
        DEFB _NEWLINE

        DEFB 6089 >> 8
        DEFB 6089 & $FF
        DEFW $0002
        DEFB _RETURN, _NEWLINE

        DEFB 6110 >> 8
        DEFB 6110 & $FF
        DEFW $0025
        DEFB _PRINT, _AT, _1, _4, _NUMBER, $84, $60, $00, $00, $00
        DEFB _COMMA, _C, _SEMICOLON, _QUOTE, _SPACE, _U, _S, _E, _SPACE
        DEFB _K, _E, _Y, _S, _SPACE, _SPACE, _W, _SPACE, _A, _SPACE, _D
        DEFB _AND, _X, _SPACE, _SPACE, _OR, _QUOTE, _NEWLINE

        DEFB 6112 >> 8
        DEFB 6112 & $FF
        DEFW $0028
        DEFB _PRINT, _AT, _1, _6, _NUMBER, $85, $00, $00, $00, $00
        DEFB _COMMA, _C, _SEMICOLON, _QUOTE, _SPACE, _W, _SPACE, _S
        DEFB _SPACE, _H, _AND, _J, _FULLSTOP, _SPACE, _SPACE
        DEFB _V, _EQUALS, _V, _I, _E, _W, _COMMA, _Y, _EQUALS
        DEFB _S, _T, _O, _P, _QUOTE, _NEWLINE

        DEFB 6114 >> 8
        DEFB 6114 & $FF
        DEFW $002C
        DEFB _PRINT, _AT, _2, _1, _NUMBER, $85, $28, $00, $00, $00
        DEFB _COMMA, _C, _SEMICOLON, _QUOTE, _INVT, _INVH, _INVE, _BLACK
        DEFB _INVM, _INVA, _INVZ, _INVE, _BLACK, _INVI, _INVS, _BLACK
        DEFB _INVN, _INVO, _INVW, _BLACK, _INVB, _INVE, _INVI, _INVN
        DEFB _INVG, _BLACK, _INVD, _INVR, _INVA, _INVW, _INVN, _BLACK
        DEFB _QUOTE, _NEWLINE

        DEFB 6124 >> 8
        DEFB 6124 & $FF
        DEFW $0017
        DEFB _POKE, _1, _6, _6, _7, _7, _NUMBER, $8F, $02, $4A, $00, $00
        DEFB _COMMA, _1, _2, _8, _NUMBER, $88, $00, $00, $00, $00
        DEFB _NEWLINE

        DEFB 6126 >> 8
        DEFB 6126 & $FF
        DEFW $000E
        DEFB _RAND, _USR, _1, _6, _6, _7, _2
        DEFB _NUMBER, $8F, $02, $40, $00, $00, _NEWLINE

        DEFB 6130 >> 8
        DEFB 6130 & $FF
        DEFW $0015
        DEFB _POKE, _1, _6, _5, _1, _8, _NUMBER, $8F, $01, $0C, $00, $00
        DEFB _COMMA, _8, _NUMBER, $84, $00, $00, $00, $00, _NEWLINE

        DEFB 6132 >> 8
        DEFB 6132 & $FF
        DEFW $000E
        DEFB _RAND, _USR, _1, _6, _6, _2, _0
        DEFB _NUMBER, $8F, $01, $D8, $00, $00, _NEWLINE

        DEFB 6141 >> 8
        DEFB 6141 & $FF
        DEFW $0002
        DEFB _RAND, _NEWLINE

        DEFB 6142 >> 8
        DEFB 6142 & $FF
        DEFW $0021
        DEFB _LET, _N, _EQUALS, _M, _S, _T, _PLUS, _1, _2, _8
        DEFB _NUMBER, $88, $00, $00, $00, $00, _PLUS, _INT, _OPENBRACKET
        DEFB _RND, _ASTERISK, _2, _8, _1, _0
        DEFB _NUMBER, $8C, $2F, $A0, $00, $00, _CLOSEBRACKET, _NEWLINE

        DEFB 6144 >> 8
        DEFB 6144 & $FF
        DEFW $0042
        DEFB _IF, _PEEK, _N, _EQUALS, _8
        DEFB _NUMBER, $84, $00, $00, $00, $00, _OR, _PEEK, _OPENBRACKET
        DEFB _N, _PLUS, _1, _NUMBER, $81, $00, $00, $00, $00
        DEFB _CLOSEBRACKET, _EQUALS, _8
        DEFB _NUMBER, $84, $00, $00, $00, $00, _OR, _PEEK, _OPENBRACKET
        DEFB _N, _MINUS, _1, _NUMBER, $81, $00, $00, $00, $00
        DEFB _CLOSEBRACKET, _EQUALS, _8
        DEFB _NUMBER, $84, $00, $00, $00, $00, _THEN, _GOTO
        DEFB _6, _1, _4, _2, _NUMBER, $8D, $3F, $F0, $00, $00, _NEWLINE

        DEFB 6146 >> 8
        DEFB 6146 & $FF
        DEFW $0010
        DEFB _LET, _A, _D, _EQUALS, _1, _6, _5, _2, _0
        DEFB _NUMBER, $8F, $01, $10, $00, $00, _NEWLINE

        DEFB 6148 >> 8
        DEFB 6148 & $FF
        DEFW $0006
        DEFB _GOSUB, _P, _O, _K, _E, _NEWLINE

        DEFB 6150 >> 8
        DEFB 6150 & $FF
        DEFW $000C
        DEFB _POKE, _N, _COMMA, _5, _7, _NUMBER, $86, $64, $00, $00, $00
        DEFB _NEWLINE

        DEFB 6152 >> 8
        DEFB 6152 & $FF
        DEFW $0006
        DEFB _LET, _T, _R, _EQUALS, _N, _NEWLINE

        DEFB 6153 >> 8
        DEFB 6153 & $FF
        DEFW $0026
        DEFB _POKE, _1, _6, _4, _3, _7, _NUMBER, $8F, $00, $6A, $00, $00
        DEFB _COMMA, _INT, _OPENBRACKET, _RND, _ASTERISK, _1, _2, _0
        DEFB _NUMBER, $87, $70, $00, $00, $00, _CLOSEBRACKET, _PLUS
        DEFB _1, _3, _2, _NUMBER, $88, $04, $00, $00, $00, _NEWLINE

        DEFB 6155 >> 8
        DEFB 6155 & $FF
        DEFW $0010
        DEFB _LET, _X, _EQUALS, _USR, _1, _6, _6, _9, _4
        DEFB _NUMBER, $8F, $02, $6C, $00, $00, _NEWLINE

        DEFB 6157 >> 8
        DEFB 6157 & $FF
        DEFW $003C
        DEFB _IF, _PEEK, _1, _6, _5, _1, _8
        DEFB _NUMBER, $8F, $01, $0C, $00, $00, _PLUS, _PEEK
        DEFB _1, _6, _5, _1, _9, _NUMBER, $8F, $01, $0E, $00, $00
        DEFB _ASTERISK, _2, _5, _6, _NUMBER, $89, $00, $00, $00, $00
        DEFB _GREATERTHAN, _1, _2, _0, _0
        DEFB _NUMBER, $8B, $16, $00, $00, $00, _THEN, _GOTO
        DEFB _6, _1, _7, _0, _NUMBER, $8D, $40, $D0, $00, $00, _NEWLINE

        DEFB 6158 >> 8
        DEFB 6158 & $FF
        DEFW $002C
        DEFB _PRINT, _AT, _2, _1, _NUMBER, $85, $28, $00, $00, $00
        DEFB _COMMA, _C, _SEMICOLON, _QUOTE, _SPACE, _T, _H, _E, _SPACE
        DEFB _M, _A, _Z, _E, _SPACE , _I, _S, _SPACE , _B, _E, _I, _N, _G
        DEFB _SPACE , _R, _E, _D, _R, _A, _W, _N, _SPACE, _SPACE, _QUOTE
        DEFB _NEWLINE

        DEFB 6160 >> 8
        DEFB 6160 & $FF
        DEFW $000C
        DEFB _GOTO, _6, _1, _2, _0, _NUMBER, $8D, $3F, $40, $00, $00
        DEFB _NEWLINE

        DEFB 6170 >> 8
        DEFB 6170 & $FF
        DEFW $000E
        DEFB _RAND, _USR, _2, _0, _5, _1, _5
        DEFB _NUMBER, $8F, $20, $46, $00, $00, _NEWLINE

        DEFB 6172 >> 8
        DEFB 6172 & $FF
        DEFW $0010
        DEFB _LET, _X, _EQUALS, _USR, _2, _0, _1, _3, _3
        DEFB _NUMBER, $8F, $1D, $4A, $00, $00, _NEWLINE

        DEFB 6298 >> 8
        DEFB 6298 & $FF
        DEFW $002C
        DEFB _PRINT, _AT, _2, _1, _NUMBER, $85, $28, $00, $00, $00
        DEFB _COMMA, _C, _SEMICOLON, _QUOTE, _SPACE, _M, _A, _Z, _E
        DEFB _SPACE, _R, _E, _A, _D, _Y, _SPACE, _MINUS, _SPACE
        DEFB _P, _R, _E, _S, _S, _SPACE, _A, _N, _Y, _SPACE, _K, _E, _Y
        DEFB _SPACE, _QUOTE, _NEWLINE

        DEFB 6300 >> 8
        DEFB 6300 & $FF
        DEFW $0005
        DEFB _GOSUB, _I, _N, _K, _NEWLINE

        DEFB 6310 >> 8
        DEFB 6310 & $FF
        DEFW $0005
        DEFB _GOSUB, _S, _U, _R, _NEWLINE

        DEFB 6314 >> 8
        DEFB 6314 & $FF
        DEFW $000E
        DEFB _RAND, _USR, _2, _0, _8, _6, _0
        DEFB _NUMBER, $8F, $22, $F8, $00, $00, _NEWLINE

        DEFB 6316 >> 8
        DEFB 6316 & $FF
        DEFW $0030
        DEFB _PRINT, _AT, _2, _NUMBER, $82, $00, $00, $00, $00, _COMMA
        DEFB _1, _NUMBER, $81, $00, $00, $00, $00, _SEMICOLON, _QUOTE
        DEFB _W, _H, _I, _C, _H, _SPACE, _W, _A, _Y, _SPACE
        DEFB _QUESTIONMARK, _SPACE, _SPACE, _SPACE, _P, _R, _E, _S, _S
        DEFB _SPACE, _DOUBLEQUOTE, _L, _DOUBLEQUOTE, _OR, _DOUBLEQUOTE
        DEFB _R, _DOUBLEQUOTE, _QUOTE, _NEWLINE

        DEFB 6318 >> 8
        DEFB 6318 & $FF
        DEFW $0027
        DEFB _LET, _N, _EQUALS, _PEEK, _1, _6, _5, _2, _0
        DEFB _NUMBER, $8F, $01, $10, $00, $00, _PLUS, _PEEK
        DEFB _1, _6, _5, _2, _1, _NUMBER, $8F, $01, $12, $00, $00
        DEFB _ASTERISK, _2, _5, _6, _NUMBER, $89, $00, $00, $00, $00
        DEFB _NEWLINE

        DEFB 6319 >> 8
        DEFB 6319 & $FF
        DEFW $0006
        DEFB _LET, _H, _M, _EQUALS, _N, _NEWLINE

        DEFB 6320 >> 8
        DEFB 6320 & $FF
        DEFW $0010
        DEFB _LET, _A, _D, _EQUALS, _1, _6, _5, _2, _2
        DEFB _NUMBER, $8F, $01, $14, $00, $00, _NEWLINE

        DEFB 6322 >> 8
        DEFB 6322 & $FF
        DEFW $0006
        DEFB _GOSUB, _P, _O, _K, _E, _NEWLINE

        DEFB 6324 >> 8
        DEFB 6324 & $FF
        DEFW $0005
        DEFB _GOSUB, _I, _N, _K, _NEWLINE

        DEFB 6334 >> 8
        DEFB 6334 & $FF
        DEFW $0006
        DEFB _LET, _D, _DOLLAR, _EQUALS, _INKEY, _NEWLINE

        DEFB 6336 >> 8
        DEFB 6336 & $FF
        DEFW $0014
        DEFB _IF, _D, _DOLLAR, _EQUALS, _QUOTE, _R, _QUOTE, _THEN, _GOTO
        DEFB _6, _3, _4, _6, _NUMBER, $8D, $46, $50, $00, $00, _NEWLINE

        DEFB 6338 >> 8
        DEFB 6338 & $FF
        DEFW $0014
        DEFB _IF, _D, _DOLLAR, _EQUALS, _QUOTE, _L, _QUOTE, _THEN, _GOTO
        DEFB _6, _3, _5, _0, _NUMBER, $8D, $46, $70, $00, $00, _NEWLINE

        DEFB 6340 >> 8
        DEFB 6340 & $FF
        DEFW $000C
        DEFB _GOTO, _6, _3, _2, _4, _NUMBER, $8D, $45, $A0, $00, $00
        DEFB _NEWLINE

        DEFB 6346 >> 8
        DEFB 6346 & $FF
        DEFW $0015
        DEFB _POKE, _N, _MINUS, _1, _NUMBER, $81, $00, $00, $00, $00
        DEFB _COMMA, _1, _2, _8, _NUMBER, $88, $00, $00, $00, $00
        DEFB _NEWLINE

        DEFB 6348 >> 8
        DEFB 6348 & $FF
        DEFW $000C
        DEFB _GOTO, _6, _3, _6, _0, _NUMBER, $8D, $46, $C0, $00, $00
        DEFB _NEWLINE

        DEFB 6350 >> 8
        DEFB 6350 & $FF
        DEFW $0015
        DEFB _POKE, _N, _PLUS, _1, _NUMBER, $81, $00, $00, $00, $00
        DEFB _COMMA, _1, _2, _8, _NUMBER, $88, $00, $00, $00, $00
        DEFB _NEWLINE

        DEFB 6360 >> 8
        DEFB 6360 & $FF
        DEFW $0005
        DEFB _GOSUB, _S, _U, _R, _NEWLINE

        DEFB 6362 >> 8
        DEFB 6362 & $FF
        DEFW $000E
        DEFB _RAND, _USR, _2, _0, _8, _6, _0
        DEFB _NUMBER, $8F, $22, $F8, $00, $00, _NEWLINE

        DEFB 6364 >> 8
        DEFB 6364 & $FF
        DEFW $002D
        DEFB _PRINT, _AT, _2, _1, _NUMBER, $85, $28, $00, $00, $00
        DEFB _COMMA, _C, _SEMICOLON, _QUOTE, _P, _R, _E, _S, _S, _SPACE
        DEFB _A, _N, _Y, _SPACE, _K, _E, _Y, _SPACE, _F, _O, _R, _SPACE
        DEFB _I, _N, _F, _O, _R, _M, _A, _T, _I, _O, _N, _QUOTE, _NEWLINE

        DEFB 6366 >> 8
        DEFB 6366 & $FF
        DEFW $0005
        DEFB _GOSUB, _I, _N, _K, _NEWLINE

        DEFB 6392 >> 8
        DEFB 6392 & $FF
        DEFW $0005
        DEFB _GOSUB, _S, _U, _R, _NEWLINE

        DEFB 6394 >> 8
        DEFB 6394 & $FF
        DEFW $0027
        DEFB _PRINT, _AT, _1, _0, _NUMBER, $84, $20, $00, $00, $00
        DEFB _COMMA, _7, _NUMBER, $83, $60, $00, $00, $00, _SEMICOLON
        DEFB _QUOTE, _C, _H, _E, _C, _K, _I, _N, _G, _SPACE
        DEFB _D, _I, _S, _T, _A, _N, _C, _E, _QUOTE, _NEWLINE

        DEFB 6398 >> 8
        DEFB 6398 & $FF
        DEFW $0004
        DEFB _GOSUB, _C, _T, _NEWLINE

        DEFB 6410 >> 8
        DEFB 6410 & $FF
        DEFW $001D
        DEFB _IF, _M, _O, _V, _E, _S, _GREATERTHAN, _1, _2, _0
        DEFB _NUMBER, $87, $70, $00, $00, $00, _THEN, _GOTO
        DEFB _6, _4, _4, _0, _NUMBER, $8D, $49, $40, $00, $00, _NEWLINE

        DEFB 6412 >> 8
        DEFB 6412 & $FF
        DEFW $000C
        DEFB _POKE, _T, _R, _COMMA, _0
        DEFB _NUMBER, $00, $00, $00, $00, $00, _NEWLINE

        DEFB 6414 >> 8
        DEFB 6414 & $FF
        DEFW $0021
        DEFB _LET, _N, _EQUALS, _M, _S, _T, _PLUS, _1, _2, _8
        DEFB _NUMBER, $88, $00, $00, $00, $00, _PLUS, _INT, _OPENBRACKET
        DEFB _RND, _ASTERISK, _2, _8, _1, _0
        DEFB _NUMBER, $8C, $2F, $A0, $00, $00, _CLOSEBRACKET, _NEWLINE

        DEFB 6416 >> 8
        DEFB 6416 & $FF
        DEFW $0018
        DEFB _IF, _PEEK, _N, _NOTEQUAL, _0
        DEFB _NUMBER, $00, $00, $00, $00, $00, _THEN, _GOTO
        DEFB _6, _4, _1, _4, _NUMBER, $8D, $48, $70, $00, $00, _NEWLINE

        DEFB 6418 >> 8
        DEFB 6418 & $FF
        DEFW $0006
        DEFB _LET, _T, _R, _EQUALS, _N, _NEWLINE

        DEFB 6420 >> 8
        DEFB 6420 & $FF
        DEFW $000D
        DEFB _POKE, _T, _R, _COMMA, _5, _7
        DEFB _NUMBER, $86, $64, $00, $00, $00, _NEWLINE

        DEFB 6422 >> 8
        DEFB 6422 & $FF
        DEFW $000C
        DEFB _GOTO, _6, _3, _9, _6
        DEFB _NUMBER, $8D, $47, $E0, $00, $00, _NEWLINE

        DEFB 6440 >> 8
        DEFB 6440 & $FF
        DEFW $001A
        DEFB _LET, _N, _EQUALS, _M, _O, _V, _E, _S, _ASTERISK, _4
        DEFB _NUMBER, $83, $00, $00, $00, $00, _PLUS, _1, _0
        DEFB _NUMBER, $84, $20, $00, $00, $00, _NEWLINE

        DEFB 6441 >> 8
        DEFB 6441 & $FF
        DEFW $0006
        DEFB _LET, _M, _A, _EQUALS, _N, _NEWLINE

        DEFB 6442 >> 8
        DEFB 6442 & $FF
        DEFW $0010
        DEFB _LET, _A, _D, _EQUALS, _1, _9, _2, _1, _4
        DEFB  _NUMBER, $8F, $16, $1C, $00, $00, _NEWLINE

        DEFB 6443 >> 8
        DEFB 6443 & $FF
        DEFW $0006
        DEFB _GOSUB, _P, _O, _K, _E, _NEWLINE

        DEFB 6444 >> 8
        DEFB 6444 & $FF
        DEFW $0018
        DEFB _LET, _X, _EQUALS, _INT, _OPENBRACKET, _M, _O, _V, _E, _S
        DEFB _DIVIDE, _5, _NUMBER, $83, $20, $00, $00, $00, _ASTERISK
        DEFB _VAL, _K, _DOLLAR, _CLOSEBRACKET, _NEWLINE

        DEFB 6445 >> 8
        DEFB 6445 & $FF
        DEFW $001A
        DEFB _IF, _X, _GREATERTHAN, _2, _5, _5
        DEFB _NUMBER, $88, $7F, $00, $00, $00, _THEN, _LET, _X, _EQUALS
        DEFB _2, _5, _5, _NUMBER, $88, $7F, $00, $00, $00, _NEWLINE

        DEFB 6446 >> 8
        DEFB 6446 & $FF
        DEFW $000F
        DEFB _POKE, _1, _8, _7, _7, _9, _NUMBER, $8F, $12, $B6, $00, $00
        DEFB _COMMA, _X, _NEWLINE

        DEFB 6448 >> 8
        DEFB 6448 & $FF
        DEFW $001A
        DEFB _POKE, _1, _9, _2, _2, _5, _NUMBER, $8F, $16, $32, $00, $00
        DEFB _COMMA, _3, _0, _NUMBER, $85, $70, $00, $00, $00, _DIVIDE
        DEFB _VAL, _K, _DOLLAR, _NEWLINE

        DEFB 6452 >> 8
        DEFB 6452 & $FF
        DEFW $0005
        DEFB _GOSUB, _S, _U, _R, _NEWLINE

        DEFB 6456 >> 8
        DEFB 6456 & $FF
        DEFW $0025
        DEFB _PRINT, _AT, _2, _NUMBER, $82, $00, $00, $00, $00, _COMMA
        DEFB _7, _NUMBER, $83, $60, $00, $00, $00, _SEMICOLON, _QUOTE
        DEFB _INVS, _INVI, _INVT, _INVU, _INVA, _INVT, _INVI, _INVO
        DEFB _INVN, _BLACK, _INVR, _INVE, _INVP, _INVO, _INVR, _INVT
        DEFB _QUOTE, _NEWLINE

        DEFB 6458 >> 8
        DEFB 6458 & $FF
        DEFW $0004
        DEFB _GOSUB, _C, _T, _NEWLINE

        DEFB 6470 >> 8
        DEFB 6470 & $FF
        DEFW $003C
        DEFB _IF, _NOT, _PEEK, _1, _9, _2, _1, _7
        DEFB _NUMBER, $8F, $16, $22, $00, $00, _THEN, _PRINT, _AT, _5
        DEFB _NUMBER, $83, $20, $00, $00, $00, _COMMA, _C, _SEMICOLON
        DEFB _QUOTE, _M, _O, _V, _E, _S, _SPACE, _T, _O, _SPACE
        DEFB _T, _H, _E, _SPACE, _T, _R, _E, _A, _S, _U, _R, _E, _SPACE
        DEFB _EQUALS, _SPACE, _QUOTE, _SEMICOLON, _M, _O, _V, _E, _S
        DEFB _NEWLINE

        DEFB 6472 >> 8
        DEFB 6472 & $FF
        DEFW $003A
        DEFB _IF, _PEEK, _1, _9, _2, _1, _7
        DEFB _NUMBER, $8F, $16, $22, $00, $00, _THEN, _PRINT, _AT, _5
        DEFB _NUMBER, $83, $20, $00, $00, $00, _COMMA, _C, _SEMICOLON
        DEFB _QUOTE, _M, _O, _V, _E, _S, _SPACE, _B, _A, _C, _K, _SPACE
        DEFB _T, _O, _SPACE, _DOUBLEQUOTE, _B, _A, _S, _E, _DOUBLEQUOTE
        DEFB _SPACE, _EQUALS, _SPACE, _QUOTE, _SEMICOLON, _M, _O, _V, _E
        DEFB _S, _NEWLINE

        DEFB 6474 >> 8
        DEFB 6474 & $FF
        DEFW $0014
        DEFB _IF, _K, _DOLLAR, _EQUALS, _QUOTE, _1, _QUOTE, _THEN, _GOTO
        DEFB _6, _5, _0, _0, _NUMBER, $8D, $4B, $20, $00, $00, _NEWLINE

        DEFB 6476 >> 8
        DEFB 6476 & $FF
        DEFW $0028
        DEFB _LET, _M, _L, _EQUALS, _PEEK, _1, _9, _2, _1, _4
        DEFB _NUMBER, $8F, $16, $1C, $00, $00, _PLUS, _PEEK
        DEFB _1, _9, _2, _1, _5, _NUMBER, $8F, $16, $1E, $00, $00
        DEFB _ASTERISK, _2, _5, _6, _NUMBER, $89, $00, $00, $00, $00
        DEFB _NEWLINE

        DEFB 6477 >> 8
        DEFB 6477 & $FF
        DEFW $001D
        DEFB _IF, _M, _L, _GREATERTHAN, _1, _1
        DEFB _NUMBER, $84, $30, $00, $00, $00, _THEN, _LET, _M, _L
        DEFB _EQUALS, _M, _L, _MINUS, _1, _0
        DEFB _NUMBER, $84, $20, $00, $00, $00, _NEWLINE

        DEFB 6478 >> 8
        DEFB 6478 & $FF
        DEFW $002A
        DEFB _PRINT, _AT, _7, _NUMBER, $83, $60, $00, $00, $00, _COMMA
        DEFB _C, _SEMICOLON, _QUOTE, _Y, _O, _U, _SPACE, _H, _A, _V, _E
        DEFB _SPACE, _QUOTE, _SEMICOLON, _M, _L, _SEMICOLON, _QUOTE
        DEFB _SPACE, _M, _O, _V, _E, _S, _SPACE, _T, _O, _SPACE, _G, _O
        DEFB _QUOTE, _NEWLINE

        DEFB 6480 >> 8
        DEFB 6480 & $FF
        DEFW $0016
        DEFB _IF, _M, _L, _GREATERTHANEQUAL, _M, _O, _V, _E, _S, _THEN, _GOTO
        DEFB _6, _4, _8, _9, _NUMBER, $8D, $4A, $C8, $00, $00, _NEWLINE

        DEFB 6482 >> 8
        DEFB 6482 & $FF
        DEFW $0026
        DEFB _LET, _X, _EQUALS, _INT, _OPENBRACKET, _OPENBRACKET
        DEFB _M, _O, _V, _E, _S, _MINUS, _M, _L, _CLOSEBRACKET, _DIVIDE
        DEFB _PEEK, _1, _8, _7, _7, _9, _NUMBER, $8F, $12, $B6, $00, $00
        DEFB _CLOSEBRACKET, _PLUS, _1, _NUMBER, $81, $00, $00, $00, $00
        DEFB _NEWLINE

        DEFB 6484 >> 8
        DEFB 6484 & $FF
        DEFW $0028
        DEFB _PRINT, _AT, _9, _NUMBER, $84, $10, $00, $00, $00, _COMMA
        DEFB _C, _SEMICOLON, _QUOTE, _Y, _O, _U, _SPACE, _N, _E, _E, _D
        DEFB _SPACE, _T, _O, _SPACE, _K, _I, _L, _L, _SPACE, _A, _T
        DEFB _SPACE, _L, _E, _A, _S, _T, _QUOTE, _NEWLINE

        DEFB 6485 >> 8
        DEFB 6485 & $FF
        DEFW $0019
        DEFB _PRINT, _AT, _1, _0, _NUMBER, $84, $20, $00, $00, $00
        DEFB _COMMA, _C, _SEMICOLON, _X, _SEMICOLON, _QUOTE, _SPACE
        DEFB _M, _A, _Z, _O, _G, _QUOTE, _SEMICOLON, _NEWLINE

        DEFB 6487 >> 8
        DEFB 6487 & $FF
        DEFW $0011
        DEFB _IF, _X, _GREATERTHAN, _1, _NUMBER, $81, $00, $00, $00, $00
        DEFB _THEN, _PRINT, _QUOTE, _S, _QUOTE, _SEMICOLON, _NEWLINE

        DEFB 6488 >> 8
        DEFB 6488 & $FF
        DEFW $0011
        DEFB _PRINT, _QUOTE, _SPACE, _T, _O, _SPACE, _G, _E, _T, _SPACE
        DEFB _T, _H, _E, _R, _E, _QUOTE, _NEWLINE

        DEFB 6489 >> 8
        DEFB 6489 & $FF
        DEFW $0036
        DEFB _PRINT, _AT, _1, _3, _NUMBER, $84, $50, $00, $00, $00
        DEFB _COMMA, _C, _SEMICOLON, _QUOTE, _Y, _O, _U, _SPACE
        DEFB _G, _A, _I, _N, _SPACE, _QUOTE, _SEMICOLON, _PEEK
        DEFB _1, _8, _7, _7, _9, _NUMBER, $8F, $12, $B6, $00, $00
        DEFB _SEMICOLON, _QUOTE, _SPACE, _F, _O, _R, _SPACE
        DEFB _A, _SPACE, _DOUBLEQUOTE, _K, _I, _L, _L, _DOUBLEQUOTE
        DEFB _QUOTE, _NEWLINE

        DEFB 6490 >> 8
        DEFB 6490 & $FF
        DEFW $0039
        DEFB _PRINT, _AT, _1, _5, _NUMBER, $84, $70, $00, $00, $00
        DEFB _COMMA, _C, _SEMICOLON, _QUOTE, _Y, _O, _U, _SPACE
        DEFB _L, _O, _S, _E, _SPACE, _QUOTE, _SEMICOLON, _PEEK
        DEFB _1, _9, _2, _2, _5, _NUMBER, $8F, $16, $32, $00, $00
        DEFB _SEMICOLON, _QUOTE, _SPACE, _F, _O, _R, _SPACE
        DEFB _E, _A, _C, _H, _SPACE, _DOUBLEQUOTE, _V, _I, _E, _W
        DEFB _DOUBLEQUOTE, _QUOTE, _NEWLINE

        DEFB 6492 >> 8
        DEFB 6492 & $FF
        DEFW $002A
        DEFB _PRINT, _AT, _1, _7, _NUMBER, $85, $08, $00, $00, $00
        DEFB _COMMA, _C, _SEMICOLON, _QUOTE, _T, _H, _I, _S, _SPACE
        DEFB _R, _E, _P, _O, _R, _T, _SPACE, _T, _A, _K, _E, _S, _SPACE
        DEFB _1, _0, _SPACE, _M, _O, _V, _E, _S, _QUOTE, _NEWLINE

        DEFB 6494 >> 8
        DEFB 6494 & $FF
        DEFW $000E
        DEFB _LET, _N, _EQUALS, _M, _L, _PLUS, _1
        DEFB _NUMBER, $81, $00, $00, $00, $00, _NEWLINE

        DEFB 6496 >> 8
        DEFB 6496 & $FF
        DEFW $0006
        DEFB _GOSUB, _P, _O, _K, _E, _NEWLINE

        DEFB 6498 >> 8
        DEFB 6498 & $FF
        DEFW $0027
        DEFB _PRINT, _AT, _1, _9, _NUMBER, $85, $18, $00, $00, $00
        DEFB _COMMA, _C, _SEMICOLON, _QUOTE, _P, _R, _E, _S, _S, _SPACE
        DEFB _SPACE, _T, _SPACE, _TO, _DOUBLEQUOTE, _B, _U, _Y
        DEFB _DOUBLEQUOTE, _SPACE, _A, _SPACE, _S, _W, _O, _R, _D
        DEFB _QUOTE, _NEWLINE

        DEFB 6500 >> 8
        DEFB 6500 & $FF
        DEFW $002A
        DEFB _PRINT, _AT, _2, _1, _NUMBER, $85, $28, $00, $00, $00
        DEFB _COMMA, _C, _SEMICOLON, _QUOTE, _P, _R, _E, _S, _S, _SPACE
        DEFB _A, _N, _Y, _SPACE, _K, _E, _Y, _SPACE, _F, _O, _R, _SPACE
        DEFB _T, _H, _E, _SPACE, _G, _A, _M, _E, _QUOTE, _NEWLINE

        DEFB 6502 >> 8
        DEFB 6502 & $FF
        DEFW $0015
        DEFB _POKE, _1, _9, _2, _2, _2, _NUMBER, $8F, $16, $2C, $00, $00
        DEFB _COMMA, _0, _NUMBER, $00, $00, $00, $00, $00, _NEWLINE

        DEFB 6504 >> 8
        DEFB 6504 & $FF
        DEFW $0005
        DEFB _GOSUB, _I, _N, _K, _NEWLINE

        DEFB 6506 >> 8
        DEFB 6506 & $FF
        DEFW $0006
        DEFB _LET, _P, _DOLLAR, _EQUALS, _INKEY, _NEWLINE

        DEFB 6999 >> 8
        DEFB 6999 & $FF
        DEFW $0002
        DEFB _RETURN, _NEWLINE

        DEFB 9000 >> 8
        DEFB 9000 & $FF
        DEFW $0002
        DEFB _CLEAR, _NEWLINE

        DEFB 9010 >> 8
        DEFB 9010 & $FF
        DEFW $000A
        DEFB _SAVE, _QUOTE, _M, _A, _Z, _O, _G, _INVS, _QUOTE, _NEWLINE

L6F08:  DEFB 9020 >> 8
        DEFB 9020 & $FF
        DEFW $0002
        DEFB _RUN, _NEWLINE

; ======================================================================================================================================================

; ------------
; Display File
; ------------

L6F0E:  DEFB _NEWLINE    
        DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
        DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
        DEFB _NEWLINE    
        DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
        DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
        DEFB _NEWLINE    
L6F50:  DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
        DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
        DEFB _NEWLINE    
        DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
        DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
        DEFB _NEWLINE    
        DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
        DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
        DEFB _NEWLINE    
        DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
        DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
        DEFB _NEWLINE    
        DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
        DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
        DEFB _NEWLINE    
        DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
        DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
        DEFB _NEWLINE    
        DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
        DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
        DEFB _NEWLINE    
        DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
        DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
        DEFB _NEWLINE    
        DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
        DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
        DEFB _NEWLINE    
        DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
        DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
        DEFB _NEWLINE    
        DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
        DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
        DEFB _NEWLINE    
        DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
        DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
        DEFB _NEWLINE    
        DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
        DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
        DEFB _NEWLINE    
        DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
        DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
        DEFB _NEWLINE    
        DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
        DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
        DEFB _NEWLINE    
        DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
        DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
        DEFB _NEWLINE    
        DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
        DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
        DEFB _NEWLINE    
        DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
        DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
        DEFB _NEWLINE    
        DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
        DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
        DEFB _NEWLINE    
        DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
        DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
        DEFB _NEWLINE    
        DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
        DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
        DEFB _NEWLINE    
        DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
        DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
        DEFB _NEWLINE    

; ======================================================================================================================================================

; --------------
; Variables Area
; --------------

L7227:  DEFB $80

; ======================================================================================================================================================

        END
